@@ -33,6 +33,7 @@
 
 #include "database/database.h"
 #include "util/tools.h"
+#include "util/upnp_clients.h"
 
 static constexpr bool isCdsItem(unsigned int type) { return type & OBJECT_TYPE_ITEM; }
 static constexpr bool isCdsPureItem(unsigned int type) { return type == OBJECT_TYPE_ITEM; }
@@ -55,14 +56,15 @@ void CdsObject::copyTo(const std::shared_ptr<CdsObject>& obj)
     for (auto&& resource : resources)
         obj->addResource(resource->clone());
 }
+
 bool CdsObject::equals(const std::shared_ptr<CdsObject>& obj, bool exactly) const
 {
-    if (!(id == obj->getID()
-            && parentID == obj->getParentID()
-            && isRestricted() == obj->isRestricted()
-            && title == obj->getTitle()
-            && upnpClass == obj->getClass()
-            && sortPriority == obj->getSortPriority()))
+    if (id != obj->getID()
+        || parentID != obj->getParentID()
+        || isRestricted() != obj->isRestricted()
+        || title != obj->getTitle()
+        || upnpClass != obj->getClass()
+        || sortPriority != obj->getSortPriority())
         return false;
 
     if (!resourcesEqual(obj))
@@ -71,13 +73,13 @@ bool CdsObject::equals(const std::shared_ptr<CdsObject>& obj, bool exactly) cons
     if (metaData != obj->getMetaData())
         return false;
 
-    return !(exactly
-        && !(location == obj->getLocation()
+    return !exactly
+        || (location == obj->getLocation()
             && mtime == obj->getMTime()
             && sizeOnDisk == obj->getSizeOnDisk()
             && virt == obj->isVirtual()
             && std::equal(auxdata.begin(), auxdata.end(), obj->auxdata.begin())
-            && objectFlags == obj->getFlags()));
+            && objectFlags == obj->getFlags());
 }
 
 bool CdsObject::resourcesEqual(const std::shared_ptr<CdsObject>& obj) const
@@ -99,6 +101,11 @@ void CdsObject::validate() const
         throw_std_runtime_error("Object validation failed: missing upnp class");
 }
 
+bool CdsObject::isSubClass(const std::string& cls) const
+{
+    return startswith(upnpClass, cls);
+}
+
 std::shared_ptr<CdsObject> CdsObject::createObject(unsigned int objectType)
 {
     if (IS_CDS_CONTAINER(objectType)) {
@@ -122,6 +129,7 @@ CdsItem::CdsItem()
 {
     objectType = OBJECT_TYPE_ITEM;
     upnpClass = "object.item";
+    mtime = currentTime();
 }
 
 void CdsItem::copyTo(const std::shared_ptr<CdsObject>& obj)
@@ -135,14 +143,16 @@ void CdsItem::copyTo(const std::shared_ptr<CdsObject>& obj)
     item->setTrackNumber(trackNumber);
     item->setPartNumber(partNumber);
     item->setServiceID(serviceID);
-    item->setBookMarkPos(bookMarkPos);
+    if (playStatus)
+        item->setPlayStatus(playStatus->clone());
 }
+
 bool CdsItem::equals(const std::shared_ptr<CdsObject>& obj, bool exactly) const
 {
     auto item = std::static_pointer_cast<CdsItem>(obj);
     if (!CdsObject::equals(obj, exactly))
         return false;
-    return (mimeType == item->getMimeType() && partNumber == item->getPartNumber() && trackNumber == item->getTrackNumber() && serviceID == item->getServiceID() && bookMarkPos == item->getBookMarkPos());
+    return (mimeType == item->getMimeType() && partNumber == item->getPartNumber() && trackNumber == item->getTrackNumber() && serviceID == item->getServiceID());
 }
 
 void CdsItem::validate() const
@@ -187,6 +197,7 @@ CdsContainer::CdsContainer()
 {
     objectType = OBJECT_TYPE_CONTAINER;
     upnpClass = UPNP_CLASS_CONTAINER;
+    mtime = currentTime();
 }
 
 void CdsContainer::copyTo(const std::shared_ptr<CdsObject>& obj)
