@@ -64,12 +64,13 @@ static constexpr bool IS_CDS_ITEM_EXTERNAL_URL(unsigned int type) { return type
 #define OBJECT_FLAG_PROXY_URL 0x00000020u
 #define OBJECT_FLAG_ONLINE_SERVICE 0x00000040u
 #define OBJECT_FLAG_OGG_THEORA 0x00000080u
-#define OBJECT_FLAG_PLAYED 0x00000200u
 
 #define OBJECT_AUTOSCAN_NONE 0u
 #define OBJECT_AUTOSCAN_UI 1u
 #define OBJECT_AUTOSCAN_CFG 2u
 
+class ClientStatusDetail;
+
 /// \brief Generic object in the Content Directory.
 class CdsObject {
 protected:
@@ -167,6 +168,7 @@ public:
     void setClass(const std::string& upnpClass) { this->upnpClass = upnpClass; }
     /// \brief Retrieve class
     std::string getClass() const { return upnpClass; }
+    bool isSubClass(const std::string& cls) const;
 
     /// \brief Set the physical location of the media (usually an absolute path)
     void setLocation(const fs::path& location) { this->location = location; }
@@ -260,13 +262,7 @@ public:
     void clearMetaData() { metaData.clear(); }
 
     /// \brief Set entire metadata dictionary.
-    void setMetaData(const std::vector<std::pair<std::string, std::string>>& metaData)
-    {
-        this->metaData = metaData;
-    }
-
-    /// \brief Set entire metadata dictionary by moving
-    void setMetaData(std::vector<std::pair<std::string, std::string>>&& metaData)
+    void setMetaData(std::vector<std::pair<std::string, std::string>> metaData)
     {
         this->metaData = std::move(metaData);
     }
@@ -285,9 +281,7 @@ public:
     /// \brief Removes metadata with the given key
     void removeMetaData(const metadata_fields_t key)
     {
-        auto&& field = MetadataHandler::getMetaFieldName(key);
-        while (std::find_if(metaData.begin(), metaData.end(), [=](auto&& md) { return md.first == field; }) != metaData.end())
-            metaData.erase(std::remove_if(metaData.begin(), metaData.end(), [=](auto&& md) { return md.first == field; }));
+        metaData.erase(std::remove_if(metaData.begin(), metaData.end(), [field = MetadataHandler::getMetaFieldName(key)](auto&& md) { return md.first == field; }), metaData.end());
     }
 
     /// \brief Query single auxdata value.
@@ -321,25 +315,19 @@ public:
     }
 
     /// \brief Set resources
-    void setResources(const std::vector<std::shared_ptr<CdsResource>>& res)
-    {
-        resources = res;
-    }
-
-    /// \brief Set resources by move
-    void setResources(std::vector<std::shared_ptr<CdsResource>>&& res)
+    void setResources(std::vector<std::shared_ptr<CdsResource>> res)
     {
         resources = std::move(res);
     }
 
     /// \brief Search resources for given handler id
-    bool hasResource(int id) const
+    bool hasResource(ContentHandler id) const
     {
         return std::any_of(resources.begin(), resources.end(), [=](auto&& res) { return id == res->getHandlerType(); });
     }
 
     /// \brief Remove resource with given handler id
-    void removeResource(int id)
+    void removeResource(ContentHandler id)
     {
         auto index = std::find_if(resources.begin(), resources.end(), [=](auto&& res) { return id == res->getHandlerType(); });
         if (index != resources.end()) {
@@ -353,6 +341,26 @@ public:
         return resources.at(index);
     }
 
+    /// \brief Query resource tag with the given handler id
+    std::shared_ptr<CdsResource> getResource(ContentHandler id) const
+    {
+        auto it = std::find_if(resources.begin(), resources.end(), [=](auto&& res) { return id == res->getHandlerType(); });
+        if (it != resources.end()) {
+            return *it;
+        }
+        return {};
+    }
+
+    /// \brief Query resource tag with the given purpose
+    std::shared_ptr<CdsResource> getResource(CdsResource::Purpose purpose) const
+    {
+        auto it = std::find_if(resources.begin(), resources.end(), [=](auto&& res) { return purpose == res->getPurpose(); });
+        if (it != resources.end()) {
+            return *it;
+        }
+        return {};
+    }
+
     /// \brief Add resource tag
     void addResource(const std::shared_ptr<CdsResource>& resource)
     {
@@ -400,7 +408,7 @@ protected:
     /// \brief unique service ID
     std::string serviceID;
 
-    std::chrono::milliseconds bookMarkPos {};
+    std::shared_ptr<ClientStatusDetail> playStatus {};
 
 public:
     /// \brief Constructor, sets the object type and default upnp:class (object.item)
@@ -447,11 +455,11 @@ public:
     /// \brief Retrieve the unique service ID.
     std::string getServiceID() const { return serviceID; }
 
-    /// \brief Retrieve the last known bookmark position in milliseconds.
-    void setBookMarkPos(std::chrono::milliseconds bookMarkPos) { this->bookMarkPos = bookMarkPos; }
+    /// \brief Retrieve Play Status details
+    void setPlayStatus(const std::shared_ptr<ClientStatusDetail>& playStatus) { this->playStatus = playStatus; }
 
-    /// \brief Set the bookmark position in milliseconds.
-    std::chrono::milliseconds getBookMarkPos() const { return bookMarkPos; }
+    /// \brief Set Play Status details
+    std::shared_ptr<ClientStatusDetail> getPlayStatus() const { return playStatus; }
 };
 
 /// \brief An item that is accessible via a URL.
