@@ -30,8 +30,8 @@
 #include "util/grb_fs.h"
 
 // forward declarations
-class AutoscanDirectory;
 class AutoscanList;
+class AutoscanDirectory;
 class ClientConfigList;
 class ConfigOption;
 class Database;
@@ -105,7 +105,6 @@ enum config_option_t {
     CFG_SERVER_EXTOPTS_FFMPEGTHUMBNAILER_THUMBSIZE,
     CFG_SERVER_EXTOPTS_FFMPEGTHUMBNAILER_SEEK_PERCENTAGE,
     CFG_SERVER_EXTOPTS_FFMPEGTHUMBNAILER_FILMSTRIP_OVERLAY,
-    CFG_SERVER_EXTOPTS_FFMPEGTHUMBNAILER_WORKAROUND_BUGS,
     CFG_SERVER_EXTOPTS_FFMPEGTHUMBNAILER_IMAGE_QUALITY,
     CFG_SERVER_EXTOPTS_FFMPEGTHUMBNAILER_CACHE_DIR_ENABLED,
     CFG_SERVER_EXTOPTS_FFMPEGTHUMBNAILER_CACHE_DIR,
@@ -197,6 +196,7 @@ enum config_option_t {
 #endif
     CFG_CLIENTS_LIST,
     CFG_CLIENTS_LIST_ENABLED,
+    CFG_CLIENTS_CACHE_THRESHOLD,
     CFG_IMPORT_LAYOUT_PARENT_PATH,
     CFG_IMPORT_LAYOUT_MAPPING,
     CFG_IMPORT_LIBOPTS_ENTRY_SEP,
@@ -235,7 +235,6 @@ enum config_option_t {
     CFG_UPNP_PLAYLIST_NAMESPACES,
     CFG_UPNP_TITLE_NAMESPACES,
     CFG_UPNP_CAPTION_COUNT,
-    CFG_THREAD_SCOPE_SYSTEM,
     CFG_IMPORT_READABLE_NAMES,
     CFG_SERVER_DYNAMIC_CONTENT_LIST_ENABLED,
     CFG_SERVER_DYNAMIC_CONTENT_LIST,
@@ -270,6 +269,7 @@ enum config_option_t {
     ATTR_IMPORT_LIBOPTS_AUXDATA_KEY,
     ATTR_IMPORT_LIBOPTS_AUXDATA_TAG,
     ATTR_TRANSCODING_MIMETYPE_PROF_MAP,
+    ATTR_TRANSCODING_MIMETYPE_FILTER,
     ATTR_TRANSCODING_MIMETYPE_PROF_MAP_TRANSCODE,
     ATTR_TRANSCODING_MIMETYPE_PROF_MAP_MIMETYPE,
     ATTR_TRANSCODING_MIMETYPE_PROF_MAP_USING,
@@ -284,7 +284,8 @@ enum config_option_t {
     ATTR_TRANSCODING_PROFILES_PROFLE_AVI4CC_MODE,
     ATTR_TRANSCODING_PROFILES_PROFLE_AVI4CC_4CC,
     ATTR_TRANSCODING_PROFILES_PROFLE_ACCURL,
-    ATTR_TRANSCODING_PROFILES_PROFLE_DLNA,
+    ATTR_TRANSCODING_PROFILES_PROFLE_DLNAPROF,
+    ATTR_TRANSCODING_PROFILES_PROFLE_SRCDLNA,
     ATTR_TRANSCODING_PROFILES_PROFLE_SAMPFREQ,
     ATTR_TRANSCODING_PROFILES_PROFLE_NRCHAN,
     ATTR_TRANSCODING_PROFILES_PROFLE_HIDEORIG,
@@ -307,6 +308,7 @@ enum config_option_t {
     ATTR_AUTOSCAN_DIRECTORY_MODE,
     ATTR_AUTOSCAN_DIRECTORY_INTERVAL,
     ATTR_AUTOSCAN_DIRECTORY_RECURSIVE,
+    ATTR_AUTOSCAN_DIRECTORY_MEDIATYPE,
     ATTR_AUTOSCAN_DIRECTORY_HIDDENFILES,
     ATTR_AUTOSCAN_DIRECTORY_SCANCOUNT,
     ATTR_AUTOSCAN_DIRECTORY_TASKCOUNT,
@@ -314,6 +316,7 @@ enum config_option_t {
     ATTR_CLIENTS_CLIENT,
     ATTR_CLIENTS_CLIENT_FLAGS,
     ATTR_CLIENTS_CLIENT_IP,
+    ATTR_CLIENTS_CLIENT_GROUP,
     ATTR_CLIENTS_CLIENT_USERAGENT,
     ATTR_DIRECTORIES_TWEAK,
     ATTR_DIRECTORIES_TWEAK_LOCATION,
@@ -378,13 +381,17 @@ public:
     /// \param option option to retrieve.
     virtual std::map<std::string, std::string> getDictionaryOption(config_option_t option) const = 0;
 
+    /// \brief returns a config option of type vector
+    /// \param option option to retrieve.
+    virtual std::vector<std::vector<std::pair<std::string, std::string>>> getVectorOption(config_option_t option) const = 0;
+
     /// \brief returns a config option of type array of string
     /// \param option option to retrieve.
     virtual std::vector<std::string> getArrayOption(config_option_t option) const = 0;
 
     /// \brief returns a config option of type AutoscanList
     /// \param option to retrieve
-    virtual std::shared_ptr<AutoscanList> getAutoscanListOption(config_option_t option) const = 0;
+    virtual std::vector<AutoscanDirectory> getAutoscanListOption(config_option_t option) const = 0;
 
     /// \brief returns a config option of type ClientConfigList
     /// \param option to retrieve
