@@ -104,11 +104,10 @@
 #endif
 
 #if defined(HAVE_FFMPEG) && defined(HAVE_FFMPEGTHUMBNAILER)
-#define DEFAULT_FFMPEGTHUMBNAILER_ENABLED NO
-#define DEFAULT_FFMPEGTHUMBNAILER_THUMBSIZE 128
+#define DEFAULT_FFMPEGTHUMBNAILER_ENABLED YES
+#define DEFAULT_FFMPEGTHUMBNAILER_THUMBSIZE 160
 #define DEFAULT_FFMPEGTHUMBNAILER_SEEK_PERCENTAGE 5
-#define DEFAULT_FFMPEGTHUMBNAILER_FILMSTRIP_OVERLAY YES
-#define DEFAULT_FFMPEGTHUMBNAILER_WORKAROUND_BUGS NO
+#define DEFAULT_FFMPEGTHUMBNAILER_FILMSTRIP_OVERLAY NO
 #define DEFAULT_FFMPEGTHUMBNAILER_IMAGE_QUALITY 8
 #define DEFAULT_FFMPEGTHUMBNAILER_CACHE_DIR_ENABLED YES
 #define DEFAULT_FFMPEGTHUMBNAILER_CACHE_DIR ""
@@ -212,21 +211,21 @@ static const std::map<std::string, std::string> mtCtDefaults {
 };
 
 /// \brief default values for CFG_IMPORT_MAPPINGS_CONTENTTYPE_TO_DLNAPROFILE_LIST
-static const std::map<std::string, std::string> ctDlnaDefaults {
-    { CONTENT_TYPE_ASF, "VC_ASF_AP_L2_WMA" },
-    { CONTENT_TYPE_AVI, "AVI" },
-    { CONTENT_TYPE_DSD, "DSF" },
-    { CONTENT_TYPE_FLAC, "FLAC" },
-    { CONTENT_TYPE_JPG, "JPEG_LRG" },
-    { CONTENT_TYPE_MKA, "MKV" },
-    { CONTENT_TYPE_MKV, "MKV" },
-    { CONTENT_TYPE_MP3, "MP3" },
-    { CONTENT_TYPE_MP4, "AVC_MP4_EU" },
-    { CONTENT_TYPE_MPEG, "MPEG_PS_PAL" },
-    { CONTENT_TYPE_OGG, "OGG" },
-    { CONTENT_TYPE_PCM, "LPCM" },
-    { CONTENT_TYPE_PNG, "PNG_LRG" },
-    { CONTENT_TYPE_WMA, "WMAFULL" },
+static const std::vector<std::vector<std::pair<std::string, std::string>>> ctDlnaDefaults {
+    { { "from", CONTENT_TYPE_ASF }, { "to", "VC_ASF_AP_L2_WMA" } },
+    { { "from", CONTENT_TYPE_AVI }, { "to", "AVI" } },
+    { { "from", CONTENT_TYPE_DSD }, { "to", "DSF" } },
+    { { "from", CONTENT_TYPE_FLAC }, { "to", "FLAC" } },
+    { { "from", CONTENT_TYPE_JPG }, { "to", "JPEG_LRG" } },
+    { { "from", CONTENT_TYPE_MKA }, { "to", "MKV" } },
+    { { "from", CONTENT_TYPE_MKV }, { "to", "MKV" } },
+    { { "from", CONTENT_TYPE_MP3 }, { "to", "MP3" } },
+    { { "from", CONTENT_TYPE_MP4 }, { "to", "AVC_MP4_EU" } },
+    { { "from", CONTENT_TYPE_MPEG }, { "to", "MPEG_PS_PAL" } },
+    { { "from", CONTENT_TYPE_OGG }, { "to", "OGG" } },
+    { { "from", CONTENT_TYPE_PCM }, { "to", "LPCM" } },
+    { { "from", CONTENT_TYPE_PNG }, { "to", "PNG_LRG" } },
+    { { "from", CONTENT_TYPE_WMA }, { "to", "WMAFULL" } },
 };
 
 /// \brief default values for CFG_IMPORT_MAPPINGS_MIMETYPE_TO_UPNP_CLASS_LIST
@@ -524,24 +523,26 @@ const std::vector<std::shared_ptr<ConfigSetup>> ConfigDefinition::complexOptions
         "/server/ui/attribute::show-tooltips", "config-server.html#ui",
         DEFAULT_UI_SHOW_TOOLTIPS_VALUE),
 
-    std::make_shared<ConfigBoolSetup>(CFG_THREAD_SCOPE_SYSTEM,
-        "/server/attribute::system-threads", "config-server.html#system-threads",
-        YES),
-
     std::make_shared<ConfigClientSetup>(CFG_CLIENTS_LIST,
         "/clients", "config-clients.html#clients"),
     std::make_shared<ConfigBoolSetup>(CFG_CLIENTS_LIST_ENABLED,
         "/clients/attribute::enabled", "config-clients.html#clients",
         DEFAULT_CLIENTS_EN_VALUE),
+    std::make_shared<ConfigIntSetup>(CFG_CLIENTS_CACHE_THRESHOLD,
+        "/clients/attribute::cache-threshold", "config-clients.html#clients",
+        6, 1, ConfigIntSetup::CheckMinValue),
     std::make_shared<ConfigStringSetup>(ATTR_CLIENTS_CLIENT,
         "/clients/client", "config-clients.html#clients",
         ""),
-    std::make_shared<ConfigStringSetup>(ATTR_CLIENTS_CLIENT_FLAGS,
+    std::make_shared<ConfigIntSetup>(ATTR_CLIENTS_CLIENT_FLAGS,
         "flags", "config-clients.html#client",
-        true),
+        0, ClientConfig::makeFlags),
     std::make_shared<ConfigStringSetup>(ATTR_CLIENTS_CLIENT_IP,
         "ip", "config-clients.html#client",
         ""),
+    std::make_shared<ConfigStringSetup>(ATTR_CLIENTS_CLIENT_GROUP,
+        "group", "config-clients.html#client",
+        DEFAULT_CLIENT_GROUP),
     std::make_shared<ConfigStringSetup>(ATTR_CLIENTS_CLIENT_USERAGENT,
         "userAgent", "config-clients.html#client",
         ""),
@@ -577,9 +578,9 @@ const std::vector<std::shared_ptr<ConfigSetup>> ConfigDefinition::complexOptions
         "/import/mappings/mimetype-contenttype", "config-import.html#mimetype-contenttype",
         ATTR_IMPORT_MAPPINGS_M2CTYPE_LIST_TREAT, ATTR_IMPORT_MAPPINGS_M2CTYPE_LIST_MIMETYPE, ATTR_IMPORT_MAPPINGS_M2CTYPE_LIST_AS,
         false, false, true, mtCtDefaults),
-    std::make_shared<ConfigDictionarySetup>(CFG_IMPORT_MAPPINGS_CONTENTTYPE_TO_DLNAPROFILE_LIST,
+    std::make_shared<ConfigVectorSetup>(CFG_IMPORT_MAPPINGS_CONTENTTYPE_TO_DLNAPROFILE_LIST,
         "/import/mappings/contenttype-dlnaprofile", "config-import.html#contenttype-dlnaprofile",
-        ATTR_IMPORT_MAPPINGS_MIMETYPE_MAP, ATTR_IMPORT_MAPPINGS_MIMETYPE_FROM, ATTR_IMPORT_MAPPINGS_MIMETYPE_TO,
+        ATTR_IMPORT_MAPPINGS_MIMETYPE_MAP, std::vector<config_option_t> { ATTR_IMPORT_MAPPINGS_MIMETYPE_FROM, ATTR_IMPORT_MAPPINGS_MIMETYPE_TO },
         false, false, true, ctDlnaDefaults),
     std::make_shared<ConfigArraySetup>(CFG_IMPORT_MAPPINGS_IGNORED_EXTENSIONS,
         "/import/mappings/ignore-extensions", "config-import.html#ignore-extensions",
@@ -720,7 +721,8 @@ const std::vector<std::shared_ptr<ConfigSetup>> ConfigDefinition::complexOptions
 
     std::make_shared<ConfigArraySetup>(CFG_IMPORT_RESOURCES_ORDER,
         "/import/resources/order", "config-import.html#resources-order",
-        ATTR_IMPORT_RESOURCES_HANDLER, ATTR_IMPORT_RESOURCES_NAME),
+        ATTR_IMPORT_RESOURCES_HANDLER, ATTR_IMPORT_RESOURCES_NAME,
+        MetadataHandler::checkContentHandler),
 
     std::make_shared<ConfigArraySetup>(CFG_IMPORT_SYSTEM_DIRECTORIES,
         "/import/system-directories", "config-import.html#system-directories",
@@ -728,7 +730,7 @@ const std::vector<std::shared_ptr<ConfigSetup>> ConfigDefinition::complexOptions
         excludesFullpath),
     std::make_shared<ConfigArraySetup>(CFG_IMPORT_VISIBLE_DIRECTORIES,
         "/import/visible-directories", "config-import.html#visible-directories",
-        ATTR_IMPORT_SYSTEM_DIR_ADD_PATH, ATTR_IMPORT_RESOURCES_NAME),
+        ATTR_IMPORT_SYSTEM_DIR_ADD_PATH, ATTR_IMPORT_RESOURCES_NAME, false, false),
 
 #if defined(HAVE_FFMPEG) && defined(HAVE_FFMPEGTHUMBNAILER)
     std::make_shared<ConfigBoolSetup>(CFG_SERVER_EXTOPTS_FFMPEGTHUMBNAILER_ENABLED,
@@ -749,9 +751,6 @@ const std::vector<std::shared_ptr<ConfigSetup>> ConfigDefinition::complexOptions
     std::make_shared<ConfigBoolSetup>(CFG_SERVER_EXTOPTS_FFMPEGTHUMBNAILER_FILMSTRIP_OVERLAY,
         "/server/extended-runtime-options/ffmpegthumbnailer/filmstrip-overlay", "config-extended.html#ffmpegthumbnailer",
         DEFAULT_FFMPEGTHUMBNAILER_FILMSTRIP_OVERLAY),
-    std::make_shared<ConfigBoolSetup>(CFG_SERVER_EXTOPTS_FFMPEGTHUMBNAILER_WORKAROUND_BUGS,
-        "/server/extended-runtime-options/ffmpegthumbnailer/workaround-bugs", "config-extended.html#ffmpegthumbnailer",
-        DEFAULT_FFMPEGTHUMBNAILER_WORKAROUND_BUGS),
     std::make_shared<ConfigIntSetup>(CFG_SERVER_EXTOPTS_FFMPEGTHUMBNAILER_IMAGE_QUALITY,
         "/server/extended-runtime-options/ffmpegthumbnailer/image-quality", "config-extended.html#ffmpegthumbnailer",
         DEFAULT_FFMPEGTHUMBNAILER_IMAGE_QUALITY, ConfigIntSetup::CheckImageQualityValue),
@@ -814,26 +813,29 @@ const std::vector<std::shared_ptr<ConfigSetup>> ConfigDefinition::complexOptions
         "auto", StringCheckFunction(ConfigBoolSetup::CheckInotifyValue)),
     std::make_shared<ConfigAutoscanSetup>(CFG_IMPORT_AUTOSCAN_INOTIFY_LIST,
         "/import/autoscan", "config-import.html#autoscan",
-        ScanMode::INotify),
+        AutoscanDirectory::ScanMode::INotify),
 #endif
     std::make_shared<ConfigSetup>(ATTR_AUTOSCAN_DIRECTORY,
         "directory", "config-import.html#autoscan",
         ""),
     std::make_shared<ConfigAutoscanSetup>(CFG_IMPORT_AUTOSCAN_TIMED_LIST,
         "/import/autoscan", "config-import.html#autoscan",
-        ScanMode::Timed),
+        AutoscanDirectory::ScanMode::Timed),
     std::make_shared<ConfigPathSetup>(ATTR_AUTOSCAN_DIRECTORY_LOCATION,
         "attribute::location", "config-import.html#autoscan",
         "", false, true, true),
-    std::make_shared<ConfigEnumSetup<ScanMode>>(ATTR_AUTOSCAN_DIRECTORY_MODE,
+    std::make_shared<ConfigEnumSetup<AutoscanDirectory::ScanMode>>(ATTR_AUTOSCAN_DIRECTORY_MODE,
         "attribute::mode", "config-import.html#autoscan",
-        std::map<std::string, ScanMode>({ { "timed", ScanMode::Timed }, { "inotify", ScanMode::INotify } })),
+        std::map<std::string, AutoscanDirectory::ScanMode>({ { "timed", AutoscanDirectory::ScanMode::Timed }, { "inotify", AutoscanDirectory::ScanMode::INotify } })),
     std::make_shared<ConfigIntSetup>(ATTR_AUTOSCAN_DIRECTORY_INTERVAL,
         "attribute::interval", "config-import.html#autoscan",
         -1, 0, ConfigIntSetup::CheckMinValue),
     std::make_shared<ConfigBoolSetup>(ATTR_AUTOSCAN_DIRECTORY_RECURSIVE,
         "attribute::recursive", "config-import.html#autoscan",
         false, true),
+    std::make_shared<ConfigIntSetup>(ATTR_AUTOSCAN_DIRECTORY_MEDIATYPE,
+        "attribute::media-type", "config-import.html#autoscan",
+        to_underlying(AutoscanDirectory::MediaType::Any), AutoscanDirectory::makeMediaType),
     std::make_shared<ConfigBoolSetup>(ATTR_AUTOSCAN_DIRECTORY_HIDDENFILES,
         "attribute::hidden-files", "config-import.html#autoscan"),
     std::make_shared<ConfigIntSetup>(ATTR_AUTOSCAN_DIRECTORY_SCANCOUNT,
@@ -854,7 +856,7 @@ const std::vector<std::shared_ptr<ConfigSetup>> ConfigDefinition::complexOptions
 #ifdef HAVE_LIBEXIF
     std::make_shared<ConfigArraySetup>(CFG_IMPORT_LIBOPTS_EXIF_AUXDATA_TAGS_LIST,
         "/import/library-options/libexif/auxdata", "config-import.html#libexif",
-        ATTR_IMPORT_LIBOPTS_AUXDATA_DATA, ATTR_IMPORT_LIBOPTS_AUXDATA_TAG),
+        ATTR_IMPORT_LIBOPTS_AUXDATA_DATA, ATTR_IMPORT_LIBOPTS_AUXDATA_TAG, false, false),
     std::make_shared<ConfigDictionarySetup>(CFG_IMPORT_LIBOPTS_EXIF_METADATA_TAGS_LIST,
         "/import/library-options/libexif/metadata", "config-import.html#libexif",
         ATTR_IMPORT_LIBOPTS_AUXDATA_DATA, ATTR_IMPORT_LIBOPTS_AUXDATA_TAG, ATTR_IMPORT_LIBOPTS_AUXDATA_KEY,
@@ -866,7 +868,7 @@ const std::vector<std::shared_ptr<ConfigSetup>> ConfigDefinition::complexOptions
 #ifdef HAVE_EXIV2
     std::make_shared<ConfigArraySetup>(CFG_IMPORT_LIBOPTS_EXIV2_AUXDATA_TAGS_LIST,
         "/import/library-options/exiv2/auxdata", "config-import.html#exiv2",
-        ATTR_IMPORT_LIBOPTS_AUXDATA_DATA, ATTR_IMPORT_LIBOPTS_AUXDATA_TAG),
+        ATTR_IMPORT_LIBOPTS_AUXDATA_DATA, ATTR_IMPORT_LIBOPTS_AUXDATA_TAG, false, false),
     std::make_shared<ConfigDictionarySetup>(CFG_IMPORT_LIBOPTS_EXIV2_METADATA_TAGS_LIST,
         "/import/library-options/exiv2/metadata", "config-import.html#exiv2",
         ATTR_IMPORT_LIBOPTS_AUXDATA_DATA, ATTR_IMPORT_LIBOPTS_AUXDATA_TAG, ATTR_IMPORT_LIBOPTS_AUXDATA_KEY,
@@ -878,7 +880,7 @@ const std::vector<std::shared_ptr<ConfigSetup>> ConfigDefinition::complexOptions
 #ifdef HAVE_TAGLIB
     std::make_shared<ConfigArraySetup>(CFG_IMPORT_LIBOPTS_ID3_AUXDATA_TAGS_LIST,
         "/import/library-options/id3/auxdata", "config-import.html#id3",
-        ATTR_IMPORT_LIBOPTS_AUXDATA_DATA, ATTR_IMPORT_LIBOPTS_AUXDATA_TAG),
+        ATTR_IMPORT_LIBOPTS_AUXDATA_DATA, ATTR_IMPORT_LIBOPTS_AUXDATA_TAG, false, false),
     std::make_shared<ConfigDictionarySetup>(CFG_IMPORT_LIBOPTS_ID3_METADATA_TAGS_LIST,
         "/import/library-options/id3/metadata", "config-import.html#id3",
         ATTR_IMPORT_LIBOPTS_AUXDATA_DATA, ATTR_IMPORT_LIBOPTS_AUXDATA_TAG, ATTR_IMPORT_LIBOPTS_AUXDATA_KEY,
@@ -890,7 +892,7 @@ const std::vector<std::shared_ptr<ConfigSetup>> ConfigDefinition::complexOptions
 #ifdef HAVE_FFMPEG
     std::make_shared<ConfigArraySetup>(CFG_IMPORT_LIBOPTS_FFMPEG_AUXDATA_TAGS_LIST,
         "/import/library-options/ffmpeg/auxdata", "config-import.html#ffmpeg",
-        ATTR_IMPORT_LIBOPTS_AUXDATA_DATA, ATTR_IMPORT_LIBOPTS_AUXDATA_TAG),
+        ATTR_IMPORT_LIBOPTS_AUXDATA_DATA, ATTR_IMPORT_LIBOPTS_AUXDATA_TAG, false, false),
     std::make_shared<ConfigDictionarySetup>(CFG_IMPORT_LIBOPTS_FFMPEG_METADATA_TAGS_LIST,
         "/import/library-options/ffmpeg/metadata", "config-import.html#ffmpeg",
         ATTR_IMPORT_LIBOPTS_AUXDATA_DATA, ATTR_IMPORT_LIBOPTS_AUXDATA_TAG, ATTR_IMPORT_LIBOPTS_AUXDATA_KEY,
@@ -923,12 +925,15 @@ const std::vector<std::shared_ptr<ConfigSetup>> ConfigDefinition::complexOptions
     std::make_shared<ConfigStringSetup>(ATTR_TRANSCODING_PROFILES_PROFLE_AVI4CC_4CC,
         "fourcc", "config-transcode.html#profiles",
         ""),
-    std::make_shared<ConfigStringSetup>(ATTR_TRANSCODING_PROFILES_PROFLE_CLIENTFLAGS,
+    std::make_shared<ConfigIntSetup>(ATTR_TRANSCODING_PROFILES_PROFLE_CLIENTFLAGS,
         "attribute::client-flags", "config-transcode.html#profiles",
-        ""),
-    std::make_shared<ConfigStringSetup>(ATTR_TRANSCODING_PROFILES_PROFLE_DLNA,
+        0, ClientConfig::makeFlags),
+    std::make_shared<ConfigStringSetup>(ATTR_TRANSCODING_PROFILES_PROFLE_DLNAPROF,
         "attribute::dlna-profile", "config-transcode.html#profiles",
         ""),
+    std::make_shared<ConfigStringSetup>(ATTR_TRANSCODING_PROFILES_PROFLE_SRCDLNA,
+        "attribute::source-profile", "config-transcode.html#profiles",
+        ""),
     std::make_shared<ConfigBoolSetup>(ATTR_TRANSCODING_PROFILES_PROFLE_ENABLED,
         "attribute::enabled", "config-transcode.html#profiles"),
     std::make_shared<ConfigBoolSetup>(ATTR_TRANSCODING_PROFILES_PROFLE_ACCURL,
@@ -963,8 +968,11 @@ const std::vector<std::shared_ptr<ConfigSetup>> ConfigDefinition::complexOptions
         "/transcoding/mimetype-profile-mappings", "config-transcode.html#profiles",
         ATTR_TRANSCODING_MIMETYPE_PROF_MAP_TRANSCODE, ATTR_TRANSCODING_MIMETYPE_PROF_MAP_MIMETYPE, ATTR_TRANSCODING_MIMETYPE_PROF_MAP_USING,
         false, false, false, trMtDefaults),
+    std::make_shared<ConfigSetup>(ATTR_TRANSCODING_MIMETYPE_FILTER,
+        "/transcoding/mimetype-profile-mappings/transcode", "config-transcode.html#profiles",
+        ""),
     std::make_shared<ConfigSetup>(ATTR_TRANSCODING_PROFILES_PROFLE,
-        "/transcoding/profiles/profile", "config-server.html#ui",
+        "/transcoding/profiles/profile", "config-transcode.html#profiles",
         ""),
     std::make_shared<ConfigStringSetup>(ATTR_TRANSCODING_PROFILES_PROFLE_NAME,
         "attribute::name", "config-transcode.html#profiles",
@@ -972,9 +980,9 @@ const std::vector<std::shared_ptr<ConfigSetup>> ConfigDefinition::complexOptions
     std::make_shared<ConfigStringSetup>(ATTR_TRANSCODING_PROFILES_PROFLE_MIMETYPE,
         "mimetype", "config-transcode.html#profiles",
         true, "", true),
-    std::make_shared<ConfigStringSetup>(ATTR_TRANSCODING_PROFILES_PROFLE_AGENT_COMMAND,
+    std::make_shared<ConfigPathSetup>(ATTR_TRANSCODING_PROFILES_PROFLE_AGENT_COMMAND,
         "attribute::command", "config-transcode.html#profiles",
-        "", ConfigPathSetup::checkAgentPath, true, true),
+        "", true, true, true, true),
     std::make_shared<ConfigStringSetup>(ATTR_TRANSCODING_PROFILES_PROFLE_AGENT_ARGS,
         "attribute::arguments", "config-transcode.html#profiles",
         true, "", true),
@@ -1238,6 +1246,11 @@ const std::map<config_option_t, std::vector<config_option_t>> ConfigDefinition::
     { ATTR_AUTOSCAN_DIRECTORY_RECURSIVE, { CFG_IMPORT_AUTOSCAN_TIMED_LIST,
 #ifdef HAVE_INOTIFY
                                              CFG_IMPORT_AUTOSCAN_INOTIFY_LIST
+#endif
+                                         } },
+    { ATTR_AUTOSCAN_DIRECTORY_MEDIATYPE, { CFG_IMPORT_AUTOSCAN_TIMED_LIST,
+#ifdef HAVE_INOTIFY
+                                             CFG_IMPORT_AUTOSCAN_INOTIFY_LIST
 #endif
                                          } },
     { ATTR_AUTOSCAN_DIRECTORY_HIDDENFILES, { CFG_IMPORT_AUTOSCAN_TIMED_LIST,
@@ -1329,7 +1342,6 @@ const std::map<config_option_t, config_option_t> ConfigDefinition::dependencyMap
     { CFG_SERVER_EXTOPTS_FFMPEGTHUMBNAILER_THUMBSIZE, CFG_SERVER_EXTOPTS_FFMPEGTHUMBNAILER_ENABLED },
     { CFG_SERVER_EXTOPTS_FFMPEGTHUMBNAILER_SEEK_PERCENTAGE, CFG_SERVER_EXTOPTS_FFMPEGTHUMBNAILER_ENABLED },
     { CFG_SERVER_EXTOPTS_FFMPEGTHUMBNAILER_FILMSTRIP_OVERLAY, CFG_SERVER_EXTOPTS_FFMPEGTHUMBNAILER_ENABLED },
-    { CFG_SERVER_EXTOPTS_FFMPEGTHUMBNAILER_WORKAROUND_BUGS, CFG_SERVER_EXTOPTS_FFMPEGTHUMBNAILER_ENABLED },
     { CFG_SERVER_EXTOPTS_FFMPEGTHUMBNAILER_IMAGE_QUALITY, CFG_SERVER_EXTOPTS_FFMPEGTHUMBNAILER_ENABLED },
     { CFG_SERVER_EXTOPTS_FFMPEGTHUMBNAILER_CACHE_DIR_ENABLED, CFG_SERVER_EXTOPTS_FFMPEGTHUMBNAILER_ENABLED },
     { CFG_SERVER_EXTOPTS_FFMPEGTHUMBNAILER_CACHE_DIR, CFG_SERVER_EXTOPTS_FFMPEGTHUMBNAILER_ENABLED },
