@@ -391,7 +391,6 @@ void ConfigManager::load(const fs::path& userHome)
         setOption(root, CFG_SERVER_EXTOPTS_FFMPEGTHUMBNAILER_THUMBSIZE);
         setOption(root, CFG_SERVER_EXTOPTS_FFMPEGTHUMBNAILER_SEEK_PERCENTAGE);
         setOption(root, CFG_SERVER_EXTOPTS_FFMPEGTHUMBNAILER_FILMSTRIP_OVERLAY);
-        setOption(root, CFG_SERVER_EXTOPTS_FFMPEGTHUMBNAILER_WORKAROUND_BUGS);
         setOption(root, CFG_SERVER_EXTOPTS_FFMPEGTHUMBNAILER_IMAGE_QUALITY);
         setOption(root, CFG_SERVER_EXTOPTS_FFMPEGTHUMBNAILER_CACHE_DIR_ENABLED);
         setOption(root, CFG_SERVER_EXTOPTS_FFMPEGTHUMBNAILER_CACHE_DIR);
@@ -424,11 +423,9 @@ void ConfigManager::load(const fs::path& userHome)
     auto configTimedList = getAutoscanListOption(CFG_IMPORT_AUTOSCAN_TIMED_LIST);
     auto configInotifyList = getAutoscanListOption(CFG_IMPORT_AUTOSCAN_INOTIFY_LIST);
 
-    for (std::size_t i = 0; i < configInotifyList->size(); i++) {
-        auto iDir = configInotifyList->get(i);
-        for (std::size_t j = 0; j < configTimedList->size(); j++) {
-            auto tDir = configTimedList->get(j);
-            if (iDir->getLocation() == tDir->getLocation())
+    for (const auto& iDir : configInotifyList) {
+        for (const auto& tDir : configTimedList) {
+            if (iDir.getLocation() == tDir.getLocation())
                 throw_std_runtime_error("Error in config file: same path used in both inotify and timed scan modes");
         }
     }
@@ -550,6 +547,15 @@ std::map<std::string, std::string> ConfigManager::getDictionaryOption(config_opt
     return optionValue->getDictionaryOption();
 }
 
+std::vector<std::vector<std::pair<std::string, std::string>>> ConfigManager::getVectorOption(config_option_t option) const
+{
+    auto optionValue = options.at(option);
+    if (!optionValue) {
+        throw_std_runtime_error("option {} not set", option);
+    }
+    return optionValue->getVectorOption();
+}
+
 std::vector<std::string> ConfigManager::getArrayOption(config_option_t option) const
 {
     auto optionValue = options.at(option);
@@ -559,7 +565,7 @@ std::vector<std::string> ConfigManager::getArrayOption(config_option_t option) c
     return optionValue->getArrayOption();
 }
 
-std::shared_ptr<AutoscanList> ConfigManager::getAutoscanListOption(config_option_t option) const
+std::vector<AutoscanDirectory> ConfigManager::getAutoscanListOption(config_option_t option) const
 {
     auto optionValue = options.at(option);
     if (!optionValue) {
