@@ -53,7 +53,6 @@ class DirectoryConfigList;
 class DynamicContentList;
 class TranscodingProfileList;
 enum class ClientType;
-enum class ScanMode;
 
 class ConfigManager : public Config, public std::enable_shared_from_this<Config> {
 public:
@@ -90,13 +89,17 @@ public:
     /// \param option option to retrieve.
     std::map<std::string, std::string> getDictionaryOption(config_option_t option) const override;
 
+    /// \brief returns a config option of type vector
+    /// \param option option to retrieve.
+    std::vector<std::vector<std::pair<std::string, std::string>>> getVectorOption(config_option_t option) const override;
+
     /// \brief returns a config option of type array of string
     /// \param option option to retrieve.
     std::vector<std::string> getArrayOption(config_option_t option) const override;
 
     /// \brief returns a config option of type AutoscanList
     /// \param option to retrieve
-    std::shared_ptr<AutoscanList> getAutoscanListOption(config_option_t option) const override;
+    std::vector<AutoscanDirectory> getAutoscanListOption(config_option_t option) const override;
 
     /// \brief returns a config option of type ClientConfigList
     /// \param option to retrieve
