@@ -40,7 +40,6 @@
 class ConfigOption;
 class DirectoryTweak;
 class DynamicContent;
-enum class ScanMode;
 
 #define ITEM_PATH_ROOT (-1)
 #define ITEM_PATH_NEW (-2)
@@ -48,8 +47,10 @@ enum class ScanMode;
 
 using StringCheckFunction = std::function<bool(std::string& value)>;
 using ArrayInitFunction = std::function<bool(const pugi::xml_node& value, std::vector<std::string>& result, const char* node_name)>;
+using ArrayItemCheckFunction = std::function<bool(const std::string& value)>;
 using DictionaryInitFunction = std::function<bool(const pugi::xml_node& value, std::map<std::string, std::string>& result)>;
 using IntCheckFunction = std::function<bool(int value)>;
+using IntParseFunction = std::function<int(const std::string& value)>;
 using IntMinFunction = std::function<bool(int value, int minValue)>;
 
 using ConfigOptionIterator = EnumIterator<config_option_t, config_option_t::CFG_MIN, config_option_t::CFG_MAX>;
@@ -126,9 +127,9 @@ public:
     {
     }
 
-    void setDefaultValue(const std::string& defaultValue)
+    void setDefaultValue(std::string defaultValue)
     {
-        this->defaultValue.assign(defaultValue);
+        this->defaultValue = std::move(defaultValue);
     }
     std::string getDefaultValue() const
     {
@@ -270,6 +271,7 @@ protected:
     bool isFile = false;
     bool mustExist = false;
     bool notEmpty = false;
+    bool isExe = false;
     bool resolveEmpty = true;
 
     /// \brief resolve path against home, an exception is raised if path does not exist on filesystem.
@@ -279,15 +281,17 @@ protected:
     fs::path resolvePath(fs::path path) const;
 
     void loadArguments(const std::map<std::string, std::string>* arguments = nullptr);
+    bool checkExecutable(std::string& optValue) const;
 
 public:
     static fs::path Home;
 
-    ConfigPathSetup(config_option_t option, const char* xpath, const char* help, const char* defaultValue = "", bool isFile = false, bool mustExist = true, bool notEmpty = false)
+    ConfigPathSetup(config_option_t option, const char* xpath, const char* help, const char* defaultValue = "", bool isFile = false, bool mustExist = true, bool notEmpty = false, bool isExe = false)
         : ConfigSetup(option, xpath, help, false, defaultValue)
         , isFile(isFile)
         , mustExist(mustExist)
         , notEmpty(notEmpty)
+        , isExe(isExe)
     {
     }
 
@@ -298,15 +302,17 @@ public:
     void makeOption(std::string optValue, const std::shared_ptr<Config>& config, const std::map<std::string, std::string>* arguments = nullptr) override;
 
     std::shared_ptr<ConfigOption> newOption(std::string& optValue);
+    std::string getXmlContent(const pugi::xml_node& root);
 
     bool checkPathValue(std::string& optValue, std::string& pathValue) const;
 
-    static bool checkAgentPath(std::string& optValue);
+    void setMustExist(bool mustExist) { this->mustExist = mustExist; }
 };
 
 class ConfigIntSetup : public ConfigSetup {
 protected:
     IntCheckFunction valueCheck = nullptr;
+    IntParseFunction parseValue = nullptr;
     IntMinFunction minCheck = nullptr;
     int minValue {};
 
@@ -333,6 +339,14 @@ public:
         this->defaultValue = fmt::to_string(0);
     }
 
+    ConfigIntSetup(config_option_t option, const char* xpath, const char* help, int defaultValue, IntParseFunction parseValue)
+        : ConfigSetup(option, xpath, help)
+        , parseValue(std::move(parseValue))
+
+    {
+        this->defaultValue = fmt::to_string(defaultValue);
+    }
+
     ConfigIntSetup(config_option_t option, const char* xpath, const char* help, int defaultValue, IntCheckFunction check)
         : ConfigSetup(option, xpath, help)
         , valueCheck(std::move(check))
@@ -363,7 +377,7 @@ public:
     {
     }
 
-    std::string getTypeString() const override { return "Number"; }
+    std::string getTypeString() const override { return parseValue ? "String" : "Number"; }
 
     void makeOption(const pugi::xml_node& root, const std::shared_ptr<Config>& config, const std::map<std::string, std::string>* arguments = nullptr) override;
 
@@ -437,6 +451,7 @@ protected:
     bool notEmpty = false;
     bool itemNotEmpty = false;
     ArrayInitFunction initArray = nullptr;
+    ArrayItemCheckFunction itemCheck = nullptr;
     std::vector<std::string> defaultEntries;
 
     /// \brief Creates an array of strings from an XML nodeset.
@@ -471,7 +486,7 @@ public:
     }
 
     ConfigArraySetup(config_option_t option, const char* xpath, const char* help, config_option_t nodeOption, config_option_t attrOption,
-        bool notEmpty = false, bool itemNotEmpty = false, std::vector<std::string> defaultEntries = {})
+        bool notEmpty, bool itemNotEmpty, std::vector<std::string> defaultEntries = {})
         : ConfigSetup(option, xpath, help)
         , notEmpty(notEmpty)
         , itemNotEmpty(itemNotEmpty)
@@ -481,6 +496,16 @@ public:
     {
     }
 
+    ConfigArraySetup(config_option_t option, const char* xpath, const char* help, config_option_t nodeOption, config_option_t attrOption,
+        ArrayItemCheckFunction itemCheck, std::vector<std::string> defaultEntries = {})
+        : ConfigSetup(option, xpath, help)
+        , itemCheck(std::move(itemCheck))
+        , defaultEntries(std::move(defaultEntries))
+        , nodeOption(nodeOption)
+        , attrOption(attrOption)
+    {
+    }
+
     std::string getTypeString() const override { return "List"; }
 
     void makeOption(const pugi::xml_node& root, const std::shared_ptr<Config>& config, const std::map<std::string, std::string>* arguments = nullptr) override;
@@ -524,7 +549,7 @@ protected:
     /// </some-section>
     ///
     /// This function will create a dictionary with the following
-    /// key:value paris: "1":"2", "3":"4"
+    /// key:value pairs: "1":"2", "3":"4"
     bool createOptionFromNode(const pugi::xml_node& optValue, std::map<std::string, std::string>& result) const;
 
     bool updateItem(std::size_t i, const std::string& optItem, const std::shared_ptr<Config>& config, const std::shared_ptr<DictionaryOption>& value, const std::string& optKey, const std::string& optValue, const std::string& status = "") const;
@@ -572,20 +597,75 @@ public:
     std::string getCurrentValue() const override { return {}; }
 };
 
+class ConfigVectorSetup : public ConfigSetup {
+protected:
+    bool notEmpty = false;
+    bool itemNotEmpty = false;
+    bool tolower = false;
+    std::vector<std::vector<std::pair<std::string, std::string>>> defaultEntries;
+
+    /// \brief Creates a vector from an XML nodeset.
+    /// \param optValue starting element of the nodeset.
+    ///
+    /// The basic idea is the following:
+    /// You have a piece of XML that looks like this
+    /// <some-section>
+    ///    <map from="1" via="3" to="2"/>
+    ///    <map from="3" to="4"/>
+    /// </some-section>
+    ///
+    /// This function will create a vector with the following
+    /// list: { { "1", "3", "2" }, {"3", "", "4"}
+    bool createOptionFromNode(const pugi::xml_node& optValue, std::vector<std::vector<std::pair<std::string, std::string>>>& result) const;
+
+    bool updateItem(std::size_t i, const std::string& optItem, const std::shared_ptr<Config>& config, const std::shared_ptr<VectorOption>& value, const std::string& optValue, const std::string& status = "") const;
+
+public:
+    config_option_t nodeOption {};
+    std::vector<config_option_t> optionList {};
+
+    explicit ConfigVectorSetup(config_option_t option, const char* xpath, const char* help,
+        config_option_t nodeOption, std::vector<config_option_t> optionList,
+        bool notEmpty = false, bool itemNotEmpty = false, bool required = false, std::vector<std::vector<std::pair<std::string, std::string>>> defaultEntries = {})
+        : ConfigSetup(option, xpath, help, required && defaultEntries.empty())
+        , notEmpty(notEmpty)
+        , itemNotEmpty(itemNotEmpty)
+        , defaultEntries(std::move(defaultEntries))
+        , nodeOption(nodeOption)
+        , optionList(std::move(optionList))
+    {
+    }
+
+    std::string getTypeString() const override { return "List"; }
+
+    void makeOption(const pugi::xml_node& root, const std::shared_ptr<Config>& config, const std::map<std::string, std::string>* arguments = nullptr) override;
+
+    bool updateDetail(const std::string& optItem, std::string& optValue, const std::shared_ptr<Config>& config, const std::map<std::string, std::string>* arguments = nullptr) override;
+
+    std::string getItemPath(int index = 0, config_option_t propOption = CFG_MAX, config_option_t propOption2 = CFG_MAX, config_option_t propOption3 = CFG_MAX, config_option_t propOption4 = CFG_MAX) const override;
+    std::string getItemPath(int index, const std::string& propOption) const;
+
+    std::vector<std::vector<std::pair<std::string, std::string>>> getXmlContent(const pugi::xml_node& optValue);
+
+    std::shared_ptr<ConfigOption> newOption(const std::vector<std::vector<std::pair<std::string, std::string>>>& optValue);
+
+    std::string getCurrentValue() const override { return {}; }
+};
+
 class ConfigAutoscanSetup : public ConfigSetup {
 protected:
-    ScanMode scanMode;
+    AutoscanDirectory::ScanMode scanMode;
     bool hiddenFiles = false;
 
     /// \brief Creates an array of AutoscanDirectory objects from a XML nodeset.
     /// \param element starting element of the nodeset.
     /// \param scanmode add only directories with the specified scanmode to the array
-    bool createOptionFromNode(const pugi::xml_node& element, std::shared_ptr<AutoscanList>& result);
+    bool createOptionFromNode(const pugi::xml_node& element, std::vector<AutoscanDirectory>& result);
 
-    bool updateItem(std::size_t i, const std::string& optItem, const std::shared_ptr<Config>& config, const std::shared_ptr<AutoscanDirectory>& entry, std::string& optValue, const std::string& status = "") const;
+    bool updateItem(std::size_t i, const std::string& optItem, const std::shared_ptr<Config>& config, AutoscanDirectory& entry, std::string& optValue, const std::string& status = "") const;
 
 public:
-    ConfigAutoscanSetup(config_option_t option, const char* xpath, const char* help, ScanMode scanmode)
+    ConfigAutoscanSetup(config_option_t option, const char* xpath, const char* help, AutoscanDirectory::ScanMode scanmode)
         : ConfigSetup(option, xpath, help)
         , scanMode(scanmode)
     {
