@@ -4,7 +4,7 @@
 
     dynamic_content.cc - this file is part of Gerbera.
 
-    Copyright (C) 2021 Gerbera Contributors
+    Copyright (C) 2021-2022 Gerbera Contributors
 
     Gerbera is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
@@ -25,18 +25,15 @@
 
 #include "dynamic_content.h" // API
 
-#include "config/config.h"
 #include "content/content_manager.h"
-#include "util/upnp_clients.h"
-#include "util/upnp_quirks.h"
 
-void DynamicContentList::add(const std::shared_ptr<DynamicContent>& cont, size_t index)
+void DynamicContentList::add(const std::shared_ptr<DynamicContent>& cont, std::size_t index)
 {
     AutoLock lock(mutex);
     _add(cont, index);
 }
 
-void DynamicContentList::_add(const std::shared_ptr<DynamicContent>& cont, size_t index)
+void DynamicContentList::_add(const std::shared_ptr<DynamicContent>& cont, std::size_t index)
 {
     if (index == std::numeric_limits<std::size_t>::max()) {
         index = getEditSize();
@@ -51,21 +48,21 @@ void DynamicContentList::_add(const std::shared_ptr<DynamicContent>& cont, size_
     indexMap[index] = cont;
 }
 
-size_t DynamicContentList::getEditSize() const
+std::size_t DynamicContentList::getEditSize() const
 {
     if (indexMap.empty()) {
         return 0;
     }
-    return (*std::max_element(indexMap.begin(), indexMap.end(), [&](auto a, auto b) { return (a.first < b.first); })).first + 1;
+    return std::max_element(indexMap.begin(), indexMap.end(), [](auto a, auto b) { return (a.first < b.first); })->first + 1;
 }
 
-std::vector<std::shared_ptr<DynamicContent>> DynamicContentList::getArrayCopy()
+std::vector<std::shared_ptr<DynamicContent>> DynamicContentList::getArrayCopy() const
 {
     AutoLock lock(mutex);
     return list;
 }
 
-std::shared_ptr<DynamicContent> DynamicContentList::get(size_t id, bool edit)
+std::shared_ptr<DynamicContent> DynamicContentList::get(std::size_t id, bool edit) const
 {
     AutoLock lock(mutex);
     if (!edit) {
@@ -75,22 +72,22 @@ std::shared_ptr<DynamicContent> DynamicContentList::get(size_t id, bool edit)
         return list[id];
     }
     if (indexMap.find(id) != indexMap.end()) {
-        return indexMap[id];
+        return indexMap.at(id);
     }
     return nullptr;
 }
 
-std::shared_ptr<DynamicContent> DynamicContentList::get(const fs::path& location)
+std::shared_ptr<DynamicContent> DynamicContentList::get(const fs::path& location) const
 {
     AutoLock lock(mutex);
-    auto entry = std::find_if(list.begin(), list.end(), [&](auto&& c) { return c->getLocation() == location; });
+    auto entry = std::find_if(list.begin(), list.end(), [=](auto&& c) { return c->getLocation() == location; });
     if (entry != list.end() && *entry) {
         return *entry;
     }
     return nullptr;
 }
 
-void DynamicContentList::remove(size_t id, bool edit)
+void DynamicContentList::remove(std::size_t id, bool edit)
 {
     AutoLock lock(mutex);
 
