@@ -71,6 +71,7 @@ class ScriptingRuntime;
 #include "util/executor.h"
 
 // forward declarations
+class AutoScanSetting;
 class ContentManager;
 class LastFm;
 class Server;
@@ -137,6 +138,27 @@ public:
 };
 #endif
 
+class UpnpMap {
+private:
+    std::vector<std::tuple<std::string, std::string, std::string>> filters;
+
+    bool checkValue(const std::string& op, const std::string& expect, const std::string& actual);
+    bool checkValue(const std::string& op, int expect, int actual);
+
+public:
+    std::string mimeType;
+    std::string upnpClass;
+
+    UpnpMap(std::string mt, std::string cls, std::vector<std::tuple<std::string, std::string, std::string>> f)
+        : filters(std::move(f))
+        , mimeType(std::move(mt))
+        , upnpClass(std::move(cls))
+    {
+    }
+
+    bool isMatch(const std::shared_ptr<CdsItem>& item, const std::string& mt);
+};
+
 class ContentManager : public Timer::Subscriber, public std::enable_shared_from_this<ContentManager> {
 public:
     ContentManager(const std::shared_ptr<Context>& context,
@@ -182,7 +204,7 @@ public:
         bool async = true, bool lowPriority = false, bool cancellable = true);
 
     int ensurePathExistence(const fs::path& path) const;
-    void removeObject(const std::shared_ptr<AutoscanDirectory>& adir, int objectID, bool rescanResource, bool async = true, bool all = false);
+    std::vector<int> removeObject(const std::shared_ptr<AutoscanDirectory>& adir, int objectID, bool rescanResource, bool async = true, bool all = false);
 
     /// \brief Updates an object in the database using the given parameters.
     /// \param objectID ID of the object to update
@@ -236,7 +258,7 @@ public:
     void updateObject(const std::shared_ptr<CdsObject>& obj, bool sendUpdates = true);
 
     /// \brief Gets an AutocsanDirectrory from the watch list.
-    std::shared_ptr<AutoscanDirectory> getAutoscanDirectory(int scanID, ScanMode scanMode) const;
+    std::shared_ptr<AutoscanDirectory> getAutoscanDirectory(int scanID, AutoscanDirectory::ScanMode scanMode) const;
 
     /// \brief Gets an AutoscanDirectory (by objectID) from the watch list.
     std::shared_ptr<AutoscanDirectory> getAutoscanDirectory(int objectID) const;
@@ -281,7 +303,7 @@ public:
     /// The handler will then remove the executor from the list.
     void unregisterExecutor(const std::shared_ptr<Executor>& exec);
 
-    void triggerPlayHook(const std::shared_ptr<CdsObject>& obj);
+    void triggerPlayHook(const std::string& group, const std::shared_ptr<CdsObject>& obj);
 
     void initLayout();
     void destroyLayout();
@@ -312,11 +334,12 @@ protected:
     std::shared_ptr<LastFm> last_fm;
 
     std::map<std::string, std::string> mimetypeContenttypeMap;
+    std::map<std::string, std::string> mimetypeUpnpclassMap;
+    std::vector<UpnpMap> upnpMap {};
 
-    std::shared_ptr<AutoscanList> autoscan_timed;
+    std::shared_ptr<AutoscanList> autoscanList;
 #ifdef HAVE_INOTIFY
     std::unique_ptr<AutoscanInotify> inotify;
-    std::shared_ptr<AutoscanList> autoscan_inotify;
 #endif
 
     std::vector<std::shared_ptr<Executor>> process_list;
@@ -330,21 +353,25 @@ protected:
     int _addFile(const fs::directory_entry& dirEnt, fs::path rootPath, AutoScanSetting& asSetting,
         const std::shared_ptr<CMAddFileTask>& task = nullptr);
 
-    void _removeObject(const std::shared_ptr<AutoscanDirectory>& adir, int objectID, bool rescanResource, bool all);
+    std::vector<int> _removeObject(const std::shared_ptr<AutoscanDirectory>& adir, int objectID, bool rescanResource, bool all);
 
     void _rescanDirectory(const std::shared_ptr<AutoscanDirectory>& adir, int containerID, const std::shared_ptr<GenericTask>& task = nullptr);
     /* for recursive addition */
     void addRecursive(std::shared_ptr<AutoscanDirectory>& adir, const fs::directory_entry& subDir, bool followSymlinks, bool hidden, const std::shared_ptr<CMAddFileTask>& task);
-    std::shared_ptr<CdsObject> createSingleItem(const fs::directory_entry& dirEnt, const fs::path& rootPath, bool followSymlinks, bool checkDatabase, bool processExisting, bool firstChild, std::shared_ptr<CMAddFileTask> task);
+    std::shared_ptr<CdsObject> createSingleItem(const fs::directory_entry& dirEnt, const fs::path& rootPath, bool followSymlinks, bool checkDatabase, bool processExisting, bool firstChild, std::shared_ptr<AutoscanDirectory>& adir, std::shared_ptr<CMAddFileTask> task);
     bool updateAttachedResources(const std::shared_ptr<AutoscanDirectory>& adir, const std::shared_ptr<CdsObject>& obj, const fs::path& parentPath, bool all);
     void finishScan(const std::shared_ptr<AutoscanDirectory>& adir, const fs::path& location, const std::shared_ptr<CdsContainer>& parent, std::chrono::seconds lmt, const std::shared_ptr<CdsObject>& firstObject = nullptr) const;
     static void invalidateAddTask(const std::shared_ptr<GenericTask>& t, const fs::path& path);
+    static void initUpnpMap(std::vector<UpnpMap>& target, const std::map<std::string, std::string>& source);
+    std::string mimeTypeToUpnpClass(const std::string& mimeType);
 
     void assignFanArt(const std::shared_ptr<CdsContainer>& container, const std::shared_ptr<CdsObject>& origObj, int count) const;
 
     template <typename T>
     void updateCdsObject(const std::shared_ptr<T>& item, const std::map<std::string, std::string>& parameters);
 
+    void updateItemData(const std::shared_ptr<CdsItem>& item, const std::string& mimetype);
+
     std::shared_ptr<Layout> layout;
 
 #ifdef ONLINE_SERVICES
