@@ -47,8 +47,8 @@
 
 #endif // ONLINE_SERVICES
 
-BuiltinLayout::BuiltinLayout(const std::shared_ptr<ContentManager>& content)
-    : Layout(content)
+BuiltinLayout::BuiltinLayout(std::shared_ptr<ContentManager> content)
+    : Layout(std::move(content))
     , config(this->content->getContext()->getConfig())
     , genreMap(this->config->getDictionaryOption(CFG_IMPORT_SCRIPTING_IMPORT_GENRE_MAP))
 {
@@ -168,7 +168,7 @@ void BuiltinLayout::addVideo(const std::shared_ptr<CdsObject>& obj, const fs::pa
 
     auto meta = obj->getMetaData();
 
-    std::string date = getValueOrDefault(meta, MetadataHandler::getMetaFieldName(M_CREATION_DATE));
+    std::string date = getValueOrDefault(meta, std::string { MetadataHandler::getMetaFieldName(M_CREATION_DATE) });
     if (!date.empty()) {
         std::string year, month;
         auto m = std::numeric_limits<std::size_t>::max();
@@ -218,7 +218,7 @@ void BuiltinLayout::addImage(const std::shared_ptr<CdsObject>& obj, const fs::pa
 
     auto meta = obj->getMetaData();
 
-    std::string date = getValueOrDefault(meta, MetadataHandler::getMetaFieldName(M_DATE));
+    std::string date = getValueOrDefault(meta, std::string { MetadataHandler::getMetaFieldName(M_DATE) });
     if (!date.empty()) {
         std::string year, month;
         auto m = std::numeric_limits<std::size_t>::max();
@@ -511,11 +511,11 @@ void BuiltinLayout::processCdsObject(const std::shared_ptr<CdsObject>& obj, cons
                 addVideo(clone, rootpath);
             else
                 addAudio(clone, rootpath);
-        } else if (objCls == UPNP_CLASS_VIDEO_ITEM) {
+        } else if (startswith(objCls, UPNP_CLASS_VIDEO_ITEM)) {
             addVideo(clone, rootpath);
-        } else if (objCls == UPNP_CLASS_IMAGE_ITEM) {
+        } else if (startswith(objCls, UPNP_CLASS_IMAGE_ITEM)) {
             addImage(clone, rootpath);
-        } else if (objCls == UPNP_CLASS_MUSIC_TRACK && contentType != CONTENT_TYPE_PLAYLIST) {
+        } else if (startswith(objCls, UPNP_CLASS_AUDIO_ITEM) && contentType != CONTENT_TYPE_PLAYLIST) {
             addAudio(clone, rootpath);
         }
 
