@@ -32,6 +32,8 @@
 #ifdef ATRAILERS
 #include "atrailers_content_handler.h" // API
 
+#include <array>
+
 #include "cds_objects.h"
 #include "config/config.h"
 #include "metadata/metadata_handler.h"
@@ -80,7 +82,7 @@ std::shared_ptr<CdsObject> ATrailersContentHandler::getNextObject()
 std::shared_ptr<CdsObject> ATrailersContentHandler::getObject(const pugi::xml_node& trailer) const
 {
     auto item = std::make_shared<CdsItemExternalURL>();
-    auto resource = std::make_shared<CdsResource>(CH_DEFAULT);
+    auto resource = std::make_shared<CdsResource>(ContentHandler::DEFAULT, CdsResource::Purpose::Content);
     item->addResource(resource);
 
     auto info = trailer.child("info");
@@ -94,7 +96,7 @@ std::shared_ptr<CdsObject> ATrailersContentHandler::getObject(const pugi::xml_no
         item->setTitle(temp);
 
     item->setMimeType(trailer_mimetype);
-    resource->addAttribute(R_PROTOCOLINFO, renderProtocolInfo(trailer_mimetype));
+    resource->addAttribute(CdsResource::Attribute::PROTOCOLINFO, renderProtocolInfo(trailer_mimetype));
 
     item->setAuxData(ONLINE_SERVICE_AUX_ID, fmt::to_string(OS_ATrailers));
 
