@@ -4,7 +4,7 @@
 
     curl_online_service.cc - this file is part of Gerbera.
 
-    Copyright (C) 2021 Gerbera Contributors
+    Copyright (C) 2021-2022 Gerbera Contributors
 
     Gerbera is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
@@ -38,8 +38,8 @@ CurlContentHandler::CurlContentHandler(const std::shared_ptr<Context>& context)
 {
 }
 
-CurlOnlineService::CurlOnlineService(std::shared_ptr<ContentManager> content, std::string serviceName)
-    : OnlineService(std::move(content))
+CurlOnlineService::CurlOnlineService(const std::shared_ptr<ContentManager>& content, std::string serviceName)
+    : OnlineService(content)
     , curl_handle(curl_easy_init())
     , serviceName(std::move(serviceName))
 {
@@ -66,7 +66,7 @@ std::unique_ptr<pugi::xml_document> CurlOnlineService::getData()
     std::string buffer;
 
     try {
-        log_debug("DOWNLOADING URL: {}", service_url.c_str());
+        log_debug("DOWNLOADING URL: {}", service_url);
         buffer = URL::download(service_url, &retcode,
             curl_handle, false, true, true);
     } catch (const std::runtime_error& ex) {
@@ -80,7 +80,7 @@ std::unique_ptr<pugi::xml_document> CurlOnlineService::getData()
     if (retcode != 200)
         return nullptr;
 
-    log_debug("GOT BUFFER{}", buffer.c_str());
+    log_debug("GOT BUFFER{}", buffer);
     auto doc = std::make_unique<pugi::xml_document>();
     pugi::xml_parse_result result = doc->load_string(sc->convert(buffer).c_str());
     if (result.status != pugi::xml_parse_status::status_ok) {
@@ -126,12 +126,18 @@ bool CurlOnlineService::refreshServiceData(const std::shared_ptr<Layout>& layout
 
         obj->setVirtual(true);
 
-        auto old = database->loadObjectByServiceID(std::static_pointer_cast<CdsItem>(obj)->getServiceID());
+        auto item = std::static_pointer_cast<CdsItem>(obj);
+        auto old = database->loadObjectByServiceID(item->getServiceID());
         if (!old) {
             log_debug("Adding new {} object", serviceName);
 
-            if (layout)
-                layout->processCdsObject(obj, "");
+            if (layout) {
+                std::string mimetype = item->getMimeType();
+                auto mappings = config->getDictionaryOption(CFG_IMPORT_MAPPINGS_MIMETYPE_TO_CONTENTTYPE_LIST);
+                std::string contentType = getValueOrDefault(mappings, mimetype);
+
+                layout->processCdsObject(obj, "", contentType);
+            }
         } else {
             log_debug("Updating existing {} object", serviceName);
             obj->setID(old->getID());
@@ -146,4 +152,4 @@ bool CurlOnlineService::refreshServiceData(const std::shared_ptr<Layout>& layout
     return false;
 }
 
-#endif //HAVE_CURL
+#endif // HAVE_CURL
