@@ -1,29 +1,29 @@
 /*MT*
-    
+
     MediaTomb - http://www.mediatomb.cc/
-    
+
     online_service.cc - this file is part of MediaTomb.
-    
+
     Copyright (C) 2005 Gena Batyan <bgeradz@mediatomb.cc>,
                        Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>
-    
+
     Copyright (C) 2006-2010 Gena Batyan <bgeradz@mediatomb.cc>,
                             Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>,
                             Leonhard Wimmer <leo@mediatomb.cc>
-    
+
     MediaTomb is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
     as published by the Free Software Foundation.
-    
+
     MediaTomb is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
-    
+
     You should have received a copy of the GNU General Public License
     version 2 along with MediaTomb; if not, write to the Free Software
     Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
-    
+
     $Id$
 */
 
@@ -40,7 +40,7 @@
 
 // DO NOT FORGET TO ADD SERVICE STORAGE PREFIXES TO THIS ARRAY WHEN ADDING
 // NEW SERVICES!
-static constexpr auto service_prefixes = std::array { '\0', 'Y', 'S', 'W', 'T', '\0' };
+static constexpr auto servicePrefixes = std::array { '\0', 'Y', 'S', 'W', 'T', '\0' };
 
 void OnlineServiceList::registerService(const std::shared_ptr<OnlineService>& service)
 {
@@ -62,10 +62,10 @@ std::shared_ptr<OnlineService> OnlineServiceList::getService(service_type_t serv
     return service_list.at(service);
 }
 
-OnlineService::OnlineService(std::shared_ptr<ContentManager> content)
+OnlineService::OnlineService(const std::shared_ptr<ContentManager>& content)
     : config(content->getContext()->getConfig())
     , database(content->getContext()->getDatabase())
-    , content(std::move(content))
+    , content(content)
 {
 }
 
@@ -74,7 +74,7 @@ char OnlineService::getDatabasePrefix(service_type_t service)
     if (service >= OS_Max)
         throw_std_runtime_error("Illegal service requested");
 
-    return service_prefixes.at(service);
+    return servicePrefixes.at(service);
 }
 
 char OnlineService::getDatabasePrefix() const
@@ -82,4 +82,4 @@ char OnlineService::getDatabasePrefix() const
     return getDatabasePrefix(getServiceType());
 }
 
-#endif //ONLINE_SERVICES
+#endif // ONLINE_SERVICES
