@@ -47,7 +47,7 @@ void TaskProcessor::run()
             auto inst = static_cast<TaskProcessor*>(arg);
             inst->threadProc();
         },
-        this, config);
+        this);
 
     // wait for thread to become ready
     threadRunner->waitForReady();
@@ -139,7 +139,7 @@ void TaskProcessor::invalidateTask(unsigned int taskID)
     }
 }
 
-std::deque<std::shared_ptr<GenericTask>> TaskProcessor::getTasklist()
+std::deque<std::shared_ptr<GenericTask>> TaskProcessor::getTasklist() const
 {
     std::deque<std::shared_ptr<GenericTask>> taskList;
 
@@ -192,7 +192,7 @@ void TPFetchOnlineContentTask::run()
             if ((service->getRefreshInterval() > std::chrono::seconds::zero()) || unscheduled_refresh) {
                 auto t = std::make_shared<TPFetchOnlineContentTask>(
                     content, task_processor, timer, service, layout, cancellable, unscheduled_refresh);
-                task_processor->addTask(t);
+                task_processor->addTask(std::move(t));
             }
         } else {
             content->cleanupOnlineServiceObjects(service);
