@@ -1,29 +1,29 @@
 /*MT*
-    
+
     MediaTomb - http://www.mediatomb.cc/
-    
+
     js_functions.cc - this file is part of MediaTomb.
-    
+
     Copyright (C) 2005 Gena Batyan <bgeradz@mediatomb.cc>,
                        Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>
-    
+
     Copyright (C) 2006-2010 Gena Batyan <bgeradz@mediatomb.cc>,
                             Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>,
                             Leonhard Wimmer <leo@mediatomb.cc>
-    
+
     MediaTomb is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
     as published by the Free Software Foundation.
-    
+
     MediaTomb is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
-    
+
     You should have received a copy of the GNU General Public License
     version 2 along with MediaTomb; if not, write to the Free Software
     Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
-    
+
     $Id$
 */
 
@@ -32,16 +32,13 @@
 #ifdef HAVE_JS
 #include "js_functions.h" // API
 
-#include <typeinfo>
-
-#include "config/config_manager.h"
 #include "content/content_manager.h"
 #include "database/database.h"
 #include "metadata/metadata_handler.h"
 #include "script.h"
 #include "util/string_converter.h"
 
-//extern "C" {
+// extern "C" {
 
 duk_ret_t js_print(duk_context* ctx)
 {
@@ -54,17 +51,17 @@ duk_ret_t js_print(duk_context* ctx)
 
 duk_ret_t js_copyObject(duk_context* ctx)
 {
-    auto* self = Script::getContextScript(ctx);
+    auto self = Script::getContextScript(ctx);
     if (!duk_is_object(ctx, 0))
         return duk_error(ctx, DUK_ERR_TYPE_ERROR, "copyObject argument is not an object");
-    auto cds_obj = self->dukObject2cdsObject(nullptr);
-    self->cdsObject2dukObject(cds_obj);
+    auto cdsObj = self->dukObject2cdsObject(nullptr);
+    self->cdsObject2dukObject(cdsObj);
     return 1;
 }
 
 duk_ret_t js_addContainerTree(duk_context* ctx)
 {
-    auto* self = Script::getContextScript(ctx);
+    auto self = Script::getContextScript(ctx);
 
     if (!duk_is_array(ctx, 0)) {
         log_js("js_addContainerTree: No Array");
@@ -74,7 +71,7 @@ duk_ret_t js_addContainerTree(duk_context* ctx)
     std::vector<std::shared_ptr<CdsObject>> result;
     auto length = duk_get_length(ctx, -1);
 
-    for (duk_size_t i = 0; i < length; i++) {
+    for (duk_uarridx_t i = 0; i < length; i++) {
         if (duk_get_prop_index(ctx, -1, i)) {
             if (!duk_is_object(ctx, -1)) {
                 duk_pop(ctx);
@@ -82,9 +79,9 @@ duk_ret_t js_addContainerTree(duk_context* ctx)
                 break;
             }
             duk_to_object(ctx, -1);
-            auto cds_obj = self->dukObject2cdsObject(nullptr);
-            if (cds_obj) {
-                result.push_back(std::move(cds_obj));
+            auto cdsObj = self->dukObject2cdsObject(nullptr);
+            if (cdsObj) {
+                result.push_back(std::move(cdsObj));
             } else {
                 log_js("js_addContainerTree: no CdsObject at {}", i);
             }
@@ -94,10 +91,10 @@ duk_ret_t js_addContainerTree(duk_context* ctx)
 
     if (!result.empty()) {
         auto cm = self->getContent();
-        auto containerId = cm->addContainerTree(result);
-        if (containerId.first != INVALID_OBJECT_ID) {
+        auto [containerId, containerStatus] = cm->addContainerTree(result);
+        if (containerId != INVALID_OBJECT_ID) {
             /* setting last container ID as return value */
-            std::string tmp = fmt::to_string(containerId.first);
+            auto tmp = fmt::to_string(containerId);
             duk_push_string(ctx, tmp.c_str());
             return 1;
         }
@@ -113,17 +110,11 @@ duk_ret_t js_addCdsObject(duk_context* ctx)
     if (!duk_is_object(ctx, 0))
         return 0;
     duk_to_object(ctx, 0);
-    //stack: js_cds_obj
-    const char* ts = duk_to_string(ctx, 1);
-    if (!ts)
-        ts = "/";
-    fs::path path = ts;
-    //stack: js_cds_obj path
-    std::string containerclass;
-    if (!duk_is_null_or_undefined(ctx, 2)) {
-        containerclass = duk_to_string(ctx, 2);
-    }
-    //stack: js_cds_obj path containerclass
+    // stack: js_cds_obj
+    const char* containerId = duk_to_string(ctx, 1);
+    if (!containerId)
+        containerId = "-1";
+    // stack: js_cds_obj containerId
 
     try {
         std::unique_ptr<StringConverter> p2i;
@@ -135,6 +126,10 @@ duk_ret_t js_addCdsObject(duk_context* ctx)
         } else {
             i2i = StringConverter::i2i(config);
         }
+        duk_get_global_string(ctx, "object_script_path");
+        auto rp = duk_get_string(ctx, -1);
+        duk_pop(ctx);
+        std::string rootPath = rp ? rp : "";
 
         if (self->whoami() == S_PLAYLIST)
             duk_get_global_string(ctx, "playlist");
@@ -142,23 +137,23 @@ duk_ret_t js_addCdsObject(duk_context* ctx)
             duk_get_global_string(ctx, "orig");
         else
             duk_push_undefined(ctx);
-        //stack: js_cds_obj path containerclass js_orig_obj
+        // stack: js_cds_obj containerId js_orig_obj
 
         if (duk_is_undefined(ctx, -1)) {
-            log_debug("Could not retrieve orig/playlist object");
+            log_debug("Could not retrieve global 'orig'/'playlist' object");
             return 0;
         }
 
-        auto orig_object = self->dukObject2cdsObject(self->getProcessedObject());
-        if (!orig_object)
+        auto origObject = self->dukObject2cdsObject(self->getProcessedObject());
+        if (!origObject)
             return 0;
 
-        std::shared_ptr<CdsObject> cds_obj;
+        std::shared_ptr<CdsObject> cdsObj;
         auto cm = self->getContent();
-        int pcd_id = INVALID_OBJECT_ID;
+        int pcdId = INVALID_OBJECT_ID;
 
         duk_swap_top(ctx, 0);
-        //stack: js_orig_obj path containerclass js_cds_obj
+        // stack: js_orig_obj containerId js_cds_obj
         if (self->whoami() == S_PLAYLIST) {
             int otype = self->getIntProperty("objectType", -1);
             if (otype == -1) {
@@ -178,66 +173,60 @@ duk_ret_t js_addCdsObject(duk_context* ctx)
                     asSetting.rescanResource = false;
                     asSetting.mergeOptions(config, loc);
 
-                    pcd_id = cm->addFile(dirEnt, asSetting, false);
-                    if (pcd_id == INVALID_OBJECT_ID) {
+                    pcdId = cm->addFile(dirEnt, rootPath, asSetting, false);
+                    if (pcdId == INVALID_OBJECT_ID) {
+                        log_error("Failed to add object {}", dirEnt.path().string());
                         return 0;
                     }
-                    auto mainObj = self->getDatabase()->loadObject(pcd_id);
-                    cds_obj = self->dukObject2cdsObject(mainObj);
+                    auto mainObj = self->getDatabase()->loadObject(pcdId);
+                    cdsObj = self->dukObject2cdsObject(mainObj);
                 } else {
                     log_error("Failed to read {}: {}", loc.c_str(), ec.message());
                 }
             } else
-                cds_obj = self->dukObject2cdsObject(orig_object);
+                cdsObj = self->dukObject2cdsObject(origObject);
         } else
-            cds_obj = self->dukObject2cdsObject(orig_object);
+            cdsObj = self->dukObject2cdsObject(origObject);
 
-        if (!cds_obj) {
+        if (!cdsObj) {
             return 0;
         }
 
-        auto parentId = std::pair(stoiString(ts), false);
+        auto [parentId, parentStatus] = std::pair(stoiString(containerId), false);
 
-        if (parentId.first <= 0) {
-            if ((self->whoami() == S_PLAYLIST) && (self->getConfig()->getBoolOption(CFG_IMPORT_SCRIPTING_PLAYLIST_SCRIPT_LINK_OBJECTS))) {
-                path = p2i->convert(path);
-                parentId = cm->addContainerChain(path, containerclass, orig_object->getID());
-            } else {
-                path = (self->whoami() == S_PLAYLIST) ? p2i->convert(path) : i2i->convert(path);
-                parentId = cm->addContainerChain(path, containerclass, INVALID_OBJECT_ID, orig_object);
-            }
+        if (parentId <= 0) {
+            log_error("Invalid parent id passed to addCdsObject: {}", parentId);
+            return 0;
         }
 
-        cds_obj->setParentID(parentId.first);
-        if (!cds_obj->isExternalItem()) {
+        cdsObj->setParentID(parentId);
+        if (!cdsObj->isExternalItem()) {
             /// \todo get hidden file setting from config manager?
             /// what about same stuff in content manager, why is it not used
             /// there?
 
             if (self->whoami() == S_PLAYLIST) {
-                if (pcd_id == INVALID_OBJECT_ID) {
+                if (pcdId == INVALID_OBJECT_ID) {
                     return 0;
                 }
-                cds_obj->setRefID(pcd_id);
+                cdsObj->setRefID(pcdId);
             } else
-                cds_obj->setRefID(orig_object->getID());
+                cdsObj->setRefID(origObject->getID());
 
-            cds_obj->setFlag(OBJECT_FLAG_USE_RESOURCE_REF);
-        } else if (cds_obj->isExternalItem()) {
-            if ((self->whoami() == S_PLAYLIST) && (self->getConfig()->getBoolOption(CFG_IMPORT_SCRIPTING_PLAYLIST_SCRIPT_LINK_OBJECTS))) {
-                cds_obj->setFlag(OBJECT_FLAG_PLAYLIST_REF);
-                cds_obj->setRefID(orig_object->getID());
-            }
+            cdsObj->setFlag(OBJECT_FLAG_USE_RESOURCE_REF);
+        } else if (cdsObj->isExternalItem() && (self->whoami() == S_PLAYLIST) && self->getConfig()->getBoolOption(CFG_IMPORT_SCRIPTING_PLAYLIST_SCRIPT_LINK_OBJECTS)) {
+            cdsObj->setFlag(OBJECT_FLAG_PLAYLIST_REF);
+            cdsObj->setRefID(origObject->getID());
         }
 
-        cds_obj->setID(INVALID_OBJECT_ID);
-        cm->addObject(cds_obj, parentId.second);
+        cdsObj->setID(INVALID_OBJECT_ID);
+        cm->addObject(cdsObj, parentStatus);
 
         /* setting object ID as return value */
-        std::string tmp = fmt::to_string(parentId.first);
+        auto tmp = fmt::to_string(parentId);
         duk_push_string(ctx, tmp.c_str());
         return 1;
-    } catch (const ServerShutdownException& se) {
+    } catch (const ServerShutdownException&) {
         log_warning("Aborting script execution due to server shutdown.");
         return duk_error(ctx, DUK_ERR_ERROR, "Aborting script execution due to server shutdown.\n");
     } catch (const std::runtime_error& e) {
@@ -246,9 +235,9 @@ duk_ret_t js_addCdsObject(duk_context* ctx)
     return 0;
 }
 
-static duk_ret_t convert_charset_generic(duk_context* ctx, charset_convert_t chr)
+static duk_ret_t convertCharsetGeneric(duk_context* ctx, charset_convert_t chr)
 {
-    auto* self = Script::getContextScript(ctx);
+    auto self = Script::getContextScript(ctx);
     if (duk_get_top(ctx) != 1)
         return DUK_RET_SYNTAX_ERROR;
     if (!duk_is_string(ctx, 0))
@@ -260,7 +249,7 @@ static duk_ret_t convert_charset_generic(duk_context* ctx, charset_convert_t chr
         std::string result = self->convertToCharset(ts, chr);
         duk_push_lstring(ctx, result.c_str(), result.length());
         return 1;
-    } catch (const ServerShutdownException& se) {
+    } catch (const ServerShutdownException&) {
         log_warning("Aborting script execution due to server shutdown.");
         return DUK_RET_ERROR;
     } catch (const std::runtime_error& e) {
@@ -271,24 +260,24 @@ static duk_ret_t convert_charset_generic(duk_context* ctx, charset_convert_t chr
 
 duk_ret_t js_f2i(duk_context* ctx)
 {
-    return convert_charset_generic(ctx, F2I);
+    return convertCharsetGeneric(ctx, F2I);
 }
 
 duk_ret_t js_m2i(duk_context* ctx)
 {
-    return convert_charset_generic(ctx, M2I);
+    return convertCharsetGeneric(ctx, M2I);
 }
 
 duk_ret_t js_p2i(duk_context* ctx)
 {
-    return convert_charset_generic(ctx, P2I);
+    return convertCharsetGeneric(ctx, P2I);
 }
 
 duk_ret_t js_j2i(duk_context* ctx)
 {
-    return convert_charset_generic(ctx, J2I);
+    return convertCharsetGeneric(ctx, J2I);
 }
 
 //} // extern "C"
 
-#endif //HAVE_JS
+#endif // HAVE_JS
