@@ -32,6 +32,7 @@
 #ifdef HAVE_JS
 #include "script.h" // API
 
+#include <array>
 #include <fmt/chrono.h>
 
 #include "cds_objects.h"
@@ -196,7 +197,7 @@ Script::Script(const std::shared_ptr<ContentManager>& content,
     /* initialize contstants */
     for (auto&& [field, sym] : ot_names) {
         duk_push_int(ctx, field);
-        duk_put_global_string(ctx, sym);
+        duk_put_global_lstring(ctx, sym.data(), sym.size());
     }
 #ifdef ONLINE_SERVICES
     duk_push_int(ctx, int(OS_None));
@@ -228,27 +229,25 @@ Script::Script(const std::shared_ptr<ContentManager>& content,
     duk_put_global_string(ctx, "ONLINE_SERVICE_SOPCAST");
 #endif // ONLINE_SERVICES
 
+    // M_TITLE = "dc:title"
     for (auto&& [field, sym] : mt_keys) {
-        duk_push_string(ctx, sym);
-        for (auto [f, s] : mt_names) {
-            if (f == field) {
-                duk_put_global_string(ctx, s.data());
-            }
+        auto s = getValueOrDefault(mt_names, field, { "" });
+        if (!s.empty()) {
+            duk_push_lstring(ctx, sym.data(), sym.size());
+            duk_put_global_lstring(ctx, s.data(), s.length());
         }
     }
 
-    for (auto&& [field, sym] : res_keys) {
-        duk_push_string(ctx, sym);
-        for (auto&& [f, s] : res_names) {
-            if (f == field) {
-                duk_put_global_string(ctx, s);
-            }
-        }
+    // R_SIZE = "size"
+    for (auto&& [field, sym] : res_names) {
+        duk_push_string(ctx, CdsResource::getAttributeName(field).c_str());
+        duk_put_global_lstring(ctx, sym.data(), sym.length());
     }
 
+    // UPNP_CLASS_MUSIC_ALBUM = "object.container.album.musicAlbum"
     for (auto&& [field, sym] : upnp_classes) {
-        duk_push_string(ctx, field);
-        duk_put_global_string(ctx, sym);
+        duk_push_lstring(ctx, field.data(), field.length());
+        duk_put_global_lstring(ctx, sym.data(), sym.size());
     }
 
     duk_push_object(ctx); // config
@@ -286,15 +285,13 @@ Script::Script(const std::shared_ptr<ContentManager>& content,
     std::string autoscanItemPath;
     for (auto&& ascs : ConfigDefinition::getConfigSetupList<ConfigAutoscanSetup>()) {
         auto autoscan = ascs->getValue()->getAutoscanListOption();
-        for (std::size_t i = 0; i < autoscan->size(); i++) {
-            auto&& entry = autoscan->get(i);
-            auto&& adir = this->content->getAutoscanDirectory(entry->getLocation());
-
+        for (const auto& adir : content->getAutoscanDirectories()) {
             duk_push_object(ctx);
             setProperty(ConfigDefinition::removeAttribute(ATTR_AUTOSCAN_DIRECTORY_LOCATION), adir->getLocation());
             setProperty(ConfigDefinition::removeAttribute(ATTR_AUTOSCAN_DIRECTORY_MODE), AutoscanDirectory::mapScanmode(adir->getScanMode()));
             setIntProperty(ConfigDefinition::removeAttribute(ATTR_AUTOSCAN_DIRECTORY_INTERVAL), adir->getInterval().count());
             setIntProperty(ConfigDefinition::removeAttribute(ATTR_AUTOSCAN_DIRECTORY_RECURSIVE), adir->getRecursive());
+            setIntProperty(ConfigDefinition::removeAttribute(ATTR_AUTOSCAN_DIRECTORY_MEDIATYPE), adir->getMediaType());
             setIntProperty(ConfigDefinition::removeAttribute(ATTR_AUTOSCAN_DIRECTORY_HIDDENFILES), adir->getHidden());
             setIntProperty(ConfigDefinition::removeAttribute(ATTR_AUTOSCAN_DIRECTORY_SCANCOUNT), adir->getActiveScanCount());
             setIntProperty(ConfigDefinition::removeAttribute(ATTR_AUTOSCAN_DIRECTORY_TASKCOUNT), adir->getTaskCount());
@@ -553,17 +550,20 @@ std::shared_ptr<CdsObject> Script::dukObject2cdsObject(const std::shared_ptr<Cds
             int resCount = 0;
             for (auto&& sym : keys) {
                 if (sym.find("handlerType") != std::string::npos) {
-                    int resNr = getIntProperty(sym, -1);
-                    if (resNr >= 0) {
-                        obj->addResource(std::make_shared<CdsResource>(resNr));
+                    int ht = getIntProperty(sym, -1);
+                    auto purpSym = fmt::format("{}:purpose", resCount);
+                    int purpose = getIntProperty(purpSym, -1);
+                    if (ht >= 0 && purpose >= 0) {
+                        obj->addResource(std::make_shared<CdsResource>(MetadataHandler::remapContentHandler(ht), CdsResource::remapPurpose(purpose)));
                     }
+                    resCount++;
                 }
             }
             resCount = 0;
             for (auto&& res : obj->getResources()) {
                 // only attribute enumerated in res_keys is allowed
-                for (auto&& [key, upnp] : res_keys) {
-                    val = getProperty(resCount == 0 ? upnp : fmt::format("{}-{}", resCount, upnp));
+                for (auto&& [key, upnp] : res_names) {
+                    val = getProperty(resCount == 0 ? upnp.data() : fmt::format("{}-{}", resCount, upnp));
                     if (!val.empty()) {
                         val = sc->convert(val);
                         res->addAttribute(key, val);
@@ -635,7 +635,7 @@ std::shared_ptr<CdsObject> Script::dukObject2cdsObject(const std::shared_ptr<Cds
             val = sc->convert(val);
             item->removeMetaData(M_DESCRIPTION);
             item->addMetaData(M_DESCRIPTION, val);
-        } else if (pcd && item->getMetaData(M_DESCRIPTION).empty()) {
+        } else if (pcd && item->getMetaData(M_DESCRIPTION).empty() && !pcdItem->getMetaData(M_DESCRIPTION).empty()) {
             item->addMetaData(M_DESCRIPTION, pcdItem->getMetaData(M_DESCRIPTION));
         }
         if (this->whoami() == S_PLAYLIST) {
@@ -665,13 +665,13 @@ std::shared_ptr<CdsObject> Script::dukObject2cdsObject(const std::shared_ptr<Cds
             }
 
             if (item->getResourceCount() == 0) {
-                auto resource = std::make_shared<CdsResource>(CH_DEFAULT);
-                resource->addAttribute(R_PROTOCOLINFO, protocolInfo);
+                auto resource = std::make_shared<CdsResource>(ContentHandler::DEFAULT, CdsResource::Purpose::Content);
+                resource->addAttribute(CdsResource::Attribute::PROTOCOLINFO, protocolInfo);
 
                 item->addResource(resource);
             } else {
-                auto resource = item->getResource(CH_DEFAULT);
-                resource->addAttribute(R_PROTOCOLINFO, protocolInfo);
+                auto resource = item->getResource(ContentHandler::DEFAULT);
+                resource->addAttribute(CdsResource::Attribute::PROTOCOLINFO, protocolInfo);
             }
         }
     }
@@ -819,10 +819,11 @@ void Script::cdsObject2dukObject(const std::shared_ptr<CdsObject>& obj)
         if (obj->getResourceCount() > 0) {
             int resCount = 0;
             for (auto&& res : obj->getResources()) {
-                setProperty(fmt::format("{}:handlerType", resCount), fmt::to_string(res->getHandlerType()));
+                setProperty(fmt::format("{}:handlerType", resCount), fmt::to_string(to_underlying(res->getHandlerType())));
+                setProperty(fmt::format("{}:purpose", resCount), fmt::to_string(to_underlying(res->getPurpose())));
                 auto attributes = res->getAttributes();
                 for (auto&& [key, attr] : attributes) {
-                    setProperty(resCount == 0 ? key : fmt::format("{}-{}", resCount, key), attr);
+                    setProperty(resCount == 0 ? CdsResource::getAttributeName(key) : fmt::format("{}-{}", resCount, key), attr);
                 }
                 auto parameters = res->getParameters();
                 for (auto&& [key, param] : parameters) {
