@@ -26,16 +26,14 @@
 #include "context.h" // API
 
 Context::Context(std::shared_ptr<Config> config,
-    std::shared_ptr<Clients> clients,
+    std::shared_ptr<ClientManager> clients,
     std::shared_ptr<Mime> mime,
     std::shared_ptr<Database> database,
-    std::shared_ptr<Server> server,
     std::shared_ptr<Web::SessionManager> sessionManager)
     : config(std::move(config))
     , clients(std::move(clients))
     , mime(std::move(mime))
     , database(std::move(database))
-    , server(std::move(server))
     , session_manager(std::move(sessionManager))
 {
 }
