@@ -30,7 +30,7 @@
 
 // forward declaration
 class Config;
-class Clients;
+class ClientManager;
 class Database;
 class Mime;
 class Server;
@@ -42,10 +42,9 @@ class SessionManager;
 class Context {
 public:
     Context(std::shared_ptr<Config> config,
-        std::shared_ptr<Clients> clients,
+        std::shared_ptr<ClientManager> clients,
         std::shared_ptr<Mime> mime,
         std::shared_ptr<Database> database,
-        std::shared_ptr<Server> server,
         std::shared_ptr<Web::SessionManager> sessionManager);
 
     std::shared_ptr<Config> getConfig() const
@@ -53,7 +52,7 @@ public:
         return config;
     }
 
-    std::shared_ptr<Clients> getClients() const
+    std::shared_ptr<ClientManager> getClients() const
     {
         return clients;
     }
@@ -68,11 +67,6 @@ public:
         return database;
     }
 
-    std::shared_ptr<Server> getServer() const
-    {
-        return server;
-    }
-
     std::shared_ptr<Web::SessionManager> getSessionManager() const
     {
         return session_manager;
@@ -80,10 +74,9 @@ public:
 
 private:
     std::shared_ptr<Config> config;
-    std::shared_ptr<Clients> clients;
+    std::shared_ptr<ClientManager> clients;
     std::shared_ptr<Mime> mime;
     std::shared_ptr<Database> database;
-    std::shared_ptr<Server> server;
     std::shared_ptr<Web::SessionManager> session_manager;
 };
 
