@@ -36,17 +36,18 @@
 #include <unordered_set>
 #include <vector>
 
+#include "content/autoscan.h"
 #include "util/grb_fs.h"
 
 // forward declaration
-class AutoscanDirectory;
 class AutoscanList;
 class CdsContainer;
 class CdsObject;
+struct ClientCacheEntry;
+class ClientStatusDetail;
 class Config;
 class ConfigValue;
 class Mime;
-enum class ScanMode;
 class Timer;
 
 #define BROWSE_DIRECT_CHILDREN 0x00000001
@@ -64,15 +65,16 @@ protected:
     int startingIndex {};
     int requestedCount {};
     std::string sortCrit;
+    std::string group;
     bool showDynamicContainers { true };
 
     // output parameters
     int totalMatches {};
 
 public:
-    BrowseParam(const std::shared_ptr<CdsObject>& object, unsigned int flags)
+    BrowseParam(std::shared_ptr<CdsObject> object, unsigned int flags)
         : flags(flags)
-        , object(object)
+        , object(std::move(object))
     {
     }
 
@@ -102,6 +104,11 @@ public:
         this->sortCrit = sortCrit;
     }
 
+    void setGroup(const std::string& group)
+    {
+        this->group = group;
+    }
+
     void setDynamicContainers(bool showDynamicContainers)
     {
         this->showDynamicContainers = showDynamicContainers;
@@ -112,6 +119,7 @@ public:
     int getRequestedCount() const { return requestedCount; }
     int getTotalMatches() const { return totalMatches; }
     const std::string& getSortCriteria() const { return sortCrit; }
+    const std::string& getGroup() const { return group; }
 
     void setTotalMatches(int totalMatches)
     {
@@ -127,23 +135,27 @@ protected:
     int startingIndex;
     int requestedCount;
     bool searchableContainers;
+    std::string group;
 
 public:
     SearchParam(std::string containerID, std::string searchCriteria, std::string sortCriteria, int startingIndex,
-        int requestedCount, bool searchableContainers)
+        int requestedCount, bool searchableContainers, std::string group)
         : containerID(std::move(containerID))
         , searchCrit(std::move(searchCriteria))
         , sortCrit(std::move(sortCriteria))
         , startingIndex(startingIndex)
         , requestedCount(requestedCount)
         , searchableContainers(searchableContainers)
+        , group(std::move(group))
     {
     }
     const std::string& searchCriteria() const { return searchCrit; }
+    const std::string& getContainerID() const { return containerID; }
     bool getSearchableContainers() const { return searchableContainers; }
     int getStartingIndex() const { return startingIndex; }
     int getRequestedCount() const { return requestedCount; }
     const std::string& getSortCriteria() const { return sortCrit; }
+    const std::string& getGroup() const { return group; }
 };
 
 class Database {
@@ -215,6 +227,7 @@ public:
 
     /* utility methods */
     virtual std::shared_ptr<CdsObject> loadObject(int objectID) = 0;
+    virtual std::shared_ptr<CdsObject> loadObject(const std::string& group, int objectID) = 0;
     virtual int getChildCount(int contId, bool containers = true, bool items = true, bool hideFsRoot = false) = 0;
     virtual std::map<int, int> getChildCounts(const std::vector<int>& contId, bool containers = true, bool items = true, bool hideFsRoot = false) = 0;
 
@@ -264,14 +277,22 @@ public:
     virtual void storeInternalSetting(const std::string& key, const std::string& value) = 0;
 
     /* autoscan methods */
-    virtual std::shared_ptr<AutoscanList> getAutoscanList(ScanMode scanode) = 0;
-    virtual void updateAutoscanList(ScanMode scanmode, const std::shared_ptr<AutoscanList>& list) = 0;
+    virtual std::shared_ptr<AutoscanList> getAutoscanList(AutoscanDirectory::ScanMode scanode) = 0;
+    virtual void updateAutoscanList(AutoscanDirectory::ScanMode scanmode, const std::shared_ptr<AutoscanList>& list) = 0;
 
     /* config methods */
     virtual std::vector<ConfigValue> getConfigValues() = 0;
     virtual void removeConfigValue(const std::string& item) = 0;
     virtual void updateConfigValue(const std::string& key, const std::string& item, const std::string& value, const std::string& status = "unchanged") = 0;
 
+    /* clients methods */
+    virtual std::vector<ClientCacheEntry> getClients() = 0;
+    virtual void saveClients(const std::vector<ClientCacheEntry>& cache) = 0;
+    virtual std::shared_ptr<ClientStatusDetail> getPlayStatus(const std::string& group, int objectId) = 0;
+    virtual void savePlayStatus(const std::shared_ptr<ClientStatusDetail>& detail) = 0;
+    virtual std::vector<std::shared_ptr<ClientStatusDetail>> getPlayStatusList(int objectId) = 0;
+    virtual std::vector<std::map<std::string, std::string>> getClientGroupStats() = 0;
+
     /// \brief returns the AutoscanDirectory for the given objectID or nullptr if
     /// it's not an autoscan start point - scan id will be invalid
     /// \param objectID the object id to get the AutoscanDirectory for
