@@ -677,10 +677,8 @@ std::string SortParser::parse(std::string& addColumns, std::string& addJoin)
         } else {
             log_warning("Unknown sort direction '{}' in '{}'", seg, sortCrit);
         }
-        auto sortSql = colMapper ? colMapper->mapQuoted(seg) : "";
-        if (!sortSql.empty()) {
-            sort.push_back(fmt::format("{} {}", sortSql, (desc ? "DESC" : "ASC")));
-        } else {
+        if (!colMapper || !colMapper->mapQuotedList(sort, seg, (desc ? "DESC" : "ASC"))) {
+            std::string sortSql;
             for (auto&& metaId : MetadataIterator()) {
                 auto&& metaName = MetadataHandler::getMetaFieldName(metaId);
                 if (metaName == seg) {
@@ -691,7 +689,7 @@ std::string SortParser::parse(std::string& addColumns, std::string& addJoin)
                 log_debug("Sort by meta data '{}'", sortSql);
                 auto metaAlias = fmt::format("meta_prop{}", cnt);
                 colBuf.push_back(fmt::format("{}.{}", metaMapper->quote(metaAlias), metaMapper->mapQuoted(META_VALUE, true)));
-                joinBuf.push_back(fmt::format("INNER JOIN {0} {1} ON {2} = {1}.{3} AND {1}.{4} = '{5}'",
+                joinBuf.push_back(fmt::format("LEFT JOIN {0} {1} ON {2} = {1}.{3} AND {1}.{4} = '{5}'",
                     metaMapper->getTableName(), metaMapper->quote(metaAlias),
                     colMapper->mapQuoted(UPNP_SEARCH_ID),
                     metaMapper->mapQuoted(UPNP_SEARCH_ID, true),
