@@ -31,8 +31,6 @@
 
 #include "sqlite_database.h" // API
 
-#include <array>
-
 #include "config/config_manager.h"
 
 #define DB_BACKUP_FORMAT "{}.backup"
@@ -48,8 +46,10 @@ Sqlite3Database::Sqlite3Database(const std::shared_ptr<Config>& config, const st
     table_quote_begin = '"';
     table_quote_end = '"';
 
-    // if sqlite3.sql or sqlite3-upgrade.xml is changed hashies have to be updated, index 0 is used for create script
-    hashies = { 3035716215, 778996897, 3362507034, 853149842, 4035419264, 3497064885, 974692115, 119767663, 3167732653, 2427825904, 3305506356, 43189396, 2767540493, 2512852146, 1273710965 };
+    // if sqlite3.sql or sqlite3-upgrade.xml is changed hashies have to be updated
+    hashies = { 3585221191, // index 0 is used for create script sqlite3.sql
+        778996897, 3362507034, 853149842, 4035419264, 3497064885, 974692115, 119767663, 3167732653, 2427825904, 3305506356, // upgrade 1-10
+        43189396, 2767540493, 2512852146, 1273710965, 319062951, 3593597366, 1028160353, 2644417837 };
 }
 
 void Sqlite3Database::prepare()
@@ -66,17 +66,18 @@ void Sqlite3Database::init()
     SQLDatabase::init();
 
     fs::path dbFilePath = config->getOption(CFG_SERVER_STORAGE_SQLITE_DATABASE_FILE);
+    auto dbFile = GrbFile(dbFilePath);
     log_debug("SQLite path: {}", dbFilePath.c_str());
 
     // check for db-file
-    if (access(dbFilePath.c_str(), R_OK | W_OK) != 0 && errno != ENOENT)
+    if (!dbFile.isWritable())
         throw DatabaseException("", fmt::format("Error while accessing sqlite database file ({}): {}", dbFilePath.c_str(), std::strerror(errno)));
 
     taskQueueOpen = true;
     threadRunner = std::make_unique<StdThreadRunner>(
         "SQLiteThread", [](void* arg) {
             auto inst = static_cast<Sqlite3Database*>(arg);
-            inst->threadProc(); }, this, config);
+            inst->threadProc(); }, this);
 
     if (!threadRunner->isAlive()) {
         throw DatabaseException("", fmt::format("Could not start sqlite thread: {}", std::strerror(errno)));
@@ -90,23 +91,24 @@ void Sqlite3Database::init()
     // try to detect already active database client and terminate before doing any harm
     try {
         prepare();
-    } catch (const std::runtime_error& e) {
+    } catch (const std::runtime_error&) {
         shutdown();
         throw_std_runtime_error("Sqlite3Database.init: could not open '{}' exclusively", dbFilePath.c_str());
     }
 
     std::string dbVersion;
     fs::path dbFilePathbackup = fmt::format(DB_BACKUP_FORMAT, dbFilePath.c_str());
+    auto dbBackupFile = GrbFile(dbFilePathbackup);
     try {
         dbVersion = getInternalSetting("db_version");
-    } catch (const std::runtime_error& e) {
+    } catch (const std::runtime_error&) {
         log_warning("Sqlite3 database seems to be corrupt or doesn't exist yet.");
         // database seems to be corrupt or nonexistent
         if (config->getBoolOption(CFG_SERVER_STORAGE_SQLITE_RESTORE) && sqliteStatus == SQLITE_OK) {
             // try to restore database
 
             // checking for backup file
-            if (access(dbFilePathbackup.c_str(), R_OK) == 0) {
+            if (dbBackupFile.isReadable()) {
                 try {
                     // trying to copy backup file
                     auto btask = std::make_shared<SLBackupTask>(config, true);
@@ -114,7 +116,7 @@ void Sqlite3Database::init()
                     btask->waitForTask();
                     prepare();
                     dbVersion = getInternalSetting("db_version");
-                } catch (const std::runtime_error& err) {
+                } catch (const std::runtime_error&) {
                 }
             }
         } else {
@@ -124,13 +126,14 @@ void Sqlite3Database::init()
         }
     }
 
-    if (dbVersion.empty() && access(dbFilePathbackup.c_str(), R_OK) != 0) {
+    if (dbVersion.empty() && !dbBackupFile.isReadable()) {
         log_info("No sqlite3 backup is available or backup is corrupt. Automatically creating new database file...");
         auto itask = std::make_shared<SLInitTask>(config, hashies[0]);
         addTask(itask);
         try {
             itask->waitForTask();
             prepare();
+            dbFile.setPermissions();
             dbVersion = getInternalSetting("db_version");
         } catch (const std::runtime_error& e) {
             shutdown();
@@ -323,7 +326,7 @@ void Sqlite3Database::threadProc()
             }
             db = nullptr;
         }
-    } catch (const std::runtime_error& e) {
+    } catch (const std::runtime_error&) {
         log_error("Aborting thread");
     }
 }
@@ -520,21 +523,23 @@ void SLExecTask::run(sqlite3*& db, Sqlite3Database* sl)
 SLBackupTask::SLBackupTask(std::shared_ptr<Config> config, bool restore)
     : config(std::move(config))
     , restore(restore)
+    , dbFile(this->config->getOption(CFG_SERVER_STORAGE_SQLITE_DATABASE_FILE))
+    , dbBackupFile(fmt::format(DB_BACKUP_FORMAT, this->config->getOption(CFG_SERVER_STORAGE_SQLITE_DATABASE_FILE)))
 {
 }
 
 void SLBackupTask::run(sqlite3*& db, Sqlite3Database* sl)
 {
     log_debug("Running: backup");
-    fs::path dbFilePath = config->getOption(CFG_SERVER_STORAGE_SQLITE_DATABASE_FILE);
 
     if (!restore) {
         try {
             fs::copy(
-                dbFilePath,
-                fmt::format(DB_BACKUP_FORMAT, dbFilePath.c_str()),
+                dbFile.getPath(),
+                dbBackupFile.getPath(),
                 fs::copy_options::overwrite_existing);
             log_debug("sqlite3 backup successful");
+            dbBackupFile.setPermissions();
             decontamination = true;
         } catch (const std::runtime_error& e) {
             log_error("error while making sqlite3 backup: {}", e.what());
@@ -544,13 +549,14 @@ void SLBackupTask::run(sqlite3*& db, Sqlite3Database* sl)
         sqlite3_close(db);
         try {
             fs::copy(
-                fmt::format(DB_BACKUP_FORMAT, dbFilePath.c_str()),
-                dbFilePath,
+                dbBackupFile.getPath(),
+                dbFile.getPath(),
                 fs::copy_options::overwrite_existing);
+            dbFile.setPermissions();
         } catch (const std::runtime_error& e) {
             throw DatabaseException(fmt::format("Error while restoring sqlite3 backup: {}", e.what()), fmt::format("Error while restoring sqlite3 backup: {}", e.what()));
         }
-        int res = sqlite3_open(dbFilePath.c_str(), &db);
+        int res = sqlite3_open(dbFile.getPath().c_str(), &db);
         if (res != SQLITE_OK) {
             throw DatabaseException("", "error while restoring sqlite3 backup: could not reopen sqlite3 database after restore");
         }
