@@ -40,9 +40,11 @@
 #include "iohandler/file_io_handler.h"
 #include "metadata/metadata_handler.h"
 #include "transcoding/transcode_dispatcher.h"
+#include "util/grb_net.h"
 #include "util/tools.h"
 #include "util/upnp_headers.h"
 #include "util/upnp_quirks.h"
+#include "util/url_utils.h"
 #include "web/session_manager.h"
 
 FileRequestHandler::FileRequestHandler(const std::shared_ptr<ContentManager>& content, std::shared_ptr<UpnpXMLBuilder> xmlBuilder)
@@ -57,7 +59,7 @@ void FileRequestHandler::getInfo(const char* filename, UpnpFileInfo* info)
 
     auto quirks = getQuirks(info);
 
-    auto params = parseParameters(filename, LINK_FILE_REQUEST_HANDLER);
+    auto params = URLUtils::parseParameters(filename, LINK_FILE_REQUEST_HANDLER);
     auto obj = loadObject(params);
 
     auto resourceId = parseResourceInfo(params);
@@ -76,7 +78,7 @@ void FileRequestHandler::getInfo(const char* filename, UpnpFileInfo* info)
     // Check if the resource is actually another external file, and if it exists
     bool isResourceFile = false;
 
-    auto resPath = resource->getAttribute(R_RESOURCE_FILE);
+    auto resPath = resource->getAttribute(CdsResource::Attribute::RESOURCE_FILE);
     isResourceFile = !resPath.empty() && resPath != obj->getLocation();
     if (isResourceFile) {
         log_debug("Resource is file: {}", path.string());
@@ -91,7 +93,7 @@ void FileRequestHandler::getInfo(const char* filename, UpnpFileInfo* info)
         if (isResourceFile) {
             throw SubtitlesNotFoundException(fmt::format("Subtitle file {} is not available.", path.c_str()));
         }
-        throw_std_runtime_error("Failed to open {}: {}", path.c_str(), std::strerror(errno));
+        throw_fmt_system_error("Failed to open {}", path.c_str());
     }
 
     // If we get to here we can read the thing
@@ -106,10 +108,10 @@ void FileRequestHandler::getInfo(const char* filename, UpnpFileInfo* info)
     auto item = std::dynamic_pointer_cast<CdsItem>(obj);
     std::string mimeType = item ? item->getMimeType() : "";
 
-    if (resource->getHandlerType() != CH_DEFAULT) {
+    if (resource->getHandlerType() != ContentHandler::DEFAULT) {
         auto metadataHandler = getResourceMetadataHandler(obj, resource);
 
-        std::string protocolInfo = getValueOrDefault(resource->getAttributes(), "protocolInfo");
+        std::string protocolInfo = resource->getAttribute(CdsResource::Attribute::PROTOCOLINFO);
         if (!protocolInfo.empty()) {
             mimeType = getMTFromProtocolInfo(protocolInfo);
         }
@@ -137,8 +139,9 @@ void FileRequestHandler::getInfo(const char* filename, UpnpFileInfo* info)
         // TODO: this WAV specific logic should be more generic
         auto mappings = config->getDictionaryOption(CFG_IMPORT_MAPPINGS_MIMETYPE_TO_CONTENTTYPE_LIST);
         if (getValueOrDefault(mappings, mimeType) == CONTENT_TYPE_PCM) {
-            std::string freq = obj->getResource(0)->getAttribute(R_SAMPLEFREQUENCY);
-            std::string nrch = obj->getResource(0)->getAttribute(R_NRAUDIOCHANNELS);
+            auto res = obj->getResource(ContentHandler::DEFAULT);
+            std::string freq = res->getAttribute(CdsResource::Attribute::SAMPLEFREQUENCY);
+            std::string nrch = res->getAttribute(CdsResource::Attribute::NRAUDIOCHANNELS);
             if (!freq.empty())
                 mimeType += fmt::format(";rate={}", freq);
             if (!nrch.empty())
@@ -157,7 +160,7 @@ void FileRequestHandler::getInfo(const char* filename, UpnpFileInfo* info)
 
         // Generate DNLA Headers
         auto mappings = config->getDictionaryOption(CFG_IMPORT_MAPPINGS_MIMETYPE_TO_CONTENTTYPE_LIST);
-        std::string dlnaContentHeader = getDLNAContentHeader(config, getValueOrDefault(mappings, mimeType), resource ? resource->getAttribute(R_VIDEOCODEC) : "", resource ? resource->getAttribute(R_AUDIOCODEC) : "");
+        std::string dlnaContentHeader = xmlBuilder->getDLNAContentHeader(getValueOrDefault(mappings, mimeType), resource);
         if (!dlnaContentHeader.empty()) {
             headers.addHeader(UPNP_DLNA_CONTENT_FEATURES_HEADER, dlnaContentHeader);
         }
@@ -166,7 +169,7 @@ void FileRequestHandler::getInfo(const char* filename, UpnpFileInfo* info)
     if (mimeType.empty() && item)
         mimeType = item->getMimeType();
 
-    std::string dlnaTransferHeader = getDLNATransferHeader(config, mimeType);
+    std::string dlnaTransferHeader = xmlBuilder->getDLNATransferHeader(mimeType);
     if (!dlnaTransferHeader.empty()) {
         headers.addHeader(UPNP_DLNA_TRANSFER_MODE_HEADER, dlnaTransferHeader);
     }
@@ -187,7 +190,7 @@ void FileRequestHandler::getInfo(const char* filename, UpnpFileInfo* info)
 
 std::unique_ptr<MetadataHandler> FileRequestHandler::getResourceMetadataHandler(const std::shared_ptr<CdsObject>& obj, const std::shared_ptr<CdsResource>& resource) const
 {
-    int resHandler = resource->getHandlerType();
+    auto resHandler = resource->getHandlerType();
     return MetadataHandler::createHandler(context, resHandler);
 }
 
@@ -200,12 +203,12 @@ std::unique_ptr<IOHandler> FileRequestHandler::open(const char* filename, enum U
         throw_std_runtime_error("UPNP_WRITE unsupported");
     }
 
-    auto params = parseParameters(filename, LINK_FILE_REQUEST_HANDLER);
+    auto params = URLUtils::parseParameters(filename, LINK_FILE_REQUEST_HANDLER);
     auto obj = loadObject(params);
     auto resourceId = parseResourceInfo(params);
 
     // Serve metadata resources
-    if (obj->getResource(resourceId)->getHandlerType() != CH_DEFAULT) {
+    if (obj->getResource(resourceId)->getHandlerType() != ContentHandler::DEFAULT) {
         auto resource = obj->getResource(resourceId);
         auto metadataHandler = getResourceMetadataHandler(obj, resource);
         return metadataHandler->serveContent(obj, resourceId);
@@ -213,7 +216,11 @@ std::unique_ptr<IOHandler> FileRequestHandler::open(const char* filename, enum U
 
     auto path = obj->getLocation();
 
-    content->triggerPlayHook(obj);
+    auto it = params.find(CLIENT_GROUP_TAG);
+    std::string group = DEFAULT_CLIENT_GROUP;
+    if (it != params.end()) {
+        group = it->second;
+    }
 
     // Transcoding
     std::string trProfile = getValueOrDefault(params, URL_PARAM_TRANSCODE_PROFILE_NAME);
@@ -225,9 +232,11 @@ std::unique_ptr<IOHandler> FileRequestHandler::open(const char* filename, enum U
         std::string range = getValueOrDefault(params, "range");
 
         auto transcodeDispatcher = std::make_unique<TranscodeDispatcher>(content);
-        return transcodeDispatcher->serveContent(transcodingProfile, path, obj, range);
+        return transcodeDispatcher->serveContent(transcodingProfile, path, obj, group, range);
     }
 
+    content->triggerPlayHook(group, obj);
+
     // Boring old file
     return std::make_unique<FileIOHandler>(path);
 }
@@ -250,8 +259,8 @@ std::size_t FileRequestHandler::parseResourceInfo(std::map<std::string, std::str
 
 std::unique_ptr<Quirks> FileRequestHandler::getQuirks(const UpnpFileInfo* info) const
 {
-    const struct sockaddr_storage* ctrlPtIPAddr = UpnpFileInfo_get_CtrlPtIPAddr(info);
+    auto ctrlPtIPAddr = std::make_shared<GrbNet>(UpnpFileInfo_get_CtrlPtIPAddr(info));
     // HINT: most clients do not report exactly the same User-Agent for UPnP services and file request.
     std::string userAgent = UpnpFileInfo_get_Os_cstr(info);
-    return std::make_unique<Quirks>(context, ctrlPtIPAddr, std::move(userAgent));
+    return std::make_unique<Quirks>(*xmlBuilder, *context->getClients(), ctrlPtIPAddr, std::move(userAgent));
 }
