@@ -50,7 +50,7 @@ void IOHandlerBufferHelper::open(enum UpnpOpenFileMode mode)
     if (isOpen)
         throw_std_runtime_error("tried to reopen an open IOHandlerBufferHelper");
 
-    buffer = new char[bufSize];
+    buffer = new std::byte[bufSize];
     startBufferThread();
     isOpen = true;
 }
@@ -61,7 +61,7 @@ IOHandlerBufferHelper::~IOHandlerBufferHelper() noexcept
         close();
 }
 
-std::size_t IOHandlerBufferHelper::read(char* buf, std::size_t length)
+std::size_t IOHandlerBufferHelper::read(std::byte* buf, std::size_t length)
 {
     // check read on closed BufferedIOHandler
     assert(isOpen);
@@ -73,7 +73,7 @@ std::size_t IOHandlerBufferHelper::read(char* buf, std::size_t length)
         "IOHandlerBufferHelper", [this] { return threadRunner != nullptr; }, 100);
     auto lock = threadRunner->uniqueLock();
 
-    while ((empty || waitForInitialFillSize) && !(threadShutdown || eof || readError)) {
+    while ((empty || waitForInitialFillSize) && !threadShutdown && !eof && !readError) {
         if (checkSocket) {
             checkSocket = false;
             return CHECK_SOCKET;
@@ -181,7 +181,7 @@ void IOHandlerBufferHelper::startBufferThread()
             auto inst = static_cast<IOHandlerBufferHelper*>(arg);
             inst->threadProc();
         },
-        this, config);
+        this);
 }
 
 void IOHandlerBufferHelper::stopBufferThread()
