@@ -93,8 +93,9 @@ void FfmpegHandler::addFfmpegMetadataFields(const std::shared_ptr<CdsItem>& item
     auto sc = StringConverter::m2i(CFG_IMPORT_LIBOPTS_FFMPEG_CHARSET, item->getLocation(), config);
 
     while ((e = av_dict_get(pFormatCtx->metadata, "", e, AV_DICT_IGNORE_SUFFIX))) {
-        std::string key = e->key;
+        std::string key = toLower(e->key);
         std::string value = e->value;
+        log_debug("FFMpeg tag: {}: {}", key, value);
         auto it = specialPropertyMap.find(e->key);
         if (it != specialPropertyMap.end()) {
             // only use ffmpeg meta data if not found by other handler
@@ -105,7 +106,9 @@ void FfmpegHandler::addFfmpegMetadataFields(const std::shared_ptr<CdsItem>& item
             }
         }
         auto pIt = std::find_if(propertyMap.begin(), propertyMap.end(),
-            [&](auto&& p) { return p.second == key && item->getMetaData(p.first).empty(); });
+            [&](auto&& p) {
+                return p.second == key && item->getMetaData(p.first).empty();
+            });
         if (pIt != propertyMap.end()) {
             log_debug("Identified default metadata '{}': {}", pIt->second, value);
             const auto field = pIt->first;
@@ -128,7 +131,7 @@ void FfmpegHandler::addFfmpegMetadataFields(const std::shared_ptr<CdsItem>& item
             constexpr auto field = M_CREATION_DATE;
             if (item->getMetaData(field).empty()) {
                 log_debug("Identified metadata 'creation_time': {}", e->value);
-                std::tm tmWork;
+                std::tm tmWork {};
                 if (strptime(e->value, "%Y-%m-%dT%T.000000%Z", &tmWork)) {
                     // convert creation_time to local time
                     auto utcTime = timegm(&tmWork);
@@ -143,22 +146,24 @@ void FfmpegHandler::addFfmpegMetadataFields(const std::shared_ptr<CdsItem>& item
                 auto mDate = fmt::format("{:%Y-%m-%d}", tmWork);
                 item->addMetaData(field, mDate);
             }
+        } else {
+            log_debug("Unhandled metadata {} = '{}'", key, value);
         }
     }
 }
 
 // ffmpeg library calls
-void FfmpegHandler::addFfmpegResourceFields(const std::shared_ptr<CdsItem>& item, const AVFormatContext* pFormatCtx) const
+void FfmpegHandler::addFfmpegResourceFields(const std::shared_ptr<CdsItem>& item, const AVFormatContext* pFormatCtx)
 {
-    auto resource = item->getResource(0);
-    bool isAudioFile = item->getClass() == UPNP_CLASS_MUSIC_TRACK && item->getResourceCount() > 1 && item->getResource(1)->isMetaResource(ID3_ALBUM_ART);
-    auto resource2 = isAudioFile ? item->getResource(1) : item->getResource(0);
+    auto resource = item->getResource(ContentHandler::DEFAULT);
+    bool isAudioFile = item->isSubClass(UPNP_CLASS_AUDIO_ITEM) && item->getResource(CdsResource::Purpose::Thumbnail);
+    auto resource2 = isAudioFile ? item->getResource(CdsResource::Purpose::Thumbnail) : item->getResource(ContentHandler::DEFAULT);
 
     // duration
     if (pFormatCtx->duration > 0) {
         auto duration = millisecondsToHMSF(pFormatCtx->duration / (AV_TIME_BASE / 1000));
         log_debug("Added duration: {}", duration);
-        resource->addAttribute(R_DURATION, duration);
+        resource->addAttribute(CdsResource::Attribute::DURATION, duration);
     }
 
     // bitrate
@@ -167,7 +172,7 @@ void FfmpegHandler::addFfmpegResourceFields(const std::shared_ptr<CdsItem>& item
         // See http://www.upnp.org/schemas/av/didl-lite-v3.xsd
         auto bitrate = pFormatCtx->bit_rate / 8;
         log_debug("Added bitrate: {} kb/s", bitrate);
-        resource->addAttribute(R_BITRATE, fmt::to_string(bitrate));
+        resource->addAttribute(CdsResource::Attribute::BITRATE, fmt::to_string(bitrate));
     }
 
     // video resolution, audio sampling rate, nr of audio channels
@@ -178,7 +183,7 @@ void FfmpegHandler::addFfmpegResourceFields(const std::shared_ptr<CdsItem>& item
 
         if (st && !videoSet && as_codecpar(st)->codec_type == AVMEDIA_TYPE_VIDEO) {
             auto codecId = as_codecpar(st)->codec_id;
-            resource2->addAttribute(R_VIDEOCODEC, avcodec_get_name(codecId));
+            resource2->addAttribute(CdsResource::Attribute::VIDEOCODEC, avcodec_get_name(codecId));
 
             if (as_codecpar(st)->codec_tag > 0) {
                 char fourcc[5];
@@ -198,13 +203,13 @@ void FfmpegHandler::addFfmpegResourceFields(const std::shared_ptr<CdsItem>& item
                 auto resolution = fmt::format("{}x{}", as_codecpar(st)->width, as_codecpar(st)->height);
 
                 log_debug("Added resolution: {} pixel from stream {}", resolution, i);
-                resource2->addAttribute(R_RESOLUTION, resolution);
+                resource2->addAttribute(CdsResource::Attribute::RESOLUTION, resolution);
                 videoSet = true;
             }
         }
         if (st && !audioSet && as_codecpar(st)->codec_type == AVMEDIA_TYPE_AUDIO) {
             auto codecId = as_codecpar(st)->codec_id;
-            resource->addAttribute(R_AUDIOCODEC, avcodec_get_name(codecId));
+            resource->addAttribute(CdsResource::Attribute::AUDIOCODEC, avcodec_get_name(codecId));
             // find the first stream that has a valid sample rate
 
             if (as_codecpar(st)->sample_rate > 0) {
@@ -216,15 +221,21 @@ void FfmpegHandler::addFfmpegResourceFields(const std::shared_ptr<CdsItem>& item
                 int bitsPerSample = as_codecpar(st)->bits_per_coded_sample;
                 log_debug("Bits per coded sample: {}", bitsPerSample);
 
-                sampleFreq *= bitsPerSample > 0 ? bitsPerSample : 1;
+                if (bitsPerSample > 0) {
+                    resource->addAttribute(CdsResource::Attribute::BITS_PER_SAMPLE, fmt::to_string(bitsPerSample));
+                } else {
+                    bitsPerSample = 1;
+                }
+
+                sampleFreq *= bitsPerSample;
                 log_debug("Added sample frequency: {} Hz from stream {}", sampleFreq, i);
-                resource->addAttribute(R_SAMPLEFREQUENCY, fmt::to_string(sampleFreq));
+                resource->addAttribute(CdsResource::Attribute::SAMPLEFREQUENCY, fmt::to_string(sampleFreq));
                 audioSet = true;
 
                 int audioCh = as_codecpar(st)->channels;
                 if (audioCh > 0) {
                     log_debug("Added number of audio channels: {} from stream {}", audioCh, i);
-                    resource->addAttribute(R_NRAUDIOCHANNELS, fmt::to_string(audioCh));
+                    resource->addAttribute(CdsResource::Attribute::NRAUDIOCHANNELS, fmt::to_string(audioCh));
                 }
             }
         }
