@@ -132,10 +132,10 @@ void MatroskaHandler::parseMKV(const std::shared_ptr<CdsItem>& item, std::unique
          elL0 = ebmlStream.FindNextElement(LIBMATROSKA_NAMESPACE::KaxSegment_Context, iUpperLevel, ~0, true)) {
         iUpperLevel = 0;
         EbmlElement* elL1;
-        while ((elL1 = ebmlStream.FindNextElement(elL0->Generic().Context, iUpperLevel, ~0, true))) {
+        while ((elL1 = ebmlStream.FindNextElement(EBML_CONTEXT(elL0), iUpperLevel, ~0, true))) {
             parseLevel1Element(item, ebmlFile, ebmlStream, elL1, pIoHandler);
 
-            delete (elL1->SkipData(ebmlStream, elL1->Generic().Context));
+            delete (elL1->SkipData(ebmlStream, EBML_CONTEXT(elL1)));
             delete elL1;
             if (activeFlag == 0) // terminate search
                 break;
@@ -262,7 +262,7 @@ void MatroskaHandler::parseInfo(const std::shared_ptr<CdsItem>& item, LIBEBML_NA
                 log_error("Malformed MKV file; KaxDateUTC cast failed!");
                 continue;
             }
-            auto fDate = fmt::format("{:%Y-%m-%d}", fmt::gmtime(dateEl->GetEpochDate()));
+            auto fDate = fmt::format("{:%FT%T%z}", fmt::gmtime(dateEl->GetEpochDate()));
             if (!fDate.empty()) {
                 log_debug("KaxDateUTC = {}", fDate);
                 item->addMetaData(M_DATE, sc->convert(fDate));
@@ -278,7 +278,7 @@ void MatroskaHandler::parseInfo(const std::shared_ptr<CdsItem>& item, LIBEBML_NA
             auto fDuration = millisecondsToHMSF(double(*static_cast<EbmlFloat*>(durationEl)));
             log_debug("KaxDuration = {}", fDuration);
             if (item->getResourceCount() > 0) {
-                item->getResource(0)->addAttribute(R_DURATION, sc->convert(fDuration));
+                item->getResource(ContentHandler::DEFAULT)->addAttribute(CdsResource::Attribute::DURATION, sc->convert(fDuration));
             }
             activeFlag &= ~GRB_MATROSKA_DURATION;
         }
@@ -339,9 +339,8 @@ void MatroskaHandler::addArtworkResource(const std::shared_ptr<CdsItem>& item, c
     log_debug("Found artwork of type {} in file {}", artMimetype, item->getLocation().c_str());
 
     if (artMimetype != MIMETYPE_DEFAULT) {
-        auto resource = std::make_shared<CdsResource>(CH_MATROSKA);
-        resource->addAttribute(R_PROTOCOLINFO, renderProtocolInfo(artMimetype));
-        resource->addParameter(RESOURCE_CONTENT_TYPE, ID3_ALBUM_ART);
+        auto resource = std::make_shared<CdsResource>(ContentHandler::MATROSKA, CdsResource::Purpose::Thumbnail);
+        resource->addAttribute(CdsResource::Attribute::PROTOCOLINFO, renderProtocolInfo(artMimetype));
         item->addResource(resource);
     }
 }
