@@ -31,6 +31,8 @@
 
 #include "metadata_handler.h" // API
 
+#include <array>
+
 #include "cds_objects.h"
 #include "config/config_manager.h"
 #include "content/scripting/script_names.h"
@@ -56,6 +58,10 @@
 #include "metadata/matroska_handler.h"
 #endif
 
+#ifdef HAVE_WAVPACK
+#include "metadata/wavpack_handler.h"
+#endif
+
 #include "ffmpeg_thumbnailer_handler.h"
 #include "metadata/metacontent_handler.h"
 
@@ -74,9 +80,9 @@ void MetadataHandler::extractMetaData(const std::shared_ptr<Context>& context, c
 
     std::string mimetype = item->getMimeType();
 
-    auto resource = std::make_shared<CdsResource>(CH_DEFAULT);
-    resource->addAttribute(R_PROTOCOLINFO, renderProtocolInfo(mimetype));
-    resource->addAttribute(R_SIZE, fmt::to_string(filesize));
+    auto resource = std::make_shared<CdsResource>(ContentHandler::DEFAULT, CdsResource::Purpose::Content);
+    resource->addAttribute(CdsResource::Attribute::PROTOCOLINFO, renderProtocolInfo(mimetype));
+    resource->addAttribute(CdsResource::Attribute::SIZE, fmt::to_string(filesize));
 
     item->addResource(resource);
     item->clearMetaData();
@@ -96,7 +102,7 @@ void MetadataHandler::extractMetaData(const std::shared_ptr<Context>& context, c
 #endif // HAVE_TAGLIB
 
 #ifdef HAVE_EXIV2
-    if (contentType == CONTENT_TYPE_JPG) {
+    if (startswith(itemCls, UPNP_CLASS_IMAGE_ITEM)) {
         Exiv2Handler(context).fillMetadata(item);
     }
 #endif
@@ -113,33 +119,39 @@ void MetadataHandler::extractMetaData(const std::shared_ptr<Context>& context, c
     }
 #endif
 
+#ifdef HAVE_WAVPACK
+    if (contentType == CONTENT_TYPE_WAVPACK) {
+        WavPackHandler(context).fillMetadata(item);
+    }
+#endif
+
 #ifdef HAVE_FFMPEG
-    if (contentType != CONTENT_TYPE_PLAYLIST && (itemCls == UPNP_CLASS_MUSIC_TRACK || itemCls == UPNP_CLASS_VIDEO_ITEM)) {
+    if (contentType != CONTENT_TYPE_PLAYLIST && (startswith(itemCls, UPNP_CLASS_AUDIO_ITEM) || startswith(itemCls, UPNP_CLASS_VIDEO_ITEM))) {
         FfmpegHandler(context).fillMetadata(item);
     }
 #else
     if (contentType == CONTENT_TYPE_AVI) {
         std::string fourcc = getAVIFourCC(dirEnt.path());
         if (!fourcc.empty()) {
-            item->getResource(0)->addOption(RESOURCE_OPTION_FOURCC, fourcc);
+            resource->addOption(RESOURCE_OPTION_FOURCC, fourcc);
         }
     }
 #endif // HAVE_FFMPEG
 
 #ifdef HAVE_FFMPEGTHUMBNAILER
     // Thumbnails for videos
-    if (itemCls == UPNP_CLASS_VIDEO_ITEM)
+    if (startswith(itemCls, UPNP_CLASS_VIDEO_ITEM))
         FfmpegThumbnailerHandler(context, CFG_SERVER_EXTOPTS_FFMPEGTHUMBNAILER_VIDEO_ENABLED).fillMetadata(item);
-    else if (itemCls == UPNP_CLASS_IMAGE_ITEM)
+    else if (startswith(itemCls, UPNP_CLASS_IMAGE_ITEM))
         FfmpegThumbnailerHandler(context, CFG_SERVER_EXTOPTS_FFMPEGTHUMBNAILER_IMAGE_ENABLED).fillMetadata(item);
 #endif
 
     // Fanart for audio and video
-    if (itemCls == UPNP_CLASS_MUSIC_TRACK || itemCls == UPNP_CLASS_VIDEO_ITEM)
+    if (startswith(itemCls, UPNP_CLASS_AUDIO_ITEM) || startswith(itemCls, UPNP_CLASS_VIDEO_ITEM))
         FanArtHandler(context).fillMetadata(item);
 
     // Subtitles for videos
-    if (itemCls == UPNP_CLASS_VIDEO_ITEM)
+    if (startswith(itemCls, UPNP_CLASS_VIDEO_ITEM))
         SubtitleHandler(context).fillMetadata(item);
 
     ResourceHandler(context).fillMetadata(item);
@@ -147,51 +159,56 @@ void MetadataHandler::extractMetaData(const std::shared_ptr<Context>& context, c
 
 std::string MetadataHandler::getMetaFieldName(metadata_fields_t field)
 {
-    for (auto&& [f, s] : mt_keys) {
-        if (f == field) {
-            return s;
-        }
-    }
-    return "unknown";
+    return getValueOrDefault(mt_keys, field, { "unknown" });
 }
 
-std::string MetadataHandler::getResAttrName(resource_attributes_t attr)
-{
-    for (auto&& [f, s] : res_keys) {
-        if (f == attr) {
-            return s;
-        }
-    }
-    return "unknown";
-}
-
-std::unique_ptr<MetadataHandler> MetadataHandler::createHandler(const std::shared_ptr<Context>& context, int handlerType)
+std::unique_ptr<MetadataHandler> MetadataHandler::createHandler(const std::shared_ptr<Context>& context, ContentHandler handlerType)
 {
     switch (handlerType) {
+    case ContentHandler::LIBEXIF:
 #ifdef HAVE_LIBEXIF
-    case CH_LIBEXIF:
         return std::make_unique<LibExifHandler>(context);
+#else
+        break;
 #endif
+    case ContentHandler::ID3:
 #ifdef HAVE_TAGLIB
-    case CH_ID3:
         return std::make_unique<TagLibHandler>(context);
+#else
+        break;
 #endif
+    case ContentHandler::MATROSKA:
 #ifdef HAVE_MATROSKA
-    case CH_MATROSKA:
         return std::make_unique<MatroskaHandler>(context);
+#else
+        break;
 #endif
+    case ContentHandler::WAVPACK:
+#ifdef HAVE_WAVPACK
+        return std::make_unique<WavPackHandler>(context);
+#else
+        break;
+#endif
+    case ContentHandler::FFTH:
 #ifdef HAVE_FFMPEGTHUMBNAILER
-    case CH_FFTH:
         return std::make_unique<FfmpegThumbnailerHandler>(context, CFG_SERVER_EXTOPTS_FFMPEGTHUMBNAILER_ENABLED);
+#else
+        break;
 #endif
-    case CH_FANART:
+    case ContentHandler::FANART:
         return std::make_unique<FanArtHandler>(context);
-    case CH_CONTAINERART:
+    case ContentHandler::CONTAINERART:
         return std::make_unique<ContainerArtHandler>(context);
-    case CH_SUBTITLE:
+    case ContentHandler::SUBTITLE:
         return std::make_unique<SubtitleHandler>(context);
-    case CH_RESOURCE:
+    case ContentHandler::RESOURCE:
         return std::make_unique<ResourceHandler>(context);
+    case ContentHandler::DEFAULT:
+    case ContentHandler::TRANSCODE:
+    case ContentHandler::EXTURL:
+    case ContentHandler::MP4:
+    case ContentHandler::FLAC:
+        break;
     }
     throw_std_runtime_error("Unknown content handler ID: {}", handlerType);
 }
@@ -202,45 +219,59 @@ std::string MetadataHandler::getMimeType() const
 }
 
 static constexpr std::array chKeys = {
-    std::pair(CH_DEFAULT, "Default"),
+    std::pair(ContentHandler::DEFAULT, "Default"),
 #ifdef HAVE_LIBEXIF
-    std::pair(CH_LIBEXIF, "LibExif"),
+    std::pair(ContentHandler::LIBEXIF, "LibExif"),
 #endif
 #ifdef HAVE_TAGLIB
-    std::pair(CH_ID3, "TagLib"),
+    std::pair(ContentHandler::ID3, "TagLib"),
 #endif
-    std::pair(CH_TRANSCODE, "Transcode"),
-    std::pair(CH_EXTURL, "Exturl"),
-    std::pair(CH_MP4, "MP4"),
+    std::pair(ContentHandler::TRANSCODE, "Transcode"),
+    std::pair(ContentHandler::EXTURL, "Exturl"),
+    std::pair(ContentHandler::MP4, "MP4"),
 #ifdef HAVE_FFMPEGTHUMBNAILER
-    std::pair(CH_FFTH, "FFmpegThumbnailer"),
+    std::pair(ContentHandler::FFTH, "FFmpegThumbnailer"),
 #endif
-    std::pair(CH_FLAC, "Flac"),
-    std::pair(CH_FANART, "Fanart"),
-    std::pair(CH_CONTAINERART, "ContainerArt"),
+    std::pair(ContentHandler::FLAC, "Flac"),
+    std::pair(ContentHandler::FANART, "Fanart"),
+    std::pair(ContentHandler::CONTAINERART, "ContainerArt"),
 #ifdef HAVE_MATROSKA
-    std::pair(CH_MATROSKA, "Matroska"),
+    std::pair(ContentHandler::MATROSKA, "Matroska"),
 #endif
-    std::pair(CH_SUBTITLE, "Subtitle"),
-    std::pair(CH_RESOURCE, "Resource"),
+#ifdef HAVE_WAVPACK
+    std::pair(ContentHandler::WAVPACK, "WavPack"),
+#endif
+    std::pair(ContentHandler::SUBTITLE, "Subtitle"),
+    std::pair(ContentHandler::RESOURCE, "Resource"),
 };
 
-int MetadataHandler::remapContentHandler(const std::string& contHandler)
+bool MetadataHandler::checkContentHandler(const std::string& contHandler)
+{
+    auto chEntry = std::find_if(chKeys.begin(), chKeys.end(), [contHandler](auto&& entry) { return contHandler == entry.second; });
+    return chEntry != chKeys.end();
+}
+
+ContentHandler MetadataHandler::remapContentHandler(const std::string& contHandler)
 {
     auto chEntry = std::find_if(chKeys.begin(), chKeys.end(), [contHandler](auto&& entry) { return contHandler == entry.second; });
     if (chEntry != chKeys.end()) {
         return chEntry->first;
     }
-    return -1;
+    throw_std_runtime_error("Invalid content handler value {}", contHandler);
 }
 
-std::string MetadataHandler::mapContentHandler2String(int ch)
+ContentHandler MetadataHandler::remapContentHandler(int ch)
+{
+    return static_cast<ContentHandler>(ch);
+}
+
+std::string MetadataHandler::mapContentHandler2String(ContentHandler ch)
 {
     auto chEntry = std::find_if(chKeys.begin(), chKeys.end(), [ch](auto&& entry) { return ch == entry.first; });
     if (chEntry != chKeys.end()) {
         return chEntry->second;
     }
-    return "Unknown";
+    throw_std_runtime_error("Invalid content handler value {}", ch);
 }
 
 metadata_fields_t MetadataHandler::remapMetaDataField(std::string_view fieldName)
