@@ -32,7 +32,7 @@
 #ifndef __METADATA_HANDLER_H__
 #define __METADATA_HANDLER_H__
 
-#include <array>
+#include <set>
 
 #include "common.h"
 #include "context.h"
@@ -45,19 +45,22 @@ class CdsObject;
 class IOHandler;
 
 // content handler Id's
-#define CH_DEFAULT 0
-#define CH_LIBEXIF 1
-#define CH_ID3 2
-#define CH_TRANSCODE 3
-#define CH_EXTURL 4
-#define CH_MP4 5
-#define CH_FFTH 6
-#define CH_FLAC 7
-#define CH_FANART 8
-#define CH_MATROSKA 9
-#define CH_SUBTITLE 10
-#define CH_CONTAINERART 11
-#define CH_RESOURCE 20
+enum class ContentHandler {
+    DEFAULT = 0,
+    LIBEXIF = 1,
+    ID3 = 2,
+    TRANSCODE = 3,
+    EXTURL = 4,
+    MP4 = 5,
+    FFTH = 6,
+    FLAC = 7,
+    FANART = 8,
+    MATROSKA = 9,
+    SUBTITLE = 10,
+    CONTAINERART = 11,
+    WAVPACK = 12,
+    RESOURCE = 20,
+};
 
 #define CONTENT_TYPE_AIFF "aiff"
 #define CONTENT_TYPE_APE "ape"
@@ -80,14 +83,6 @@ class IOHandler;
 
 #define MIME_TYPE_ASX_PLAYLIST "video/x-ms-asx"
 
-#define RESOURCE_CONTENT_TYPE "rct"
-
-#define ID3_ALBUM_ART "aa"
-#define VIDEO_SUB "vs"
-
-#define EXIF_THUMBNAIL "EX_TH"
-#define THUMBNAIL "th" // thumbnail without need for special handling
-
 enum metadata_fields_t {
     M_TITLE = 0,
     M_ARTIST,
@@ -122,7 +117,7 @@ enum metadata_fields_t {
     M_MAX
 };
 
-static constexpr auto mt_keys = std::array<std::pair<metadata_fields_t, const char*>, M_MAX> {
+static const auto mt_keys = std::map<metadata_fields_t, std::string> {
     std::pair(M_TITLE, "dc:title"),
     std::pair(M_ARTIST, "upnp:artist"),
     std::pair(M_ALBUM, "upnp:album"),
@@ -150,48 +145,6 @@ static constexpr auto mt_keys = std::array<std::pair<metadata_fields_t, const ch
     std::pair(M_CONTENT_CLASS, "upnp:contentClass"),
 };
 
-// res tag attributes
-enum resource_attributes_t {
-    R_SIZE = 0,
-    R_DURATION,
-    R_BITRATE,
-    R_SAMPLEFREQUENCY,
-    R_NRAUDIOCHANNELS,
-    R_RESOLUTION,
-    R_COLORDEPTH,
-    R_PROTOCOLINFO,
-    R_RESOURCE_FILE,
-    R_TYPE,
-    R_FANART_OBJ_ID,
-    R_FANART_RES_ID,
-    R_BITS_PER_SAMPLE,
-    R_LANGUAGE,
-    R_AUDIOCODEC,
-    R_VIDEOCODEC,
-    R_MAX
-};
-
-static constexpr auto res_keys = std::array<std::pair<resource_attributes_t, const char*>, R_MAX> {
-    std::pair(R_SIZE, "size"),
-    std::pair(R_DURATION, "duration"),
-    std::pair(R_BITRATE, "bitrate"),
-    std::pair(R_SAMPLEFREQUENCY, "sampleFrequency"),
-    std::pair(R_NRAUDIOCHANNELS, "nrAudioChannels"),
-    std::pair(R_RESOLUTION, "resolution"),
-    std::pair(R_COLORDEPTH, "colorDepth"),
-    std::pair(R_PROTOCOLINFO, "protocolInfo"),
-    std::pair(R_RESOURCE_FILE, "resFile"),
-    std::pair(R_FANART_OBJ_ID, "fanArtObject"),
-    std::pair(R_FANART_RES_ID, "fanArtResource"),
-    std::pair(R_BITS_PER_SAMPLE, "bitsPerSample"),
-    std::pair(R_LANGUAGE, "dc:language"),
-    std::pair(R_AUDIOCODEC, "sec:acodec"),
-    std::pair(R_VIDEOCODEC, "sec:vcodec"),
-    std::pair(R_TYPE, "type"),
-};
-static constexpr auto privateAttributes = std::array { R_RESOURCE_FILE, R_FANART_OBJ_ID, R_FANART_RES_ID, R_BITS_PER_SAMPLE, R_TYPE };
-
-using ResourceAttributeIterator = EnumIterator<resource_attributes_t, resource_attributes_t::R_SIZE, resource_attributes_t::R_MAX>;
 using MetadataIterator = EnumIterator<metadata_fields_t, metadata_fields_t::M_TITLE, metadata_fields_t::M_MAX>;
 
 /// \brief This class is responsible for providing access to metadata information
@@ -209,8 +162,7 @@ public:
 
     static void extractMetaData(const std::shared_ptr<Context>& context, const std::shared_ptr<CdsItem>& item, const fs::directory_entry& dirEnt);
     static std::string getMetaFieldName(metadata_fields_t field);
-    static std::string getResAttrName(resource_attributes_t attr);
-    static std::unique_ptr<MetadataHandler> createHandler(const std::shared_ptr<Context>& context, int handlerType);
+    static std::unique_ptr<MetadataHandler> createHandler(const std::shared_ptr<Context>& context, ContentHandler handlerType);
 
     /// \brief read metadata from file and add to object
     /// \param obj Object to handle
@@ -223,8 +175,10 @@ public:
     virtual std::unique_ptr<IOHandler> serveContent(const std::shared_ptr<CdsObject>& obj, int resNum) = 0;
     virtual std::string getMimeType() const;
 
-    static std::string mapContentHandler2String(int ch);
-    static int remapContentHandler(const std::string& contHandler);
+    static std::string mapContentHandler2String(ContentHandler ch);
+    static bool checkContentHandler(const std::string& contHandler);
+    static ContentHandler remapContentHandler(const std::string& contHandler);
+    static ContentHandler remapContentHandler(int ch);
 
     static metadata_fields_t remapMetaDataField(std::string_view fieldName);
 };
