@@ -188,27 +188,27 @@ void TagLibHandler::populateGenericTags(const std::shared_ptr<CdsItem>& item, co
     if (!audioProps)
         return;
 
-    auto res = item->getResource(0);
+    auto res = item->getResource(ContentHandler::DEFAULT);
 
     // UPnP bitrate is in bytes/second
     int temp = audioProps->bitrate() * 1024 / 8; // kbit/second -> byte/second
     if (temp > 0) {
-        res->addAttribute(R_BITRATE, fmt::to_string(temp));
+        res->addAttribute(CdsResource::Attribute::BITRATE, fmt::to_string(temp));
     }
 
     temp = audioProps->lengthInMilliseconds();
     if (temp > 0) {
-        res->addAttribute(R_DURATION, millisecondsToHMSF(temp));
+        res->addAttribute(CdsResource::Attribute::DURATION, millisecondsToHMSF(temp));
     }
 
     temp = audioProps->sampleRate();
     if (temp > 0) {
-        res->addAttribute(R_SAMPLEFREQUENCY, fmt::to_string(temp));
+        res->addAttribute(CdsResource::Attribute::SAMPLEFREQUENCY, fmt::to_string(temp));
     }
 
     temp = audioProps->channels();
     if (temp > 0) {
-        res->addAttribute(R_NRAUDIOCHANNELS, fmt::to_string(temp));
+        res->addAttribute(CdsResource::Attribute::NRAUDIOCHANNELS, fmt::to_string(temp));
     }
 }
 
@@ -295,9 +295,8 @@ void TagLibHandler::addArtworkResource(const std::shared_ptr<CdsItem>& item, con
     log_debug("Found artwork of type {} in file {}", artMimetype.c_str(), item->getLocation().c_str());
 
     if (artMimetype != MIMETYPE_DEFAULT) {
-        auto resource = std::make_shared<CdsResource>(CH_ID3);
-        resource->addAttribute(R_PROTOCOLINFO, renderProtocolInfo(artMimetype));
-        resource->addParameter(RESOURCE_CONTENT_TYPE, ID3_ALBUM_ART);
+        auto resource = std::make_shared<CdsResource>(ContentHandler::ID3, CdsResource::Purpose::Thumbnail);
+        resource->addAttribute(CdsResource::Attribute::PROTOCOLINFO, renderProtocolInfo(artMimetype));
         item->addResource(resource);
     }
 }
@@ -601,9 +600,9 @@ void TagLibHandler::extractASF(TagLib::IOStream& roStream, const std::shared_ptr
 
     auto audioProps = asf.audioProperties();
     auto temp = audioProps->bitsPerSample();
-    auto res = item->getResource(0);
+    auto res = item->getResource(ContentHandler::DEFAULT);
     if (temp > 0) {
-        res->addAttribute(R_BITS_PER_SAMPLE, fmt::to_string(temp));
+        res->addAttribute(CdsResource::Attribute::BITS_PER_SAMPLE, fmt::to_string(temp));
     }
 
     const TagLib::ASF::AttributeListMap& attrListMap = asf.tag()->attributeListMap();
@@ -640,9 +639,9 @@ void TagLibHandler::extractFLAC(TagLib::IOStream& roStream, const std::shared_pt
 
     auto audioProps = flac.audioProperties();
     auto temp = audioProps->bitsPerSample();
-    auto res = item->getResource(0);
+    auto res = item->getResource(ContentHandler::DEFAULT);
     if (temp > 0) {
-        res->addAttribute(R_BITS_PER_SAMPLE, fmt::to_string(temp));
+        res->addAttribute(CdsResource::Attribute::BITS_PER_SAMPLE, fmt::to_string(temp));
     }
 
     if (flac.pictureList().isEmpty()) {
@@ -675,9 +674,9 @@ void TagLibHandler::extractAPE(TagLib::IOStream& roStream, const std::shared_ptr
 
     auto audioProps = ape.audioProperties();
     auto temp = audioProps->bitsPerSample();
-    auto res = item->getResource(0);
+    auto res = item->getResource(ContentHandler::DEFAULT);
     if (temp > 0) {
-        res->addAttribute(R_BITS_PER_SAMPLE, fmt::to_string(temp));
+        res->addAttribute(CdsResource::Attribute::BITS_PER_SAMPLE, fmt::to_string(temp));
     }
 }
 
@@ -697,9 +696,9 @@ void TagLibHandler::extractWavPack(TagLib::IOStream& roStream, const std::shared
 
     auto audioProps = wavpack.audioProperties();
     auto temp = audioProps->bitsPerSample();
-    auto res = item->getResource(0);
+    auto res = item->getResource(ContentHandler::DEFAULT);
     if (temp > 0) {
-        res->addAttribute(R_BITS_PER_SAMPLE, fmt::to_string(temp));
+        res->addAttribute(CdsResource::Attribute::BITS_PER_SAMPLE, fmt::to_string(temp));
     }
 }
 
@@ -725,9 +724,9 @@ void TagLibHandler::extractMP4(TagLib::IOStream& roStream, const std::shared_ptr
 
     auto audioProps = mp4.audioProperties();
     auto temp = audioProps->bitsPerSample();
-    auto res = item->getResource(0);
+    auto res = item->getResource(ContentHandler::DEFAULT);
     if (temp > 0) {
-        res->addAttribute(R_BITS_PER_SAMPLE, fmt::to_string(temp));
+        res->addAttribute(CdsResource::Attribute::BITS_PER_SAMPLE, fmt::to_string(temp));
     }
 
     if (mp4.tag()->contains("covr")) {
@@ -766,9 +765,9 @@ void TagLibHandler::extractAiff(TagLib::IOStream& roStream, const std::shared_pt
 
     auto audioProps = aiff.audioProperties();
     auto temp = audioProps->bitsPerSample();
-    auto res = item->getResource(0);
+    auto res = item->getResource(ContentHandler::DEFAULT);
     if (temp > 0) {
-        res->addAttribute(R_BITS_PER_SAMPLE, fmt::to_string(temp));
+        res->addAttribute(CdsResource::Attribute::BITS_PER_SAMPLE, fmt::to_string(temp));
     }
 }
 
