@@ -47,8 +47,10 @@
 #include "database/database.h"
 #include "device_description_handler.h"
 #include "file_request_handler.h"
+#include "util/grb_net.h"
 #include "util/mime.h"
 #include "util/upnp_clients.h"
+#include "util/url_utils.h"
 #include "web/pages.h"
 #include "web/session_manager.h"
 
@@ -74,15 +76,16 @@ void Server::init()
 
     // initialize what is needed
     auto self = shared_from_this();
-    timer = std::make_shared<Timer>(config);
-
-    clients = std::make_shared<Clients>(config);
-    mime = std::make_shared<Mime>(config);
+    timer = std::make_shared<Timer>();
     timer->run();
+
+    mime = std::make_shared<Mime>(config);
     database = Database::createInstance(config, mime, timer);
     config->updateConfigFromDatabase(database);
+
+    clients = std::make_shared<ClientManager>(config, database);
     session_manager = std::make_shared<Web::SessionManager>(config, timer);
-    context = std::make_shared<Context>(config, clients, mime, database, self, session_manager);
+    context = std::make_shared<Context>(config, clients, mime, database, session_manager);
 
     content = std::make_shared<ContentManager>(context, self, timer);
 }
@@ -106,7 +109,7 @@ void Server::run()
         throw_std_runtime_error("You cannot specify interface {} and IP {} at the same time", iface, ip);
 
     if (iface.empty())
-        iface = ipToInterface(ip);
+        iface = GrbNet::ipToInterface(ip);
 
     if (!ip.empty() && iface.empty())
         throw_std_runtime_error("Could not find IP: {}", ip);
@@ -149,7 +152,7 @@ void Server::run()
     std::string presentationURL = getPresentationUrl();
 
     log_debug("Creating UpnpXMLBuilder");
-    xmlbuilder = std::make_shared<UpnpXMLBuilder>(context, virtualUrl, presentationURL);
+    xmlbuilder = std::make_shared<UpnpXMLBuilder>(context, getVirtualUrl(), presentationURL);
 
     // register root device with the library
     auto desc = xmlbuilder->renderDeviceDescription();
@@ -219,13 +222,7 @@ void Server::run()
         },
         this);
 
-    std::string url = config->getOption(CFG_VIRTUAL_URL);
-    if (url.empty()) {
-        url = renderWebUri(ip, port);
-    }
-    if (!startswith(url, "http")) { // url does not start with http
-        url = fmt::format("http://{}", url);
-    }
+    std::string url = getVirtualUrl();
     writeBookmark(url);
     log_info("The Web UI can be reached by following this link: {}", url);
 }
@@ -262,8 +259,6 @@ int Server::startupInterface(const std::string& iface, in_port_t inPort)
     log_info("IPv6: Server bound to: {}:{}", UpnpGetServerIp6Address(), UpnpGetServerPort6());
     log_info("IPv6 ULA/GLA: Server bound to: {}:{}", UpnpGetServerUlaGuaIp6Address(), UpnpGetServerUlaGuaPort6());
 
-    virtualUrl = fmt::format("http://{}:{}/{}", ip, port, virtual_directory);
-
     return ret;
 }
 
@@ -305,8 +300,16 @@ void Server::emptyBookmark()
 
 std::string Server::getVirtualUrl() const
 {
-    auto cfgVirt = config->getOption(CFG_VIRTUAL_URL);
-    return cfgVirt.empty() ? virtualUrl : fmt::format("{}/{}", cfgVirt, virtual_directory);
+    auto virtUrl = config->getOption(CFG_VIRTUAL_URL);
+    if (virtUrl.empty()) {
+        virtUrl = renderWebUri(ip, port);
+    }
+    if (!startswith(virtUrl, "http")) { // url does not start with http
+        virtUrl = fmt::format("http://{}", virtUrl);
+    }
+    if (*virtUrl.end() == '/')
+        virtUrl.pop_back();
+    return virtUrl;
 }
 
 bool Server::getShutdownStatus() const
@@ -382,7 +385,7 @@ int Server::handleUpnpRootDeviceEvent(Upnp_EventType eventType, const void* even
     case UPNP_CONTROL_ACTION_REQUEST:
         log_debug("UPNP_CONTROL_ACTION_REQUEST");
         try {
-            auto request = ActionRequest(context, static_cast<UpnpActionRequest*>(const_cast<void*>(event)));
+            auto request = ActionRequest(*xmlbuilder, *clients, static_cast<UpnpActionRequest*>(const_cast<void*>(event)));
             routeActionRequest(request);
             request.update();
         } catch (const UpnpException& upnpE) {
@@ -396,7 +399,7 @@ int Server::handleUpnpRootDeviceEvent(Upnp_EventType eventType, const void* even
     case UPNP_EVENT_SUBSCRIPTION_REQUEST:
         log_debug("UPNP_EVENT_SUBSCRIPTION_REQUEST");
         try {
-            auto request = std::make_unique<SubscriptionRequest>(static_cast<UpnpSubscriptionRequest*>(const_cast<void*>(event)));
+            auto request = SubscriptionRequest(static_cast<UpnpSubscriptionRequest*>(const_cast<void*>(event)));
             routeSubscriptionRequest(request);
         } catch (const UpnpException& upnpE) {
             log_warning("Subscription exception: {}", upnpE.what());
@@ -428,7 +431,7 @@ int Server::handleUpnpClientEvent(Upnp_EventType eventType, const void* event)
     case UPNP_DISCOVERY_SEARCH_RESULT: {
         auto dEvent = static_cast<const UpnpDiscovery*>(event);
         const char* userAgent = UpnpDiscovery_get_Os_cstr(dEvent);
-        const struct sockaddr_storage* destAddr = UpnpDiscovery_get_DestAddr(dEvent);
+        auto destAddr = std::make_shared<GrbNet>(UpnpDiscovery_get_DestAddr(dEvent));
         const char* location = UpnpDiscovery_get_Location_cstr(dEvent);
 
         clients->addClientByDiscovery(destAddr, userAgent, location);
@@ -469,25 +472,25 @@ void Server::routeActionRequest(ActionRequest& request)
     }
 }
 
-void Server::routeSubscriptionRequest(const std::unique_ptr<SubscriptionRequest>& request) const
+void Server::routeSubscriptionRequest(const SubscriptionRequest& request) const
 {
     // make sure that the request is for our device
-    if (request->getUDN() != serverUDN) {
+    if (request.getUDN() != serverUDN) {
         // not for us
-        log_debug("routeSubscriptionRequest: request not for this device: {} vs {}", request->getUDN(), serverUDN);
+        log_debug("routeSubscriptionRequest: request not for this device: {} vs {}", request.getUDN(), serverUDN);
         throw UpnpException(UPNP_E_BAD_REQUEST, "routeActionRequest: request not for this device");
     }
 
     // we need to match the serviceID to one of our services
-    if (request->getServiceID() == UPNP_DESC_CDS_SERVICE_ID) {
+    if (request.getServiceID() == UPNP_DESC_CDS_SERVICE_ID) {
         // this call is for the content directory service
         // log_debug("routeSubscriptionRequest: request for content directory service");
         cds->processSubscriptionRequest(request);
-    } else if (request->getServiceID() == UPNP_DESC_CM_SERVICE_ID) {
+    } else if (request.getServiceID() == UPNP_DESC_CM_SERVICE_ID) {
         // this call is for the connection manager service
         // log_debug("routeSubscriptionRequest: request for connection manager service");
         cmgr->processSubscriptionRequest(request);
-    } else if (request->getServiceID() == UPNP_DESC_MRREG_SERVICE_ID) {
+    } else if (request.getServiceID() == UPNP_DESC_MRREG_SERVICE_ID) {
         mrreg->processSubscriptionRequest(request);
     } else {
         // cp asks for a nonexistent service or for a service that
@@ -512,7 +515,7 @@ std::unique_ptr<RequestHandler> Server::createRequestHandler(const char* filenam
     }
 
     if (startswith(link, fmt::format("/{}/{}", SERVER_VIRTUAL_DIR, CONTENT_UI_HANDLER))) {
-        auto&& [path, parameters] = RequestHandler::splitUrl(filename, URL_UI_PARAM_SEPARATOR);
+        auto&& [path, parameters] = URLUtils::splitUrl(filename, URL_UI_PARAM_SEPARATOR);
 
         auto params = dictDecode(parameters);
 
@@ -544,7 +547,7 @@ int Server::registerVirtualDirCallbacks()
             std::string link = urlUnescape(filename);
             reqHandler->getInfo(startswith(link, fmt::format("/{}/{}", SERVER_VIRTUAL_DIR, CONTENT_UI_HANDLER)) ? filename : link.c_str(), info);
             return 0;
-        } catch (const ServerShutdownException& se) {
+        } catch (const ServerShutdownException&) {
             return -1;
         } catch (const SubtitlesNotFoundException& sex) {
             log_warning("{}", sex.what());
@@ -585,7 +588,7 @@ int Server::registerVirtualDirCallbacks()
             return -1;
 
         auto handler = static_cast<IOHandler*>(f);
-        return handler->read(buf, length);
+        return handler->read(reinterpret_cast<std::byte*>(buf), length);
     });
     if (ret != UPNP_E_SUCCESS)
         return ret;
