@@ -70,14 +70,6 @@ public:
     /// web callbacks. Starts the update manager task.
     void run();
 
-    /// \brief Returns the content url of the server.
-    ///
-    /// Returns a string representation of the server url. Although
-    /// the port is also specified in the config, we can never be sure
-    /// that we actually get that port after startup. This function
-    /// contains the port on which the server is actually running.
-    std::string getVirtualUrl() const;
-
     /// \brief Tells if the server is about to be terminated.
     ///
     /// This function returns true if the server is about to be
@@ -90,7 +82,7 @@ public:
 
 protected:
     std::shared_ptr<Config> config;
-    std::shared_ptr<Clients> clients;
+    std::shared_ptr<ClientManager> clients;
     std::shared_ptr<Mime> mime;
     std::shared_ptr<Database> database;
     std::shared_ptr<Web::SessionManager> session_manager;
@@ -123,13 +115,6 @@ protected:
     /// should be sufficient here.
     std::string virtual_directory;
 
-    /// \brief Full virtual web server url.
-    ///
-    /// The URL is constructed upon server initialization, since
-    /// the real port is not known before. The value of this variable
-    /// is returned by the getVirtualURL() function.
-    std::string virtualUrl;
-
     /// \brief Time interval to send ssdp:alive advertisements.
     ///
     /// The value is read from the configuration.
@@ -174,7 +159,7 @@ protected:
     /// and ConnectionManagerService), this function looks at the service id
     /// of the request and calls the process_subscription_request() for the
     /// appropriate service.
-    void routeSubscriptionRequest(const std::unique_ptr<SubscriptionRequest>& request) const;
+    void routeSubscriptionRequest(const SubscriptionRequest& request) const;
 
     /// \brief Registers callback functions for the internal web server.
     /// \param filename Incoming filename.
@@ -221,6 +206,14 @@ protected:
 
     std::string getPresentationUrl() const;
     int startupInterface(const std::string& iface, in_port_t inPort);
+
+    /// \brief Returns the content url of the server.
+    ///
+    /// Returns a string representation of the server url. Although
+    /// the port is also specified in the config, we can never be sure
+    /// that we actually get that port after startup. This function
+    /// contains the port on which the server is actually running.
+    std::string getVirtualUrl() const;
 };
 
 #endif // __SERVER_H__
