@@ -32,8 +32,6 @@
 #ifndef __TRANSCODE_EXTERNAL_HANDLER_H__
 #define __TRANSCODE_EXTERNAL_HANDLER_H__
 
-#include <upnp.h>
-
 #include "common.h"
 #include "transcode_handler.h"
 #include "util/grb_fs.h"
@@ -47,6 +45,7 @@ public:
     std::unique_ptr<IOHandler> serveContent(const std::shared_ptr<TranscodingProfile>& profile,
         const fs::path& location,
         const std::shared_ptr<CdsObject>& obj,
+        const std::string& group,
         const std::string& range) override;
 
 private:
