@@ -33,78 +33,63 @@
 
 #include "util/tools.h"
 
-TranscodingProfile::TranscodingProfile(transcoding_type_t trType, std::string name)
-    : name(std::move(name))
-    , tr_type(trType)
+TranscodingProfile::TranscodingProfile(bool enabled, transcoding_type_t trType, std::string name)
+    : enabled(enabled)
+    , name(std::move(name))
+    , trType(trType)
+{
+}
+
+TranscodingFilter::TranscodingFilter(std::string mimeType, std::string transcoder)
+    : mimeType(std::move(mimeType))
+    , transcoder(std::move(transcoder))
 {
 }
 
 void TranscodingProfile::setBufferOptions(std::size_t bs, std::size_t cs, std::size_t ifs)
 {
-    buffer_size = bs;
-    chunk_size = cs;
-    initial_fill_size = ifs;
+    bufferSize = bs;
+    chunkSize = cs;
+    initialFillSize = ifs;
 }
 
-void TranscodingProfile::setAttribute(const std::string& name, const std::string& value)
+void TranscodingProfile::setAttributeOverride(CdsResource::Attribute attribute, const std::string& value)
 {
-    attributes[name] = value;
+    attributeOverrides[attribute] = value;
 }
 
-const std::map<std::string, std::string>& TranscodingProfile::getAttributes() const
+std::string TranscodingProfile::getAttributeOverride(CdsResource::Attribute attribute) const
 {
-    return attributes;
-}
-
-std::string TranscodingProfile::getAttribute(const std::string& name) const
-{
-    auto it = attributes.find(name);
-    if (it != attributes.end()) {
+    auto it = attributeOverrides.find(attribute);
+    if (it != attributeOverrides.end()) {
         return it->second;
     }
     return {};
 }
 
+std::map<CdsResource::Attribute, std::string> TranscodingProfile::getAttributeOverrides() const
+{
+    return attributeOverrides;
+}
+
 void TranscodingProfile::setAVIFourCCList(const std::vector<std::string>& list, avi_fourcc_listmode_t mode)
 {
-    fourcc_list = list;
-    fourcc_mode = mode;
+    fourccList = list;
+    fourccMode = mode;
 }
 
 const std::vector<std::string>& TranscodingProfile::getAVIFourCCList() const
 {
-    return fourcc_list;
-}
-
-void TranscodingProfileList::add(const std::string& sourceMimeType, const std::shared_ptr<TranscodingProfile>& prof)
-{
-    auto inner = [this, &sourceMimeType] {
-        auto it = list.find(sourceMimeType);
-        if (it != list.end())
-            return std::move(it->second);
-        return std::make_shared<TranscodingProfileMap>();
-    }();
-
-    inner->emplace(prof->getName(), prof);
-    list[sourceMimeType] = std::move(inner);
-}
-
-std::shared_ptr<TranscodingProfileMap> TranscodingProfileList::get(const std::string& sourceMimeType) const
-{
-    auto it = list.find(sourceMimeType);
-    if (it != list.end())
-        return it->second;
-    return nullptr;
+    return fourccList;
 }
 
 std::shared_ptr<TranscodingProfile> TranscodingProfileList::getByName(const std::string& name, bool getAll) const
 {
-    for (auto&& [key, inner] : list) {
-        auto tp = inner->find(name);
-        if (tp != inner->end() && (getAll || tp->second->getEnabled()))
-            return tp->second;
+    for (auto&& filter : filterList) {
+        if (filter->getTranscodingProfile() && filter->getTranscodingProfile()->getName() == name && (getAll || filter->getTranscodingProfile()->isEnabled()))
+            return filter->getTranscodingProfile();
     }
-    return nullptr;
+    return {};
 }
 
 std::string TranscodingProfile::mapFourCcMode(avi_fourcc_listmode_t mode)
