@@ -37,6 +37,7 @@
 #include "config/config_manager.h"
 #include "database/database.h"
 #include "database/sql_database.h"
+#include "util/upnp_clients.h"
 #include "util/upnp_quirks.h"
 
 ContentDirectoryService::ContentDirectoryService(const std::shared_ptr<Context>& context,
@@ -77,7 +78,7 @@ void ContentDirectoryService::doBrowse(ActionRequest& request)
         throw UpnpException(UPNP_E_NO_SUCH_ID, "empty object id");
 
     auto&& quirks = request.getQuirks();
-    auto arr = quirks->getSamsungFeatureRoot(objID);
+    auto arr = quirks->getSamsungFeatureRoot(*database, objID);
     int objectID = stoiString(objID);
 
     unsigned int flag = BROWSE_ITEMS | BROWSE_CONTAINERS | BROWSE_EXACT_CHILDCOUNT;
@@ -88,7 +89,7 @@ void ContentDirectoryService::doBrowse(ActionRequest& request)
         throw UpnpException(UPNP_SOAP_E_INVALID_ARGS,
             "Invalid browse flag: " + browseFlag);
 
-    auto parent = database->loadObject(objectID);
+    auto parent = database->loadObject(quirks->getGroup(), objectID);
     if (sortCriteria.empty() && (parent->getClass() == UPNP_CLASS_MUSIC_ALBUM || parent->getClass() == UPNP_CLASS_PLAYLIST_CONTAINER))
         flag |= BROWSE_TRACK_SORT;
 
@@ -101,6 +102,7 @@ void ContentDirectoryService::doBrowse(ActionRequest& request)
     param.setStartingIndex(stoiString(startingIndex));
     param.setRequestedCount(stoiString(requestedCount));
     param.setSortCriteria(trimString(sortCriteria));
+    param.setGroup(quirks->getGroup());
 
     try {
         if (arr.empty())
@@ -123,24 +125,14 @@ void ContentDirectoryService::doBrowse(ActionRequest& request)
     didlLiteRoot.append_attribute(UPNP_XML_SEC_NAMESPACE_ATTR) = UPNP_XML_SEC_NAMESPACE;
 
     for (auto&& obj : arr) {
-        if (!config->getBoolOption(CFG_SERVER_EXTOPTS_MARK_PLAYED_ITEMS_ENABLED) || !obj->getFlag(OBJECT_FLAG_PLAYED)) {
-            xmlBuilder->renderObject(obj, stringLimit, didlLiteRoot, quirks);
-            continue;
-        }
-
-        std::string title = obj->getTitle();
-        if (config->getBoolOption(CFG_SERVER_EXTOPTS_MARK_PLAYED_ITEMS_STRING_MODE_PREPEND))
-            title = config->getOption(CFG_SERVER_EXTOPTS_MARK_PLAYED_ITEMS_STRING).append(title);
-        else
-            title.append(config->getOption(CFG_SERVER_EXTOPTS_MARK_PLAYED_ITEMS_STRING));
-        obj->setTitle(title);
+        markPlayedItem(obj, obj->getTitle());
         xmlBuilder->renderObject(obj, stringLimit, didlLiteRoot, quirks);
     }
 
     std::string didlLiteXml = UpnpXMLBuilder::printXml(didlLite, "", 0);
     log_debug("didl {}", didlLiteXml);
 
-    auto response = UpnpXMLBuilder::createResponse(request.getActionName(), UPNP_DESC_CDS_SERVICE_TYPE);
+    auto response = xmlBuilder->createResponse(request.getActionName(), UPNP_DESC_CDS_SERVICE_TYPE);
     auto respRoot = response->document_element();
     respRoot.append_child("Result").append_child(pugi::node_pcdata).set_value(didlLiteXml.c_str());
     respRoot.append_child("NumberReturned").append_child(pugi::node_pcdata).set_value(fmt::to_string(arr.size()).c_str());
@@ -168,8 +160,8 @@ void ContentDirectoryService::doSearch(ActionRequest& request)
     std::string requestedCount = reqRoot.child("RequestedCount").text().as_string();
     std::string sortCriteria = reqRoot.child("SortCriteria").text().as_string();
 
-    log_debug("Search received parameters: ContainerID [{}] SearchCriteria [{}] StartingIndex [{}] RequestedCount [{}] RequestedCount [{}]",
-        containerID, searchCriteria, startingIndex, requestedCount, requestedCount);
+    log_debug("Search received parameters: ContainerID [{}] SearchCriteria [{}] SortCriteria [{}] StartingIndex [{}] RequestedCount [{}]",
+        containerID, searchCriteria, sortCriteria, startingIndex, requestedCount);
 
     auto&& quirks = request.getQuirks();
     pugi::xml_document didlLite;
@@ -185,9 +177,11 @@ void ContentDirectoryService::doSearch(ActionRequest& request)
     didlLiteRoot.append_attribute(UPNP_XML_SEC_NAMESPACE_ATTR) = UPNP_XML_SEC_NAMESPACE;
     if (quirks->checkFlags(QUIRK_FLAG_PV_SUBTITLES))
         didlLiteRoot.append_attribute("xmlns:pv") = "http://www.pv.com/pvns/";
-
+    if (sortCriteria.empty()) {
+        sortCriteria = fmt::format("+{}", MetadataHandler::getMetaFieldName(M_TITLE));
+    }
     const auto searchParam = SearchParam(containerID, searchCriteria, sortCriteria,
-        stoiString(startingIndex), stoiString(requestedCount), searchableContainers);
+        stoiString(startingIndex), stoiString(requestedCount), searchableContainers, quirks->getGroup());
 
     std::vector<std::shared_ptr<CdsObject>> results;
     int numMatches = 0;
@@ -218,21 +212,14 @@ void ContentDirectoryService::doSearch(ActionRequest& request)
                 title = fmt::format("{}", fmt::join(values, resultSeparator));
         }
 
-        if (config->getBoolOption(CFG_SERVER_EXTOPTS_MARK_PLAYED_ITEMS_ENABLED) && cdsObject->getFlag(OBJECT_FLAG_PLAYED)) {
-            if (config->getBoolOption(CFG_SERVER_EXTOPTS_MARK_PLAYED_ITEMS_STRING_MODE_PREPEND))
-                title = config->getOption(CFG_SERVER_EXTOPTS_MARK_PLAYED_ITEMS_STRING).append(title);
-            else
-                title.append(config->getOption(CFG_SERVER_EXTOPTS_MARK_PLAYED_ITEMS_STRING));
-        }
-
-        cdsObject->setTitle(title);
+        markPlayedItem(cdsObject, title);
         xmlBuilder->renderObject(cdsObject, stringLimit, didlLiteRoot);
     }
 
     std::string didlLiteXml = UpnpXMLBuilder::printXml(didlLite, "", 0);
     log_debug("didl {}", didlLiteXml);
 
-    auto response = UpnpXMLBuilder::createResponse(request.getActionName(), UPNP_DESC_CDS_SERVICE_TYPE);
+    auto response = xmlBuilder->createResponse(request.getActionName(), UPNP_DESC_CDS_SERVICE_TYPE);
     auto respRoot = response->document_element();
     respRoot.append_child("Result").append_child(pugi::node_pcdata).set_value(didlLiteXml.c_str());
     respRoot.append_child("NumberReturned").append_child(pugi::node_pcdata).set_value(fmt::to_string(results.size()).c_str());
@@ -243,11 +230,40 @@ void ContentDirectoryService::doSearch(ActionRequest& request)
     log_debug("end");
 }
 
+static const auto markContentMap = std::map<std::string, std::string> {
+    { DEFAULT_MARK_PLAYED_CONTENT_VIDEO, UPNP_CLASS_VIDEO_ITEM },
+    { DEFAULT_MARK_PLAYED_CONTENT_AUDIO, UPNP_CLASS_AUDIO_ITEM },
+    { DEFAULT_MARK_PLAYED_CONTENT_IMAGE, UPNP_CLASS_IMAGE_ITEM },
+};
+
+void ContentDirectoryService::markPlayedItem(const std::shared_ptr<CdsObject>& cdsObject, std::string title) const
+{
+    // Return early if object is not an item
+    if (!cdsObject->isItem())
+        return;
+
+    auto item = std::static_pointer_cast<CdsItem>(cdsObject);
+    auto playStatus = item->getPlayStatus();
+    if (config->getBoolOption(CFG_SERVER_EXTOPTS_MARK_PLAYED_ITEMS_ENABLED) && playStatus && playStatus->getPlayCount() > 0) {
+        std::vector<std::string> markList = config->getArrayOption(CFG_SERVER_EXTOPTS_MARK_PLAYED_ITEMS_CONTENT_LIST);
+        bool mark = std::any_of(markList.begin(), markList.end(), [&](auto&& i) { return startswith(item->getClass(), markContentMap.at(i)); });
+        if (mark) {
+            if (config->getBoolOption(CFG_SERVER_EXTOPTS_MARK_PLAYED_ITEMS_STRING_MODE_PREPEND))
+                title = config->getOption(CFG_SERVER_EXTOPTS_MARK_PLAYED_ITEMS_STRING).append(title);
+            else
+                title.append(config->getOption(CFG_SERVER_EXTOPTS_MARK_PLAYED_ITEMS_STRING));
+        }
+    }
+
+    // Always update title
+    item->setTitle(title);
+}
+
 void ContentDirectoryService::doGetSearchCapabilities(ActionRequest& request)
 {
     log_debug("start");
 
-    auto response = UpnpXMLBuilder::createResponse(request.getActionName(), UPNP_DESC_CDS_SERVICE_TYPE);
+    auto response = xmlBuilder->createResponse(request.getActionName(), UPNP_DESC_CDS_SERVICE_TYPE);
     auto root = response->document_element();
     root.append_child("SearchCaps").append_child(pugi::node_pcdata).set_value(SQLDatabase::getSearchCapabilities().c_str());
     request.setResponse(std::move(response));
@@ -259,7 +275,7 @@ void ContentDirectoryService::doGetSortCapabilities(ActionRequest& request)
 {
     log_debug("start");
 
-    auto response = UpnpXMLBuilder::createResponse(request.getActionName(), UPNP_DESC_CDS_SERVICE_TYPE);
+    auto response = xmlBuilder->createResponse(request.getActionName(), UPNP_DESC_CDS_SERVICE_TYPE);
     auto root = response->document_element();
     root.append_child("SortCaps").append_child(pugi::node_pcdata).set_value(SQLDatabase::getSortCapabilities().c_str());
     request.setResponse(std::move(response));
@@ -267,11 +283,11 @@ void ContentDirectoryService::doGetSortCapabilities(ActionRequest& request)
     log_debug("end");
 }
 
-void ContentDirectoryService::doGetSystemUpdateID(ActionRequest& request)
+void ContentDirectoryService::doGetSystemUpdateID(ActionRequest& request) const
 {
     log_debug("start");
 
-    auto response = UpnpXMLBuilder::createResponse(request.getActionName(), UPNP_DESC_CDS_SERVICE_TYPE);
+    auto response = xmlBuilder->createResponse(request.getActionName(), UPNP_DESC_CDS_SERVICE_TYPE);
     auto root = response->document_element();
     root.append_child("Id").append_child(pugi::node_pcdata).set_value(fmt::to_string(systemUpdateID).c_str());
     request.setResponse(std::move(response));
@@ -283,7 +299,7 @@ void ContentDirectoryService::doSamsungBookmark(ActionRequest& request)
 {
     log_debug("start");
 
-    request.getQuirks()->saveSamsungBookMarkedPosition(request);
+    request.getQuirks()->saveSamsungBookMarkedPosition(*database, request);
 
     log_debug("end");
 }
@@ -346,14 +362,14 @@ void ContentDirectoryService::processActionRequest(ActionRequest& request)
     log_debug("ContentDirectoryService::processActionRequest: end");
 }
 
-void ContentDirectoryService::processSubscriptionRequest(const std::unique_ptr<SubscriptionRequest>& request)
+void ContentDirectoryService::processSubscriptionRequest(const SubscriptionRequest& request)
 {
     log_debug("start");
 
-    auto propset = UpnpXMLBuilder::createEventPropertySet();
+    auto propset = xmlBuilder->createEventPropertySet();
     auto property = propset->document_element().first_child();
     property.append_child("SystemUpdateID").append_child(pugi::node_pcdata).set_value(fmt::to_string(systemUpdateID).c_str());
-    auto obj = database->loadObject(0);
+    auto obj = database->loadObject(DEFAULT_CLIENT_GROUP, 0);
     auto cont = std::static_pointer_cast<CdsContainer>(obj);
     property.append_child("ContainerUpdateIDs").append_child(pugi::node_pcdata).set_value(fmt::format("0,{}", cont->getUpdateID()).c_str());
 
@@ -364,7 +380,7 @@ void ContentDirectoryService::processSubscriptionRequest(const std::unique_ptr<S
 #if defined(USING_NPUPNP)
     UpnpAcceptSubscriptionXML(
         deviceHandle, config->getOption(CFG_SERVER_UDN).c_str(),
-        UPNP_DESC_CDS_SERVICE_ID, xml, request->getSubscriptionID().c_str());
+        UPNP_DESC_CDS_SERVICE_ID, xml, request.getSubscriptionID().c_str());
 #else
     IXML_Document* event = nullptr;
     int err = ixmlParseBufferEx(xml.c_str(), &event);
@@ -374,7 +390,7 @@ void ContentDirectoryService::processSubscriptionRequest(const std::unique_ptr<S
 
     UpnpAcceptSubscriptionExt(deviceHandle,
         config->getOption(CFG_SERVER_UDN).c_str(),
-        UPNP_DESC_CDS_SERVICE_ID, event, request->getSubscriptionID().c_str());
+        UPNP_DESC_CDS_SERVICE_ID, event, request.getSubscriptionID().c_str());
 
     ixmlDocument_free(event);
 #endif
@@ -387,7 +403,7 @@ void ContentDirectoryService::sendSubscriptionUpdate(const std::string& containe
 
     systemUpdateID++;
 
-    auto propset = UpnpXMLBuilder::createEventPropertySet();
+    auto propset = xmlBuilder->createEventPropertySet();
     auto property = propset->document_element().first_child();
     property.append_child("ContainerUpdateIDs").append_child(pugi::node_pcdata).set_value(containerUpdateIDsCsv.c_str());
     property.append_child("SystemUpdateID").append_child(pugi::node_pcdata).set_value(fmt::to_string(systemUpdateID).c_str());
