@@ -77,37 +77,42 @@ private:
     /// \param request Incoming ActionRequest.
     ///
     /// GetSearchCapabilities(string SearchCaps)
-    static void doGetSearchCapabilities(ActionRequest& request);
+    void doGetSearchCapabilities(ActionRequest& request);
 
     /// \brief UPnP standard defined action: GetSortCapabilities()
     /// \param request Incoming ActionRequest.
     ///
     /// GetSortCapabilities(string SortCaps)
-    static void doGetSortCapabilities(ActionRequest& request);
+    void doGetSortCapabilities(ActionRequest& request);
 
     /// \brief UPnP standard defined action: GetSystemUpdateID()
     /// \param request Incoming ActionRequest.
     ///
     /// GetSystemUpdateID(ui4 Id)
-    void doGetSystemUpdateID(ActionRequest& request);
+    void doGetSystemUpdateID(ActionRequest& request) const;
 
     /// \brief Samsung Extension X_SetBookmark
     /// \param request Incoming ActionRequest.
     ///
-    static void doSamsungBookmark(ActionRequest& request);
+    void doSamsungBookmark(ActionRequest& request);
 
     /// \brief Samsung Extension X_GetFeatureListResponse
     /// \param request Incoming ActionRequest.
     ///
-    static void doSamsungFeatureList(ActionRequest& request);
+    void doSamsungFeatureList(ActionRequest& request);
 
     /// \brief Samsung Extension X_GetObjectIDfromIndex
     /// \param request Incoming ActionRequest.
-    static void doSamsungGetObjectIDfromIndex(ActionRequest& request);
+    void doSamsungGetObjectIDfromIndex(ActionRequest& request);
 
     /// \brief Samsung Extension X_GetIndexfromRID
     /// \param request Incoming ActionRequest.
-    static void doSamsungGetIndexfromRID(ActionRequest& request);
+    void doSamsungGetIndexfromRID(ActionRequest& request);
+
+    /// \brief mark played item if activated
+    /// \param cdsObject item to mark
+    /// \param title current title of the item
+    void markPlayedItem(const std::shared_ptr<CdsObject>& cdsObject, std::string title) const;
 
     std::shared_ptr<Config> config;
     std::shared_ptr<Database> database;
@@ -137,7 +142,7 @@ public:
     ///
     /// Looks at the incoming SubscriptionRequest and accepts the subscription
     /// if everything is ok.
-    void processSubscriptionRequest(const std::unique_ptr<SubscriptionRequest>& request);
+    void processSubscriptionRequest(const SubscriptionRequest& request);
 
     /// \brief Sends out an event to all subscribed devices.
     /// \param containerUpdateIDs_CSV Comma Separated Value list of container update ID's (as defined in the UPnP CDS specs)
