@@ -51,7 +51,7 @@ protected:
     /// GetCurrentConnectionIDs(string ConnectionIDs)
     ///
     /// This is currently unsupported (returns empty string)
-    static void doGetCurrentConnectionIDs(ActionRequest& request);
+    void doGetCurrentConnectionIDs(ActionRequest& request);
 
     /// \brief UPnP standard defined action: GetCurrentConnectionInfo()
     /// \param request Incoming ActionRequest.
@@ -60,13 +60,13 @@ protected:
     /// string PeerConnectionManager, i4 PeerConnectionID, string Direction, string Status)
     ///
     /// This action is currently unsupported.
-    static void doGetCurrentConnectionInfo(ActionRequest& request);
+    void doGetCurrentConnectionInfo(ActionRequest& request);
 
     /// \brief UPnP standard defined action: GetProtocolInfo()
     /// \param request Incoming ActionRequest.
     ///
     /// GetProtocolInfo(string Source, string Sink)
-    void doGetProtocolInfo(ActionRequest& request);
+    void doGetProtocolInfo(ActionRequest& request) const;
 
     std::shared_ptr<Config> config;
     std::shared_ptr<Database> database;
@@ -93,7 +93,7 @@ public:
     ///
     /// Looks at the incoming SubscriptionRequest and accepts the subscription
     /// if everything is ok.
-    void processSubscriptionRequest(const std::unique_ptr<SubscriptionRequest>& request);
+    void processSubscriptionRequest(const SubscriptionRequest& request);
 
     /// \brief Sends out an event to all subscribed devices.
     /// \param sourceProtocol_CSV Comma Separated Value list of protocol information
