@@ -50,7 +50,7 @@ void MRRegistrarService::doIsAuthorized(ActionRequest& request)
 {
     log_debug("start");
 
-    auto response = UpnpXMLBuilder::createResponse(request.getActionName(), UPNP_DESC_MRREG_SERVICE_TYPE);
+    auto response = xmlBuilder->createResponse(request.getActionName(), UPNP_DESC_MRREG_SERVICE_TYPE);
     auto root = response->document_element();
     root.append_child("Result").append_child(pugi::node_pcdata).set_value("1");
 
@@ -73,7 +73,7 @@ void MRRegistrarService::doIsValidated(ActionRequest& request)
 {
     log_debug("start");
 
-    auto response = UpnpXMLBuilder::createResponse(request.getActionName(), UPNP_DESC_MRREG_SERVICE_TYPE);
+    auto response = xmlBuilder->createResponse(request.getActionName(), UPNP_DESC_MRREG_SERVICE_TYPE);
     auto root = response->document_element();
     root.append_child("Result").append_child(pugi::node_pcdata).set_value("1");
 
@@ -103,9 +103,9 @@ void MRRegistrarService::processActionRequest(ActionRequest& request)
     log_debug("end");
 }
 
-void MRRegistrarService::processSubscriptionRequest(const std::unique_ptr<SubscriptionRequest>& request)
+void MRRegistrarService::processSubscriptionRequest(const SubscriptionRequest& request)
 {
-    auto propset = UpnpXMLBuilder::createEventPropertySet();
+    auto propset = xmlBuilder->createEventPropertySet();
     auto property = propset->document_element().first_child();
     property.append_child("ValidationRevokedUpdateID").append_child(pugi::node_pcdata).set_value("0");
     property.append_child("ValidationSucceededUpdateID").append_child(pugi::node_pcdata).set_value("0");
@@ -119,7 +119,7 @@ void MRRegistrarService::processSubscriptionRequest(const std::unique_ptr<Subscr
 #if defined(USING_NPUPNP)
     UpnpAcceptSubscriptionXML(
         deviceHandle, config->getOption(CFG_SERVER_UDN).c_str(),
-        UPNP_DESC_MRREG_SERVICE_ID, xml, request->getSubscriptionID().c_str());
+        UPNP_DESC_MRREG_SERVICE_ID, xml, request.getSubscriptionID().c_str());
 #else
     IXML_Document* event = nullptr;
     int err = ixmlParseBufferEx(xml.c_str(), &event);
@@ -129,7 +129,7 @@ void MRRegistrarService::processSubscriptionRequest(const std::unique_ptr<Subscr
 
     UpnpAcceptSubscriptionExt(deviceHandle,
         config->getOption(CFG_SERVER_UDN).c_str(),
-        UPNP_DESC_MRREG_SERVICE_ID, event, request->getSubscriptionID().c_str());
+        UPNP_DESC_MRREG_SERVICE_ID, event, request.getSubscriptionID().c_str());
 
     ixmlDocument_free(event);
 #endif
@@ -156,9 +156,7 @@ void MRRegistrarService::prcoessSubscriptionUpdate(std::string sourceProtocol_CS
         throw UpnpException(UPNP_E_SUBSCRIPTION_FAILED, "Could not convert property set to ixml");
     }
 
-    UpnpNotifyExt(deviceHandle,
-            config->getOption(CFG_SERVER_UDN).c_str(),
-            serviceID.c_str(), event);
+    UpnpNotifyExt(deviceHandle, config->getOption(CFG_SERVER_UDN).c_str(), serviceID.c_str(), event);
 
     ixmlDocument_free(event);
 }
