@@ -10,7 +10,6 @@ enum task_type_t {
     Invalid,
     AddFile,
     RemoveObject,
-    LoadAccounting,
     RescanDirectory,
     FetchOnlineContent
 };
@@ -44,7 +43,6 @@ public:
     bool isValid() const { return valid; }
     bool isCancellable() const { return cancellable; }
     void invalidate() { valid = false; }
-    task_owner_t getOwner() const { return taskOwner; }
 };
 
 #endif //__GENERIC_TASK_H__
