@@ -31,11 +31,6 @@
 
 #include "timer.h" // API
 
-Timer::Timer(std::shared_ptr<Config> config)
-    : config(std::move(config))
-{
-}
-
 void Timer::run()
 {
     log_debug("Starting Timer thread...");
@@ -44,7 +39,7 @@ void Timer::run()
             auto inst = static_cast<Timer*>(arg);
             inst->threadProc();
         },
-        this, config);
+        this);
 
     // wait for TimerThread to become ready
     threadRunner->waitForReady();
@@ -58,14 +53,14 @@ void Timer::threadProc()
     triggerWait();
 }
 
-void Timer::addTimerSubscriber(Subscriber* timerSubscriber, std::chrono::seconds notifyInterval, const std::shared_ptr<Parameter>& parameter, bool once)
+void Timer::addTimerSubscriber(Subscriber* timerSubscriber, std::chrono::seconds notifyInterval, std::shared_ptr<Parameter> parameter, bool once)
 {
     log_debug("Adding subscriber... interval: {} once: {} ", notifyInterval.count(), once);
     if (notifyInterval == std::chrono::seconds::zero())
         throw_std_runtime_error("Tried to add timer with illegal notifyInterval: {}", notifyInterval.count());
 
     auto lock = threadRunner->lockGuard();
-    auto element = TimerSubscriberElement(timerSubscriber, notifyInterval, parameter, once);
+    auto element = TimerSubscriberElement(timerSubscriber, notifyInterval, std::move(parameter), once);
 
     if (!subscribers.empty()) {
         bool err = std::find(subscribers.begin(), subscribers.end(), element) != subscribers.end();
@@ -78,12 +73,12 @@ void Timer::addTimerSubscriber(Subscriber* timerSubscriber, std::chrono::seconds
     threadRunner->notify();
 }
 
-void Timer::removeTimerSubscriber(Subscriber* timerSubscriber, const std::shared_ptr<Parameter>& parameter, bool dontFail)
+void Timer::removeTimerSubscriber(Subscriber* timerSubscriber, std::shared_ptr<Parameter> parameter, bool dontFail)
 {
     log_debug("Removing subscriber...");
     auto lock = threadRunner->lockGuard();
     if (!subscribers.empty()) {
-        auto element = TimerSubscriberElement(timerSubscriber, std::chrono::seconds::zero(), parameter);
+        auto element = TimerSubscriberElement(timerSubscriber, std::chrono::seconds::zero(), std::move(parameter));
         auto it = std::find(subscribers.begin(), subscribers.end(), element);
         if (it != subscribers.end()) {
             subscribers.erase(it);
