@@ -31,29 +31,20 @@
 
 #include "tools.h" // API
 
-#include <netdb.h>
-#include <netinet/in.h>
 #include <numeric>
 #include <queue>
 #include <sstream>
-#include <sys/socket.h>
 
 #ifdef __HAIKU__
 #define _DEFAULT_SOURCE
 #endif
 
-#include <ifaddrs.h>
-
 #ifdef BSD_NATIVE_UUID
 #include <uuid.h>
 #else
 #include <uuid/uuid.h>
 #endif
 
-#ifdef SOLARIS
-#include <sys/sockio.h>
-#endif
-
 #include "config/config_manager.h"
 #include "contrib/md5.h"
 
@@ -442,24 +433,6 @@ int HMSFToMilliseconds(std::string_view time)
     return ((hours * 3600) + (minutes * 60) + seconds) * 1000 + ms;
 }
 
-std::pair<unsigned int, unsigned int> checkResolution(std::string_view resolution)
-{
-    std::vector<std::string> parts = splitString(resolution, 'x');
-    if (parts.size() != 2)
-        return {};
-
-    if (!parts[0].empty() && !parts[1].empty()) {
-        unsigned int x = std::stoul(parts[0]);
-        unsigned int y = std::stoul(parts[1]);
-
-        if ((x != std::numeric_limits<unsigned int>::max()) && (y != std::numeric_limits<unsigned int>::max())) {
-            return { x, y };
-        }
-    }
-
-    return {};
-}
-
 std::string escape(std::string_view string, char escapeChar, char toEscape)
 {
     std::ostringstream buf;
@@ -525,19 +498,6 @@ std::string getValueOrDefault(const std::map<std::string, std::string>& m, const
     return getValueOrDefault<std::string, std::string>(m, key, defval);
 }
 
-std::string getPropertyMapValue(const std::map<std::string, std::string>& propMap, const std::string& search)
-{
-    auto it = propMap.find(search);
-    if (it != propMap.end())
-        return it->second;
-
-    // try to match foo
-    std::vector<std::string> parts = splitString(search, '/');
-    if (parts.size() != 2)
-        return {};
-    return getValueOrDefault(propMap, parts[0] + "/*");
-}
-
 std::chrono::seconds currentTime()
 {
     return std::chrono::duration_cast<std::chrono::seconds>(std::chrono::system_clock::now().time_since_epoch());
@@ -559,57 +519,6 @@ std::chrono::milliseconds getDeltaMillis(std::chrono::milliseconds first, std::c
     return second - first;
 }
 
-std::string ipToInterface(std::string_view ip)
-{
-    if (ip.empty()) {
-        return {};
-    }
-
-    log_warning("Please provide an interface name instead! LibUPnP does not support specifying an IP in current versions.");
-    log_info("Attempting to map {} to an interface", ip);
-
-    struct ifaddrs* ifaddr;
-    int family, s;
-    char host[NI_MAXHOST];
-
-    if (getifaddrs(&ifaddr) == -1) {
-        log_error("Could not getifaddrs: {}", std::strerror(errno));
-    }
-
-    for (auto ifa = ifaddr; ifa; ifa = ifa->ifa_next) {
-        if (!ifa->ifa_addr)
-            continue;
-
-        family = ifa->ifa_addr->sa_family;
-        std::string name = ifa->ifa_name;
-
-        if (family == AF_INET || family == AF_INET6) {
-            s = getnameinfo(ifa->ifa_addr,
-                (family == AF_INET) ? sizeof(struct sockaddr_in) : sizeof(struct sockaddr_in6),
-                host, NI_MAXHOST, nullptr, 0, NI_NUMERICHOST);
-            if (s != 0) {
-                log_error("getnameinfo() failed: {}", gai_strerror(s));
-                return {};
-            }
-
-            std::string ipaddr = host;
-            // IPv6 link locals come back as fe80::351d:d7f4:6b17:3396%eth0
-            if (startswith(ipaddr, ip)) {
-                return name;
-            }
-        }
-    }
-
-    freeifaddrs(ifaddr);
-    log_warning("Failed to find interface for IP: {}", ip);
-    return {};
-}
-
-bool validateYesNo(std::string_view value)
-{
-    return value == "yes" || value == "no";
-}
-
 std::vector<std::string> populateCommandLine(const std::string& line,
     const std::string& in,
     const std::string& out,
@@ -676,71 +585,3 @@ ssize_t getValidUTF8CutPosition(std::string_view str, ssize_t cutpos)
 
     return pos;
 }
-
-std::string getDLNAprofileString(const std::shared_ptr<Config>& config, const std::string& contentType, const std::string& vCodec, const std::string& aCodec)
-{
-    // get profiles from <contenttype-dlnaprofile> mappings
-    auto mappings = config->getDictionaryOption(CFG_IMPORT_MAPPINGS_CONTENTTYPE_TO_DLNAPROFILE_LIST);
-    auto profile = getValueOrDefault(mappings, fmt::format("{}-{}-{}", contentType, vCodec, aCodec), "");
-    if (profile.empty())
-        profile = getValueOrDefault(mappings, contentType, "");
-
-    return profile.empty() ? "" : fmt::format("{}={};", UPNP_DLNA_PROFILE, profile);
-}
-
-std::string getDLNAContentHeader(const std::shared_ptr<Config>& config, const std::string& contentType, const std::string& vCodec, const std::string& aCodec)
-{
-    std::string contentParameter = getDLNAprofileString(config, contentType, vCodec, aCodec);
-    return fmt::format("{}{}={};{}={};{}={}", contentParameter, //
-        UPNP_DLNA_OP, UPNP_DLNA_OP_SEEK_RANGE, //
-        UPNP_DLNA_CONVERSION_INDICATOR, UPNP_DLNA_NO_CONVERSION, //
-        UPNP_DLNA_FLAGS, UPNP_DLNA_ORG_FLAGS_AV);
-}
-
-std::string getDLNATransferHeader(const std::shared_ptr<Config>& config, const std::string& mimeType)
-{
-    auto mappings = config->getDictionaryOption(CFG_IMPORT_MAPPINGS_CONTENTTYPE_TO_DLNATRANSFER_LIST);
-    return getPropertyMapValue(mappings, mimeType);
-}
-
-std::string getHostName(const struct sockaddr* addr)
-{
-    char hoststr[NI_MAXHOST];
-    char portstr[NI_MAXSERV];
-    int len = addr->sa_family == AF_INET6 ? sizeof(struct sockaddr_in6) : sizeof(struct sockaddr_in);
-    int ret = getnameinfo(addr, len, hoststr, sizeof(hoststr), portstr, sizeof(portstr), NI_NOFQDN);
-    if (ret != 0) {
-        log_debug("could not determine getnameinfo: {}", std::strerror(errno));
-    }
-
-    return hoststr;
-}
-
-int sockAddrCmpAddr(const struct sockaddr* sa, const struct sockaddr* sb)
-{
-    if (sa->sa_family != sb->sa_family)
-        return sa->sa_family - sb->sa_family;
-
-    if (sa->sa_family == AF_INET) {
-        return SOCK_ADDR_IN_ADDR(sa).s_addr - SOCK_ADDR_IN_ADDR(sb).s_addr;
-    }
-
-    if (sa->sa_family == AF_INET6) {
-        return std::memcmp(&(SOCK_ADDR_IN6_ADDR(sa)), &(SOCK_ADDR_IN6_ADDR(sb)), sizeof(SOCK_ADDR_IN6_ADDR(sa)));
-    }
-
-    throw_std_runtime_error("Unsupported address family: {}", sa->sa_family);
-}
-
-std::string sockAddrGetNameInfo(const struct sockaddr* sa)
-{
-    char hoststr[NI_MAXHOST];
-    char portstr[NI_MAXSERV];
-    int len = sa->sa_family == AF_INET6 ? sizeof(struct sockaddr_in6) : sizeof(struct sockaddr_in);
-    int ret = getnameinfo(sa, len, hoststr, sizeof(hoststr), portstr, sizeof(portstr), NI_NUMERICHOST | NI_NUMERICSERV);
-    if (ret != 0) {
-        throw_std_runtime_error("could not determine getnameinfo: {}", std::strerror(errno));
-    }
-
-    return fmt::format("{}:{}", hoststr, portstr);
-}
