@@ -36,13 +36,9 @@
 #include <optional>
 #include <vector>
 
-#include <netinet/in.h>
-
 #include "common.h"
 
 // forward declaration
-class Config;
-class CdsItem;
 class IOHandler;
 
 /// \brief splits the given string into array of strings using a separator character.
@@ -157,7 +153,7 @@ std::string getMTFromProtocolInfo(std::string_view protocol);
 std::string_view getProtocol(std::string_view protocolInfo);
 
 template <typename TP>
-std::chrono::seconds to_seconds(TP tp)
+std::chrono::seconds toSeconds(TP tp)
 {
     auto asSystemTime = std::chrono::time_point_cast<std::chrono::system_clock::duration>(tp - TP::clock::now()
         + std::chrono::system_clock::now());
@@ -170,24 +166,8 @@ std::string millisecondsToHMSF(int milliseconds);
 /// \brief converts a "H*:MM:SS.F*" representation to milliseconds
 int HMSFToMilliseconds(std::string_view time);
 
-/// \brief Extracts resolution from a JPEG image
-/// \param ioh the IOHandler must be opened. The function will read data and close the handler.
-std::string get_jpeg_resolution(std::unique_ptr<IOHandler> ioh);
-
-/// \brief checks if the given string has the format xr x yr (i.e. 320x200 etc.)
-std::pair<unsigned int, unsigned int> checkResolution(std::string_view resolution);
-
 std::string escape(std::string_view string, char escapeChar, char toEscape);
 
-/*
-/// \brief Unescape &amp; &quot; and similar XML sequences.
-///
-/// This function will silently ignore and pass on any invalid combinations.
-/// \param string that should be unescaped
-/// \return the unescaped string
-std::string xml_unescape(std::string string);
-*/
-
 /// \brief Returns the first string if it isn't "nullptr", otherwise the fallback string.
 /// \param first the string to return if it isn't nullptr
 /// \param fallback fallback string to return if first is nullptr
@@ -240,6 +220,7 @@ public:
 template <typename K, typename V>
 V getValueOrDefault(const std::vector<std::pair<K, V>>& m, const K& key, const V& defval)
 {
+    static_assert(!std::is_const_v<V>);
     auto it = std::find_if(m.begin(), m.end(), [&](auto&& v) { return v.first == key; });
     return (it == m.end()) ? defval : it->second;
 }
@@ -247,29 +228,20 @@ V getValueOrDefault(const std::vector<std::pair<K, V>>& m, const K& key, const V
 template <typename K, typename V>
 V getValueOrDefault(const std::map<K, V>& m, const K& key, const V& defval)
 {
+    static_assert(!std::is_const_v<V>);
     auto it = m.find(key);
     return (it == m.end()) ? defval : it->second;
 }
+
 std::string getValueOrDefault(const std::vector<std::pair<std::string, std::string>>& m, const std::string& key, const std::string& defval = "");
 std::string getValueOrDefault(const std::map<std::string, std::string>& m, const std::string& key, const std::string& defval = "");
 
-std::string getPropertyMapValue(const std::map<std::string, std::string>& propMap, const std::string& search);
-
 std::chrono::seconds currentTime();
 std::chrono::milliseconds currentTimeMS();
 
 std::chrono::milliseconds getDeltaMillis(std::chrono::milliseconds ms);
 std::chrono::milliseconds getDeltaMillis(std::chrono::milliseconds first, std::chrono::milliseconds second);
 
-/// \brief Finds the Interface with the specified IP address.
-/// \param ip i.e. 192.168.4.56.
-/// \return Interface name or nullptr if IP was not found.
-std::string ipToInterface(std::string_view ip);
-
-/// \brief Returns true if the given string is eitehr "yes" or "no", otherwise
-/// returns false.
-bool validateYesNo(std::string_view value);
-
 /// \brief Parses a command line, splitting the arguments into an array and
 /// substitutes %in and %out tokens with given strings.
 ///
@@ -287,18 +259,4 @@ std::vector<std::string> populateCommandLine(const std::string& line,
 /// \return Caclulated position or -1 in case of an error.
 ssize_t getValidUTF8CutPosition(std::string_view str, ssize_t cutpos);
 
-std::string getDLNAprofileString(const std::shared_ptr<Config>& config, const std::string& contentType, const std::string& vCodec, const std::string& aCodec);
-std::string getDLNAContentHeader(const std::shared_ptr<Config>& config, const std::string& contentType, const std::string& vCodec, const std::string& aCodec);
-std::string getDLNATransferHeader([[maybe_unused]] const std::shared_ptr<Config>& config, const std::string& mimeType);
-
-/// \brief Compare sockaddr
-/// inspired by: http://www.opensource.apple.com/source/postfix/postfix-197/postfix/src/util/sock_addr.c
-#define SOCK_ADDR_IN_PTR(sa) reinterpret_cast<const struct sockaddr_in*>(sa)
-#define SOCK_ADDR_IN_ADDR(sa) SOCK_ADDR_IN_PTR(sa)->sin_addr
-#define SOCK_ADDR_IN6_PTR(sa) reinterpret_cast<const struct sockaddr_in6*>(sa)
-#define SOCK_ADDR_IN6_ADDR(sa) SOCK_ADDR_IN6_PTR(sa)->sin6_addr
-std::string getHostName(const struct sockaddr* addr);
-int sockAddrCmpAddr(const struct sockaddr* sa, const struct sockaddr* sb);
-std::string sockAddrGetNameInfo(const struct sockaddr* sa);
-
 #endif // __TOOLS_H__
