@@ -27,24 +27,46 @@
 #include "upnp_clients.h" // API
 #include "config/client_config.h"
 #include "config/config.h"
-#include "util/tools.h"
-
-#include <array>
+#include "database/database.h"
+#include "util/grb_net.h"
 
 #include <upnp.h>
 
-Clients::Clients(const std::shared_ptr<Config>& config)
+std::shared_ptr<ClientStatusDetail> ClientStatusDetail::clone() const
 {
-    refresh(config);
+    return std::make_shared<ClientStatusDetail>(group, itemId, playCount, lastPlayed.count(), lastPlayedPosition.count(), bookMarkPos.count());
 }
 
-void Clients::refresh(const std::shared_ptr<Config>& config)
+ClientManager::ClientManager(const std::shared_ptr<Config>& config, std::shared_ptr<Database> database)
+    : database(std::move(database))
+    , cacheThreshold(config->getIntOption(CFG_CLIENTS_CACHE_THRESHOLD))
+{
+    refresh(config);
+    if (this->database) {
+        auto dbCache = this->database->getClients();
+        for (auto&& entry : dbCache) {
+            auto info = getInfoByAddr(entry.addr);
+            if (!info) {
+                info = getInfoByType(entry.userAgent, ClientMatchType::UserAgent);
+            }
+            if (!info) {
+                assert(clientInfo[0].type == ClientType::Unknown);
+                info = &clientInfo[0];
+            }
+            entry.pInfo = info;
+            cache.push_back(std::move(entry));
+        }
+    }
+}
+
+void ClientManager::refresh(const std::shared_ptr<Config>& config)
 {
     // table of supported clients (reverse search, sequence of entries matters!)
     clientInfo = {
         // Used for not explicitly listed clients, must be first entry
         {
             "Unknown",
+            DEFAULT_CLIENT_GROUP,
             ClientType::Unknown,
             QUIRK_FLAG_NONE,
             ClientMatchType::None,
@@ -57,6 +79,7 @@ void Clients::refresh(const std::shared_ptr<Config>& config)
         // User-Agent(actionReq): Microsoft-Windows/10.0 UPnP/1.0 Microsoft-DLNA DLNADOC/1.50
         {
             "Standard UPnP",
+            DEFAULT_CLIENT_GROUP,
             ClientType::StandardUPnP,
             QUIRK_FLAG_NONE,
             ClientMatchType::UserAgent,
@@ -68,6 +91,7 @@ void Clients::refresh(const std::shared_ptr<Config>& config)
         // User-Agent(actionReq): Android/8.0.0 UPnP/1.0 BubbleUPnP/3.4.4
         {
             "BubbleUPnP",
+            DEFAULT_CLIENT_GROUP,
             ClientType::BubbleUPnP,
             QUIRK_FLAG_NONE,
             ClientMatchType::UserAgent,
@@ -79,6 +103,7 @@ void Clients::refresh(const std::shared_ptr<Config>& config)
         // User-Agent(actionReq): DLNADOC/1.50 SEC_HHP_[TV] UE65JU7000/1.0 UPnP/1.0
         {
             "Samsung other TVs",
+            DEFAULT_CLIENT_GROUP,
             ClientType::SamsungSeriesCDE,
             QUIRK_FLAG_SAMSUNG | QUIRK_FLAG_SAMSUNG_FEATURES | QUIRK_FLAG_SAMSUNG_HIDE_DYNAMIC,
             ClientMatchType::UserAgent,
@@ -89,6 +114,7 @@ void Clients::refresh(const std::shared_ptr<Config>& config)
         // User-Agent(actionReq): DLNADOC/1.50 SEC_HHP_[PC]LPC001/1.0  MS-DeviceCaps/1024
         {
             "AllShare",
+            DEFAULT_CLIENT_GROUP,
             ClientType::SamsungAllShare,
             QUIRK_FLAG_NONE,
             ClientMatchType::UserAgent,
@@ -98,6 +124,7 @@ void Clients::refresh(const std::shared_ptr<Config>& config)
         // User-Agent(actionReq): DLNADOC/1.50 SEC_HHP_[TV] Samsung Q7 Series (49)/1.0
         {
             "Samsung Series [Q] TVs",
+            DEFAULT_CLIENT_GROUP,
             ClientType::SamsungSeriesQ,
             QUIRK_FLAG_SAMSUNG | QUIRK_FLAG_SAMSUNG_FEATURES | QUIRK_FLAG_SAMSUNG_HIDE_DYNAMIC,
             ClientMatchType::UserAgent,
@@ -107,6 +134,7 @@ void Clients::refresh(const std::shared_ptr<Config>& config)
         // User-Agent(actionReq): DLNADOC/1.50 SEC_HHP_BD-D5100/1.0
         {
             "Samsung Blu-ray Player BD-D5100",
+            DEFAULT_CLIENT_GROUP,
             ClientType::SamsungBDP,
             QUIRK_FLAG_SAMSUNG | QUIRK_FLAG_SAMSUNG_FEATURES,
             ClientMatchType::UserAgent,
@@ -116,6 +144,7 @@ void Clients::refresh(const std::shared_ptr<Config>& config)
         // User-Agent: ?
         {
             "Samsung Blu-ray Player J5500",
+            DEFAULT_CLIENT_GROUP,
             ClientType::SamsungBDJ5500,
             QUIRK_FLAG_SAMSUNG | QUIRK_FLAG_SAMSUNG_FEATURES,
             ClientMatchType::UserAgent,
@@ -125,11 +154,22 @@ void Clients::refresh(const std::shared_ptr<Config>& config)
         // User-Agent: ?
         {
             "Dual CR 510",
+            DEFAULT_CLIENT_GROUP,
             ClientType::IRadio,
             QUIRK_FLAG_IRADIO,
             ClientMatchType::UserAgent,
             "EC-IRADIO/1.0",
         },
+
+        // User-Agent(actionReq): Panasonic MIL DLNA CP UPnP/1.0 DLNADOC/1.50
+        {
+            "Panasonic TV",
+            DEFAULT_CLIENT_GROUP,
+            ClientType::PanasonicTV,
+            QUIRK_FLAG_PANASONIC,
+            ClientMatchType::UserAgent,
+            "Panasonic MIL DLNA CP",
+        },
     };
 
     auto clientConfigList = config->getClientConfigListOption(CFG_CLIENTS_LIST);
@@ -139,7 +179,7 @@ void Clients::refresh(const std::shared_ptr<Config>& config)
     }
 }
 
-void Clients::addClientByDiscovery(const struct sockaddr_storage* addr, const std::string& userAgent, const std::string& descLocation)
+void ClientManager::addClientByDiscovery(const std::shared_ptr<GrbNet>& addr, const std::string& userAgent, const std::string& descLocation)
 {
 #if 0 // only needed if UserAgent is not good enough
     const ClientInfo* info = nullptr;
@@ -152,7 +192,7 @@ void Clients::addClientByDiscovery(const struct sockaddr_storage* addr, const st
 #endif
 }
 
-const ClientInfo* Clients::getInfo(const struct sockaddr_storage* addr, const std::string& userAgent)
+const ClientInfo* ClientManager::getInfo(const std::shared_ptr<GrbNet>& addr, const std::string& userAgent) const
 {
     // 1. by IP address
     auto info = getInfoByAddr(addr);
@@ -179,44 +219,27 @@ const ClientInfo* Clients::getInfo(const struct sockaddr_storage* addr, const st
         updateCache(addr, userAgent, info);
     }
 
-    log_debug("client info: {} '{}' -> '{}' as {}", sockAddrGetNameInfo(reinterpret_cast<const struct sockaddr*>(addr)), userAgent, info->name, ClientConfig::mapClientType(info->type));
+    log_debug("client info: {} '{}' -> '{}' as {}", addr->getNameInfo(), userAgent, info->name, ClientConfig::mapClientType(info->type));
     return info;
 }
 
-const ClientInfo* Clients::getInfoByAddr(const struct sockaddr_storage* addr) const
+const ClientInfo* ClientManager::getInfoByAddr(const std::shared_ptr<GrbNet>& addr) const
 {
     auto it = std::find_if(clientInfo.begin(), clientInfo.end(), [=](auto&& c) {
         if (c.matchType != ClientMatchType::IP)
             return false;
-
-        if (c.match.find(':') != std::string::npos) {
-            // IPv6
-            struct sockaddr_in6 clientAddr = {};
-            clientAddr.sin6_family = AF_INET6;
-            if ((inet_pton(AF_INET6, c.match.c_str(), &clientAddr.sin6_addr) == 1) && (sockAddrCmpAddr(reinterpret_cast<const struct sockaddr*>(&clientAddr), reinterpret_cast<const struct sockaddr*>(addr)) == 0))
-                return true;
-        } else if (c.match.find('.') != std::string::npos) {
-            // IPv4
-            struct sockaddr_in clientAddr = {};
-            clientAddr.sin_family = AF_INET;
-            clientAddr.sin_addr.s_addr = inet_addr(c.match.c_str());
-            if (sockAddrCmpAddr(reinterpret_cast<const struct sockaddr*>(&clientAddr), reinterpret_cast<const struct sockaddr*>(addr)) == 0)
-                return true;
-        }
-
-        return false;
+        return addr->equals(c.match);
     });
 
     if (it != clientInfo.end()) {
-        auto ip = getHostName(reinterpret_cast<const struct sockaddr*>(addr));
-        log_debug("found client by IP (ip='{}')", ip);
+        log_debug("found client by IP (ip='{}')", addr->getHostName());
         return &(*it);
     }
 
     return nullptr;
 }
 
-const ClientInfo* Clients::getInfoByType(const std::string& match, ClientMatchType type) const
+const ClientInfo* ClientManager::getInfoByType(const std::string& match, ClientMatchType type) const
 {
     if (!match.empty()) {
         auto it = std::find_if(clientInfo.rbegin(), clientInfo.rend(), [=](auto&& c) { return c.matchType == type && match.find(c.match) != std::string::npos; });
@@ -229,34 +252,33 @@ const ClientInfo* Clients::getInfoByType(const std::string& match, ClientMatchTy
     return nullptr;
 }
 
-const ClientInfo* Clients::getInfoByCache(const struct sockaddr_storage* addr) const
+const ClientInfo* ClientManager::getInfoByCache(const std::shared_ptr<GrbNet>& addr) const
 {
     AutoLock lock(mutex);
 
     auto it = std::find_if(cache.begin(), cache.end(), [=](auto&& entry) //
-        { return sockAddrCmpAddr(reinterpret_cast<const struct sockaddr*>(&entry.addr), reinterpret_cast<const struct sockaddr*>(addr)) == 0; });
+        { return entry.addr->equals(addr); });
 
     if (it != cache.end()) {
-        auto hostName = getHostName(reinterpret_cast<const struct sockaddr*>(&it->addr));
-        log_debug("found client by cache (hostname='{}')", hostName);
+        log_debug("found client by cache (hostname='{}')", it->addr->getHostName());
         return it->pInfo;
     }
 
     return nullptr;
 }
 
-void Clients::updateCache(const struct sockaddr_storage* addr, const std::string& userAgent, const ClientInfo* pInfo)
+void ClientManager::updateCache(const std::shared_ptr<GrbNet>& addr, const std::string& userAgent, const ClientInfo* pInfo) const
 {
     AutoLock lock(mutex);
 
     // house cleaning, remove old entries
     auto now = currentTime();
     cache.erase(std::remove_if(cache.begin(), cache.end(),
-                    [now](auto&& entry) { return entry.last + std::chrono::hours(6) < now; }),
+                    [this, now](auto&& entry) { return entry.last + cacheThreshold < now; }),
         cache.end());
 
     auto it = std::find_if(cache.begin(), cache.end(), [=](auto&& entry) //
-        { return sockAddrCmpAddr(reinterpret_cast<const struct sockaddr*>(&entry.addr), reinterpret_cast<const struct sockaddr*>(addr)) == 0; });
+        { return entry.addr->equals(addr); });
 
     if (it != cache.end()) {
         it->last = now;
@@ -268,11 +290,13 @@ void Clients::updateCache(const struct sockaddr_storage* addr, const std::string
         }
     } else {
         // add new client
-        cache.emplace_back(*addr, userAgent, now, now, pInfo);
+        cache.emplace_back(addr, userAgent, now, now, pInfo);
     }
+    if (this->database)
+        this->database->saveClients(cache);
 }
 
-std::unique_ptr<pugi::xml_document> Clients::downloadDescription(const std::string& location)
+std::unique_ptr<pugi::xml_document> ClientManager::downloadDescription(const std::string& location)
 {
     auto xml = std::make_unique<pugi::xml_document>();
 #if defined(USING_NPUPNP)
