@@ -4,7 +4,7 @@
 
     upnp_headers.cc - this file is part of Gerbera.
 
-    Copyright (C) 2016-2021 Gerbera Contributors
+    Copyright (C) 2016-2022 Gerbera Contributors
 
     Gerbera is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
@@ -26,13 +26,8 @@
 #include "upnp_headers.h" // API
 
 #if !defined(USING_NPUPNP)
-#if (UPNP_VERSION > 11299)
 #include <UpnpExtraHeaders.h>
-#else
-#include <ExtraHeaders.h>
 #endif
-#endif
-#include <string>
 
 #include "common.h"
 #include "util/tools.h"
@@ -63,13 +58,13 @@ void Headers::addHeader(const std::string& key, const std::string& value)
         return;
     }
 
-    log_debug("Adding header: '{}: {}'", cleanKey.c_str(), cleanValue.c_str());
-    headers.emplace(cleanKey, cleanValue);
+    log_debug("Adding header: '{}: {}'", cleanKey, cleanValue);
+    headers.try_emplace(cleanKey, cleanValue);
 }
 
-std::string Headers::formatHeader(const std::pair<std::string, std::string>& header, bool crlf)
+std::string Headers::formatHeader(const std::pair<std::string, std::string>& header)
 {
-    return fmt::format("{}: {}{}", header.first, header.second, (crlf) ? "\r\n" : "");
+    return fmt::format("{}: {}", header.first, header.second);
 }
 
 std::pair<std::string, std::string> Headers::parseHeader(const std::string& header)
@@ -95,7 +90,7 @@ void Headers::writeHeaders(UpnpFileInfo* fileInfo) const
     auto head = const_cast<UpnpListHead*>(UpnpFileInfo_get_ExtraHeadersList(fileInfo));
     for (auto&& iter : headers) {
         UpnpExtraHeaders* h = UpnpExtraHeaders_new();
-        UpnpExtraHeaders_set_resp(h, formatHeader(iter, false).c_str());
+        UpnpExtraHeaders_set_resp(h, formatHeader(iter).c_str());
         UpnpListInsert(head, UpnpListEnd(head), const_cast<UpnpListHead*>(UpnpExtraHeaders_get_node(h)));
     }
 #endif
@@ -109,8 +104,7 @@ std::map<std::string, std::string> Headers::readHeaders(UpnpFileInfo* fileInfo)
     std::map<std::string, std::string> ret;
 
     auto head = const_cast<UpnpListHead*>(UpnpFileInfo_get_ExtraHeadersList(fileInfo));
-    UpnpListIter pos;
-    for (pos = UpnpListBegin(head); pos != UpnpListEnd(head); pos = UpnpListNext(head, pos)) {
+    for (auto pos = UpnpListBegin(head); pos != UpnpListEnd(head); pos = UpnpListNext(head, pos)) {
         auto extra = reinterpret_cast<UpnpExtraHeaders*>(pos);
         std::string header = UpnpExtraHeaders_get_resp(extra);
         ret.insert(parseHeader(header));
