@@ -4,7 +4,7 @@
 
     upnp_headers.h - this file is part of Gerbera.
 
-    Copyright (C) 2016-2021 Gerbera Contributors
+    Copyright (C) 2016-2022 Gerbera Contributors
 
     Gerbera is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
@@ -39,11 +39,11 @@ public:
     static std::map<std::string, std::string> readHeaders(UpnpFileInfo* fileInfo);
 
 private:
-    static std::string formatHeader(const std::pair<std::string, std::string>& header, bool crlf);
+    static std::string formatHeader(const std::pair<std::string, std::string>& header);
     static std::pair<std::string, std::string> parseHeader(const std::string& header);
     static std::string stripInvalid(const std::string& value);
 
     std::map<std::string, std::string> headers;
 };
 
-#endif //GERBERA_HEADERS_H
+#endif // GERBERA_HEADERS_H
