@@ -25,19 +25,23 @@
 
 #include "upnp_quirks.h" // API
 
+#include <array>
+#include <utility>
+
 #include "cds_objects.h"
 #include "content/content_manager.h"
 #include "database/database.h"
 #include "server.h"
+#include "util/grb_net.h"
 #include "util/tools.h"
 #include "util/upnp_clients.h"
 #include "util/upnp_headers.h"
 
-Quirks::Quirks(std::shared_ptr<Context> context, const struct sockaddr_storage* addr, const std::string& userAgent)
-    : context(std::move(context))
-    , content(this->context->getServer()->getContent())
+Quirks::Quirks(const UpnpXMLBuilder& xmlBuilder, const ClientManager& clients, const std::shared_ptr<GrbNet>& addr, const std::string& userAgent)
+    : xmlBuilder(xmlBuilder)
 {
-    pClientInfo = this->context->getClients()->getInfo(addr, userAgent);
+    if (addr || !userAgent.empty())
+        pClientInfo = clients.getInfo(addr, userAgent);
 }
 
 int Quirks::checkFlags(int flags) const
@@ -45,6 +49,11 @@ int Quirks::checkFlags(int flags) const
     return pClientInfo ? pClientInfo->flags & flags : 0;
 }
 
+std::string Quirks::getGroup() const
+{
+    return pClientInfo ? pClientInfo->group : DEFAULT_CLIENT_GROUP;
+}
+
 void Quirks::addCaptionInfo(const std::shared_ptr<CdsItem>& item, Headers& headers)
 {
     if ((pClientInfo->flags & QUIRK_FLAG_SAMSUNG) == 0)
@@ -53,22 +62,22 @@ void Quirks::addCaptionInfo(const std::shared_ptr<CdsItem>& item, Headers& heade
     if (item->getClass() != UPNP_CLASS_VIDEO_ITEM)
         return;
 
-    auto [url, subAdded] = UpnpXMLBuilder::renderSubtitle(context->getServer()->getVirtualUrl(), item);
+    auto subAdded = xmlBuilder.renderSubtitleURL(item);
     if (subAdded) {
-        log_debug("Call for Samsung CaptionInfo.sec: {}", url);
-        headers.addHeader("CaptionInfo.sec", url);
-        headers.addHeader("getCaptionInfo.sec", url);
+        log_debug("Call for Samsung CaptionInfo.sec: {}", subAdded.value());
+        headers.addHeader("CaptionInfo.sec", subAdded.value());
+        headers.addHeader("getCaptionInfo.sec", subAdded.value());
     }
 }
 
-void Quirks::getSamsungFeatureList(ActionRequest& request)
+void Quirks::getSamsungFeatureList(ActionRequest& request) const
 {
     if ((pClientInfo->flags & QUIRK_FLAG_SAMSUNG) == 0)
         return;
 
     log_debug("Call for Samsung extension: X_GetFeatureList");
 
-    auto response = UpnpXMLBuilder::createResponse(request.getActionName(), UPNP_DESC_CDS_SERVICE_TYPE);
+    auto response = xmlBuilder.createResponse(request.getActionName(), UPNP_DESC_CDS_SERVICE_TYPE);
     pugi::xml_document respRoot;
     auto features = respRoot.append_child("Features");
     features.append_attribute("xmlns") = "urn:schemas-upnp-org:av:avs";
@@ -95,7 +104,7 @@ void Quirks::getSamsungFeatureList(ActionRequest& request)
     request.setResponse(std::move(response));
 }
 
-std::vector<std::shared_ptr<CdsObject>> Quirks::getSamsungFeatureRoot(const std::string& objId)
+std::vector<std::shared_ptr<CdsObject>> Quirks::getSamsungFeatureRoot(Database& database, const std::string& objId) const
 {
     if ((pClientInfo->flags & QUIRK_FLAG_SAMSUNG_FEATURES) == 0)
         return {};
@@ -109,13 +118,13 @@ std::vector<std::shared_ptr<CdsObject>> Quirks::getSamsungFeatureRoot(const std:
         // { "T", "object.item.textItem" },
     };
     if (containers.find(objId) != containers.end()) {
-        return this->context->getDatabase()->findObjectByContentClass(containers.at(objId));
+        return database.findObjectByContentClass(containers.at(objId));
     }
 
     return {};
 }
 
-void Quirks::getSamsungObjectIDfromIndex(ActionRequest& request)
+void Quirks::getSamsungObjectIDfromIndex(ActionRequest& request) const
 {
     if ((pClientInfo->flags & QUIRK_FLAG_SAMSUNG_FEATURES) == 0)
         return;
@@ -131,12 +140,12 @@ void Quirks::getSamsungObjectIDfromIndex(ActionRequest& request)
 
     log_debug("X_GetObjectIDfromIndex CategoryType [{}] Index[{}]", categoryType, index);
 
-    auto response = UpnpXMLBuilder::createResponse(request.getActionName(), UPNP_DESC_CDS_SERVICE_TYPE);
+    auto response = xmlBuilder.createResponse(request.getActionName(), UPNP_DESC_CDS_SERVICE_TYPE);
     response->document_element().append_child("ObjectID").append_child(pugi::node_pcdata).set_value("0");
     request.setResponse(std::move(response));
 }
 
-void Quirks::getSamsungIndexfromRID(ActionRequest& request)
+void Quirks::getSamsungIndexfromRID(ActionRequest& request) const
 {
     if ((pClientInfo->flags & QUIRK_FLAG_SAMSUNG_FEATURES) == 0)
         return;
@@ -151,7 +160,7 @@ void Quirks::getSamsungIndexfromRID(ActionRequest& request)
 
     log_debug("X_GetIndexfromRID CategoryType [{}] RID[{}]", categoryType, rID);
 
-    auto response = UpnpXMLBuilder::createResponse(request.getActionName(), UPNP_DESC_CDS_SERVICE_TYPE);
+    auto response = xmlBuilder.createResponse(request.getActionName(), UPNP_DESC_CDS_SERVICE_TYPE);
     response->document_element().append_child("Index").append_child(pugi::node_pcdata).set_value("0");
     request.setResponse(std::move(response));
 }
@@ -160,7 +169,8 @@ void Quirks::restoreSamsungBookMarkedPosition(const std::shared_ptr<CdsItem>& it
 {
     if ((pClientInfo->flags & QUIRK_FLAG_SAMSUNG_BOOKMARK_SEC) == 0 && (pClientInfo->flags & QUIRK_FLAG_SAMSUNG_BOOKMARK_MSEC) == 0)
         return;
-    auto positionToRestore = item->getBookMarkPos().count();
+
+    auto positionToRestore = item->getPlayStatus() ? item->getPlayStatus()->getBookMarkPosition().count() : 0;
     if (positionToRestore > 10)
         positionToRestore -= 10;
     log_debug("restoreSamsungBookMarkedPosition: ObjectID [{}] positionToRestore [{}] sec", item->getID(), positionToRestore);
@@ -172,26 +182,27 @@ void Quirks::restoreSamsungBookMarkedPosition(const std::shared_ptr<CdsItem>& it
     result.append_child("sec:dcmInfo").append_child(pugi::node_pcdata).set_value(dcmInfo.c_str());
 }
 
-void Quirks::saveSamsungBookMarkedPosition(ActionRequest& request)
+void Quirks::saveSamsungBookMarkedPosition(Database& database, ActionRequest& request) const
 {
     if ((pClientInfo->flags & QUIRK_FLAG_SAMSUNG_BOOKMARK_SEC) == 0 && (pClientInfo->flags & QUIRK_FLAG_SAMSUNG_BOOKMARK_MSEC) == 0) {
         log_debug("saveSamsungBookMarkedPosition called, but it is not enabled for this client");
     } else {
         auto divider = (pClientInfo->flags & QUIRK_FLAG_SAMSUNG_BOOKMARK_MSEC) == 0 ? 1 : 1000;
         auto reqRoot = request.getRequest()->document_element();
-        auto objectID = reqRoot.child("ObjectID").text().as_string();
-        auto bookMarkPos = std::to_string(stoiString(reqRoot.child("PosSecond").text().as_string()) / divider);
+        auto objectID = stoiString(reqRoot.child("ObjectID").text().as_string());
+        auto bookMarkPos = stoiString(reqRoot.child("PosSecond").text().as_string()) / divider;
         [[maybe_unused]] auto categoryType = reqRoot.child("CategoryType").text().as_string();
         [[maybe_unused]] auto rID = reqRoot.child("RID").text().as_string();
 
         log_debug("saveSamsungBookMarkedPosition: ObjectID [{}] PosSecond [{}] CategoryType [{}] RID [{}]", objectID, bookMarkPos, categoryType, rID);
-
-        std::map<std::string, std::string> m {
-            { "bookmarkpos", bookMarkPos },
-        };
-        content->updateObject(stoiString(objectID), m);
+        auto playStatus = database.getPlayStatus(pClientInfo->group, objectID);
+        if (!playStatus)
+            playStatus = std::make_shared<ClientStatusDetail>(pClientInfo->group, objectID, 1, bookMarkPos, 0, 0);
+        else
+            playStatus->setBookMarkPosition(bookMarkPos);
+        database.savePlayStatus(playStatus);
     }
-    auto response = UpnpXMLBuilder::createResponse(request.getActionName(), UPNP_DESC_CDS_SERVICE_TYPE);
+    auto response = xmlBuilder.createResponse(request.getActionName(), UPNP_DESC_CDS_SERVICE_TYPE);
     request.setResponse(std::move(response));
 }
 
@@ -200,6 +211,11 @@ bool Quirks::blockXmlDeclaration() const
     return (pClientInfo && (pClientInfo->flags & QUIRK_FLAG_IRADIO) == QUIRK_FLAG_IRADIO);
 }
 
+bool Quirks::needsFileNameUri() const
+{
+    return !pClientInfo || (pClientInfo->flags & QUIRK_FLAG_PANASONIC) != QUIRK_FLAG_PANASONIC;
+}
+
 int Quirks::getCaptionInfoCount() const
 {
     return pClientInfo ? pClientInfo->captionInfoCount : -1;
