@@ -1,31 +1,31 @@
 /*MT*
-    
+
     MediaTomb - http://www.mediatomb.cc/
-    
+
     xml_to_json.cc - this file is part of MediaTomb.
-    
+
     Copyright (C) 2005 Gena Batyan <bgeradz@mediatomb.cc>,
                        Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>
-    
+
     Copyright (C) 2006-2010 Gena Batyan <bgeradz@mediatomb.cc>,
                             Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>,
                             Leonhard Wimmer <leo@mediatomb.cc>
-    
+
     Copyright (C) 2020 Patrick Ammann <pammann@gmx.net>
-    
+
     MediaTomb is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
     as published by the Free Software Foundation.
-    
+
     MediaTomb is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
-    
+
     You should have received a copy of the GNU General Public License
     version 2 along with MediaTomb; if not, write to the Free Software
     Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
-    
+
     $Id$
 */
 
@@ -33,7 +33,6 @@
 
 #include "xml_to_json.h"
 
-#include <iostream>
 #include <regex>
 
 #include "util/tools.h"
@@ -63,13 +62,12 @@ void Xml2Json::handleElement(std::ostringstream& buf, const pugi::xml_node& node
         }
     }
 
-    std::string nodeName;
-    bool array = isArray(node, hints, &nodeName);
+    auto [array, nodeName] = isArray(node, hints);
 
     if (array) {
         if (!firstChild)
             buf << ',';
-        buf << getAsString(nodeName.c_str()) << ':';
+        buf << getAsString(nodeName) << ':';
         buf << '[';
         firstChild = true;
     }
@@ -85,7 +83,7 @@ void Xml2Json::handleElement(std::ostringstream& buf, const pugi::xml_node& node
 
             // look ahead
             bool haveChildAttribute = std::distance(child.attributes().begin(), child.attributes().end()) > 0;
-            bool haveChildElement = std::any_of(child.children().begin(), child.children().end(), [&](auto&& el) { return el.type() == pugi::node_element; });
+            bool haveChildElement = std::any_of(child.children().begin(), child.children().end(), [](auto&& el) { return el.type() == pugi::node_element; });
 
             if (array) {
                 if (nodeName != child.name())
@@ -94,7 +92,7 @@ void Xml2Json::handleElement(std::ostringstream& buf, const pugi::xml_node& node
                 buf << getAsString(child.name()) << ':';
             }
 
-            if (haveChildAttribute || haveChildElement || isArray(child, hints, nullptr)) {
+            if (haveChildAttribute || haveChildElement || isArray(child, hints).first) {
                 buf << '{';
                 handleElement(buf, child, hints);
                 buf << '}';
@@ -108,19 +106,19 @@ void Xml2Json::handleElement(std::ostringstream& buf, const pugi::xml_node& node
         buf << ']';
 }
 
-std::string Xml2Json::getAsString(const char* str)
+std::string Xml2Json::getAsString(std::string_view str)
 {
     auto escaped = escape(str, '\\', '"');
 
-    escaped = replaceAllString(escaped, "\n", "\\n");
-    escaped = replaceAllString(escaped, "\r", "\\r");
-    return "\"" + escaped + '"';
+    replaceAllString(escaped, "\n", "\\n");
+    replaceAllString(escaped, "\r", "\\r");
+    return fmt::format(R"("{}")", escaped);
 }
 
 std::string Xml2Json::getValue(const std::string& name, const char* text, const Hints& hints)
 {
     std::string str = text;
-    auto& hintsType = hints.asType;
+    auto&& hintsType = hints.asType;
 
     auto hint = hintsType.find(name);
 
@@ -149,17 +147,13 @@ std::string Xml2Json::getValue(const std::string& name, const char* text, const
     return getAsString(text);
 }
 
-bool Xml2Json::isArray(const pugi::xml_node& node, const Hints& hints, std::string* arrayName)
+std::pair<bool, std::string_view> Xml2Json::isArray(const pugi::xml_node& node, const Hints& hints)
 {
-    auto& hintsArray = hints.asArray;
+    auto&& hintsArray = hints.asArray;
     auto hint = hintsArray.find(node);
 
-    if (hint == hintsArray.end()) {
-        return false;
-    }
+    if (hint == hintsArray.end())
+        return {};
 
-    if (arrayName != nullptr)
-        *arrayName = hint->second;
-
-    return true;
+    return { true, hint->second };
 }
