@@ -30,6 +30,7 @@
 #include "context.h"
 #include "database/database.h"
 #include "upnp_xml.h"
+#include "util/grb_net.h"
 #include "util/upnp_clients.h"
 
 #include <fmt/chrono.h>
@@ -47,20 +48,35 @@ void Web::Clients::process()
     auto clients = root.append_child("clients");
     xml2JsonHints->setArrayName(clients, "client");
 
-    auto&& arr = content->getContext()->getClients()->getClientList();
-    for (auto&& obj : arr) {
+    auto&& clientArr = content->getContext()->getClients()->getClientList();
+    for (auto&& obj : clientArr) {
         auto item = clients.append_child("client");
-        auto ip = sockAddrGetNameInfo(reinterpret_cast<const struct sockaddr*>(&obj.addr));
+        auto ip = obj.addr->getNameInfo();
         item.append_attribute("ip") = ip.c_str();
-        auto hostName = getHostName(reinterpret_cast<const struct sockaddr*>(&obj.addr));
+        auto hostName = obj.addr->getHostName();
         item.append_attribute("host") = hostName.c_str();
         item.append_attribute("time") = secondsToString(obj.age).c_str();
         item.append_attribute("last") = secondsToString(obj.last).c_str();
         item.append_attribute("userAgent") = obj.userAgent.c_str();
         item.append_attribute("name") = obj.pInfo->name.c_str();
+        item.append_attribute("group") = obj.pInfo->group.c_str();
         item.append_attribute("match") = obj.pInfo->match.c_str();
-        item.append_attribute("flags") = ClientConfig::mapFlags(obj.pInfo->flags).c_str();
+        auto flags = ClientConfig::mapFlags(obj.pInfo->flags);
+        replaceAllString(flags, "|", " | ");
+        item.append_attribute("flags") = flags.c_str();
         item.append_attribute("matchType") = ClientConfig::mapMatchType(obj.pInfo->matchType).data();
         item.append_attribute("clientType") = ClientConfig::mapClientType(obj.pInfo->type).data();
     }
+
+    auto groups = root.append_child("groups");
+    xml2JsonHints->setArrayName(groups, "group");
+    auto&& groupArr = content->getContext()->getDatabase()->getClientGroupStats();
+    for (auto&& obj : groupArr) {
+        auto item = groups.append_child("group");
+        item.append_attribute("name") = obj.at("name").c_str();
+        item.append_attribute("count") = obj.at("count").c_str();
+        item.append_attribute("playCount") = obj.at("playCount").c_str();
+        item.append_attribute("bookmarks") = obj.at("bookmarks").c_str();
+        item.append_attribute("last") = obj.at("last").c_str(); // obj.last).c_str();
+    }
 }
