@@ -196,6 +196,10 @@ void Web::ConfigLoad::process()
         createItem(item, cs->getItemPath(i, ATTR_CLIENTS_CLIENT_USERAGENT), cs->option, ATTR_CLIENTS_CLIENT_USERAGENT, cs);
         setValue(item, client->getUserAgent());
 
+        item = values.append_child("item");
+        createItem(item, cs->getItemPath(i, ATTR_CLIENTS_CLIENT_GROUP), cs->option, ATTR_CLIENTS_CLIENT_GROUP, cs);
+        setValue(item, client->getGroup());
+
         item = values.append_child("item");
         createItem(item, cs->getItemPath(i, ATTR_CLIENTS_UPNP_CAPTION_COUNT), cs->option, ATTR_CLIENTS_UPNP_CAPTION_COUNT, cs);
         setValue(item, client->getCaptionInfoCount());
@@ -209,6 +213,12 @@ void Web::ConfigLoad::process()
 
         item = values.append_child("item");
         createItem(item, cs->getItemPath(ITEM_PATH_NEW, ATTR_CLIENTS_CLIENT_USERAGENT), cs->option, ATTR_CLIENTS_CLIENT_USERAGENT, ConfigDefinition::findConfigSetup(ATTR_CLIENTS_CLIENT_USERAGENT));
+
+        item = values.append_child("item");
+        createItem(item, cs->getItemPath(ITEM_PATH_NEW, ATTR_CLIENTS_CLIENT_GROUP), cs->option, ATTR_CLIENTS_CLIENT_GROUP, ConfigDefinition::findConfigSetup(ATTR_CLIENTS_CLIENT_GROUP));
+
+        item = values.append_child("item");
+        createItem(item, cs->getItemPath(ITEM_PATH_NEW, ATTR_CLIENTS_UPNP_CAPTION_COUNT), cs->option, ATTR_CLIENTS_UPNP_CAPTION_COUNT, ConfigDefinition::findConfigSetup(ATTR_CLIENTS_UPNP_CAPTION_COUNT));
     }
 
     // write import tweaks
@@ -305,28 +315,35 @@ void Web::ConfigLoad::process()
     cs = ConfigDefinition::findConfigSetup(CFG_TRANSCODING_PROFILE_LIST);
     auto transcoding = cs->getValue()->getTranscodingProfileListOption();
     int pr = 0;
-    std::map<std::string, int> profiles;
-    for (auto&& [key, val] : transcoding->getList()) {
-        for (auto&& [a, name] : *val) {
-            auto item = values.append_child("item");
-            createItem(item, cs->getItemPath(pr, ATTR_TRANSCODING_MIMETYPE_PROF_MAP, ATTR_TRANSCODING_MIMETYPE_PROF_MAP_TRANSCODE, ATTR_TRANSCODING_MIMETYPE_PROF_MAP_MIMETYPE), cs->option, ATTR_TRANSCODING_MIMETYPE_PROF_MAP_MIMETYPE, cs);
-            setValue(item, key);
+    std::map<std::string, std::shared_ptr<TranscodingProfile>> profiles;
+    for (auto&& filter : transcoding->getFilterList()) {
+        auto item = values.append_child("item");
+        createItem(item, cs->getItemPath(pr, ATTR_TRANSCODING_MIMETYPE_FILTER, ATTR_TRANSCODING_MIMETYPE_PROF_MAP_MIMETYPE), cs->option, ATTR_TRANSCODING_MIMETYPE_PROF_MAP_MIMETYPE, cs);
+        setValue(item, filter->getMimeType());
 
-            item = values.append_child("item");
-            createItem(item, cs->getItemPath(pr, ATTR_TRANSCODING_MIMETYPE_PROF_MAP, ATTR_TRANSCODING_MIMETYPE_PROF_MAP_TRANSCODE, ATTR_TRANSCODING_MIMETYPE_PROF_MAP_USING), cs->option, ATTR_TRANSCODING_MIMETYPE_PROF_MAP_USING, cs);
-            setValue(item, name->getName());
-            profiles.emplace(name->getName(), pr);
+        item = values.append_child("item");
+        createItem(item, cs->getItemPath(pr, ATTR_TRANSCODING_MIMETYPE_FILTER, ATTR_TRANSCODING_MIMETYPE_PROF_MAP_USING), cs->option, ATTR_TRANSCODING_MIMETYPE_PROF_MAP_USING, cs);
+        setValue(item, filter->getTranscoderName());
 
-            pr++;
-        }
+        item = values.append_child("item");
+        createItem(item, cs->getItemPath(pr, ATTR_TRANSCODING_MIMETYPE_FILTER, ATTR_TRANSCODING_PROFILES_PROFLE_SRCDLNA), cs->option, ATTR_TRANSCODING_PROFILES_PROFLE_SRCDLNA, cs);
+        setValue(item, filter->getSourceProfile());
+
+        item = values.append_child("item");
+        createItem(item, cs->getItemPath(pr, ATTR_TRANSCODING_MIMETYPE_FILTER, ATTR_TRANSCODING_PROFILES_PROFLE_CLIENTFLAGS), cs->option, ATTR_TRANSCODING_PROFILES_PROFLE_CLIENTFLAGS, cs);
+        setValue(item, ClientConfig::mapFlags(filter->getClientFlags()));
+
+        if (filter->getTranscodingProfile())
+            profiles[filter->getTranscodingProfile()->getName()] = filter->getTranscodingProfile();
+
+        pr++;
     }
 
     pr = 0;
-    for (auto&& [key, val] : profiles) {
-        auto entry = transcoding->getByName(key, true);
+    for (auto&& [name, entry] : profiles) {
         auto item = values.append_child("item");
         createItem(item, cs->getItemPath(pr, ATTR_TRANSCODING_PROFILES_PROFLE, ATTR_TRANSCODING_PROFILES_PROFLE_NAME), cs->option, ATTR_TRANSCODING_PROFILES_PROFLE_NAME);
-        setValue(item, entry->getName());
+        setValue(item, name);
 
         item = values.append_child("item");
         createItem(item, cs->getItemPath(pr, ATTR_TRANSCODING_PROFILES_PROFLE, ATTR_TRANSCODING_PROFILES_PROFLE_CLIENTFLAGS), cs->option, ATTR_TRANSCODING_PROFILES_PROFLE_CLIENTFLAGS);
@@ -334,23 +351,27 @@ void Web::ConfigLoad::process()
 
         item = values.append_child("item");
         createItem(item, cs->getItemPath(pr, ATTR_TRANSCODING_PROFILES_PROFLE, ATTR_TRANSCODING_PROFILES_PROFLE_ENABLED), cs->option, ATTR_TRANSCODING_PROFILES_PROFLE_ENABLED);
-        setValue(item, entry->getEnabled());
+        setValue(item, entry->isEnabled());
 
         item = values.append_child("item");
         createItem(item, cs->getItemPath(pr, ATTR_TRANSCODING_PROFILES_PROFLE, ATTR_TRANSCODING_PROFILES_PROFLE_TYPE), cs->option, ATTR_TRANSCODING_PROFILES_PROFLE_TYPE);
         setValue(item, (entry->getType() == TR_External ? "external" : "none"));
 
+        item = values.append_child("item");
+        createItem(item, cs->getItemPath(pr, ATTR_TRANSCODING_PROFILES_PROFLE, ATTR_TRANSCODING_PROFILES_PROFLE_DLNAPROF), cs->option, ATTR_TRANSCODING_PROFILES_PROFLE_DLNAPROF);
+        setValue(item, entry->getDlnaProfile());
+
         item = values.append_child("item");
         createItem(item, cs->getItemPath(pr, ATTR_TRANSCODING_PROFILES_PROFLE, ATTR_TRANSCODING_PROFILES_PROFLE_MIMETYPE), cs->option, ATTR_TRANSCODING_PROFILES_PROFLE_MIMETYPE);
         setValue(item, entry->getTargetMimeType());
 
         item = values.append_child("item");
         createItem(item, cs->getItemPath(pr, ATTR_TRANSCODING_PROFILES_PROFLE, ATTR_TRANSCODING_PROFILES_PROFLE_RES), cs->option, ATTR_TRANSCODING_PROFILES_PROFLE_RES);
-        setValue(item, entry->getAttribute(MetadataHandler::getResAttrName(R_RESOLUTION)));
+        setValue(item, entry->getAttributeOverride(CdsResource::Attribute::RESOLUTION));
 
         item = values.append_child("item");
         createItem(item, cs->getItemPath(pr, ATTR_TRANSCODING_PROFILES_PROFLE, ATTR_TRANSCODING_PROFILES_PROFLE_ACCURL), cs->option, ATTR_TRANSCODING_PROFILES_PROFLE_ACCURL);
-        setValue(item, entry->acceptURL());
+        setValue(item, entry->getAcceptURL());
 
         item = values.append_child("item");
         createItem(item, cs->getItemPath(pr, ATTR_TRANSCODING_PROFILES_PROFLE, ATTR_TRANSCODING_PROFILES_PROFLE_SAMPFREQ), cs->option, ATTR_TRANSCODING_PROFILES_PROFLE_SAMPFREQ);
@@ -370,7 +391,7 @@ void Web::ConfigLoad::process()
 
         item = values.append_child("item");
         createItem(item, cs->getItemPath(pr, ATTR_TRANSCODING_PROFILES_PROFLE, ATTR_TRANSCODING_PROFILES_PROFLE_FIRST), cs->option, ATTR_TRANSCODING_PROFILES_PROFLE_FIRST);
-        setValue(item, entry->firstResource());
+        setValue(item, entry->getFirstResource());
 
         item = values.append_child("item");
         createItem(item, cs->getItemPath(pr, ATTR_TRANSCODING_PROFILES_PROFLE, ATTR_TRANSCODING_PROFILES_PROFLE_ACCOGG), cs->option, ATTR_TRANSCODING_PROFILES_PROFLE_ACCOGG);
@@ -415,9 +436,9 @@ void Web::ConfigLoad::process()
     // write autoscan configuration
     for (auto&& ascs : ConfigDefinition::getConfigSetupList<ConfigAutoscanSetup>()) {
         auto autoscan = ascs->getValue()->getAutoscanListOption();
-        for (std::size_t i = 0; i < autoscan->size(); i++) {
-            auto&& entry = autoscan->get(i);
-            auto&& adir = content->getAutoscanDirectory(entry->getLocation());
+        for (std::size_t i = 0; i < autoscan.size(); i++) {
+            auto&& entry = autoscan.at(i);
+            auto&& adir = content->getAutoscanDirectory(entry.getLocation());
             auto item = values.append_child("item");
             createItem(item, ascs->getItemPath(i, ATTR_AUTOSCAN_DIRECTORY_LOCATION), ascs->option, ATTR_AUTOSCAN_DIRECTORY_LOCATION);
             setValue(item, adir->getLocation());
@@ -434,6 +455,10 @@ void Web::ConfigLoad::process()
             createItem(item, ascs->getItemPath(i, ATTR_AUTOSCAN_DIRECTORY_RECURSIVE), ascs->option, ATTR_AUTOSCAN_DIRECTORY_RECURSIVE);
             setValue(item, adir->getRecursive());
 
+            item = values.append_child("item");
+            createItem(item, ascs->getItemPath(i, ATTR_AUTOSCAN_DIRECTORY_MEDIATYPE), ascs->option, ATTR_AUTOSCAN_DIRECTORY_MEDIATYPE);
+            setValue(item, adir->getMediaType());
+
             item = values.append_child("item");
             createItem(item, ascs->getItemPath(i, ATTR_AUTOSCAN_DIRECTORY_HIDDENFILES), ascs->option, ATTR_AUTOSCAN_DIRECTORY_HIDDENFILES);
             setValue(item, adir->getHidden());
@@ -450,7 +475,7 @@ void Web::ConfigLoad::process()
             createItem(item, ascs->getItemPath(i, ATTR_AUTOSCAN_DIRECTORY_LMT), ascs->option, ATTR_AUTOSCAN_DIRECTORY_LMT);
             setValue(item, fmt::format("{:%Y-%m-%d %H:%M:%S}", fmt::localtime(adir->getPreviousLMT().count())));
         }
-        if (autoscan->size() == 0) {
+        if (autoscan.empty()) {
             auto item = values.append_child("item");
             createItem(item, ascs->getItemPath(ITEM_PATH_NEW, ATTR_AUTOSCAN_DIRECTORY_LOCATION), ascs->option, ATTR_AUTOSCAN_DIRECTORY_LOCATION, ConfigDefinition::findConfigSetup(ATTR_AUTOSCAN_DIRECTORY_LOCATION));
 
@@ -463,6 +488,9 @@ void Web::ConfigLoad::process()
             item = values.append_child("item");
             createItem(item, ascs->getItemPath(ITEM_PATH_NEW, ATTR_AUTOSCAN_DIRECTORY_RECURSIVE), ascs->option, ATTR_AUTOSCAN_DIRECTORY_RECURSIVE, ConfigDefinition::findConfigSetup(ATTR_AUTOSCAN_DIRECTORY_RECURSIVE));
 
+            item = values.append_child("item");
+            createItem(item, ascs->getItemPath(ITEM_PATH_NEW, ATTR_AUTOSCAN_DIRECTORY_MEDIATYPE), ascs->option, ATTR_AUTOSCAN_DIRECTORY_MEDIATYPE, ConfigDefinition::findConfigSetup(ATTR_AUTOSCAN_DIRECTORY_MEDIATYPE));
+
             item = values.append_child("item");
             createItem(item, ascs->getItemPath(ITEM_PATH_NEW, ATTR_AUTOSCAN_DIRECTORY_HIDDENFILES), ascs->option, ATTR_AUTOSCAN_DIRECTORY_HIDDENFILES, ConfigDefinition::findConfigSetup(ATTR_AUTOSCAN_DIRECTORY_HIDDENFILES));
 
@@ -492,6 +520,19 @@ void Web::ConfigLoad::process()
             i++;
         }
     }
+    // write content of all vectors
+    for (auto&& vcs : ConfigDefinition::getConfigSetupList<ConfigVectorSetup>()) {
+        int i = 0;
+        auto vector = vcs->getValue()->getVectorOption(true);
+        for (auto&& value : vector) {
+            for (auto&& [key, val] : value) {
+                auto item = values.append_child("item");
+                createItem(item, vcs->getItemPath(i, vcs->option) + key, vcs->option, vcs->optionList[0], vcs); // FIxME
+                setValue(item, val);
+                i++;
+            }
+        }
+    }
 
     // write content of all arrays
     for (auto&& acs : ConfigDefinition::getConfigSetupList<ConfigArraySetup>()) {
