@@ -4,7 +4,7 @@
 
     config_save.cc - this file is part of Gerbera.
 
-    Copyright (C) 2020-2021 Gerbera Contributors
+    Copyright (C) 2020-2022 Gerbera Contributors
 
     Gerbera is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
@@ -30,26 +30,23 @@
 #include "config/client_config.h"
 #include "config/config.h"
 #include "config/config_definition.h"
-#include "config/config_options.h"
 #include "config/config_setup.h"
 #include "content/autoscan.h"
 #include "content/content_manager.h"
 #include "database/database.h"
 #include "metadata/metadata_handler.h"
-#include "transcoding/transcoding.h"
-#include "upnp_xml.h"
 #include "util/upnp_clients.h"
 
-web::configSave::configSave(std::shared_ptr<Context> context, std::shared_ptr<ContentManager> content)
-    : WebRequestHandler(std::move(content))
+Web::ConfigSave::ConfigSave(std::shared_ptr<Context> context, const std::shared_ptr<ContentManager>& content)
+    : WebRequestHandler(content)
     , context(std::move(context))
 {
 }
 
 /// \brief: process config_save request
-void web::configSave::process()
+void Web::ConfigSave::process()
 {
-    check_request();
+    checkRequest();
     auto root = xmlDoc->document_element();
     log_debug("configSave");
     std::string action = param("action");
@@ -73,12 +70,10 @@ void web::configSave::process()
             auto key = fmt::format("data[{}][{}]", i, "id");
             auto item = fmt::format("data[{}][{}]", i, "item");
             auto status = fmt::format("data[{}][{}]", i, "status");
-            bool success = false;
             std::shared_ptr<ConfigSetup> cs;
             log_debug("save item {}='{}' {}", param(item), param(key), param(status));
             if (!param(key).empty() && param(key) != "-1") {
-                config_option_t option = CFG_MAX;
-                option = config_option_t(std::stoi(param(key)));
+                auto option = config_option_t(std::stoi(param(key)));
                 cs = ConfigDefinition::findConfigSetup(option, true);
             } else if (!param(item).empty()) {
                 cs = ConfigDefinition::findConfigSetupByPath(param(item), true);
@@ -88,6 +83,7 @@ void web::configSave::process()
             }
 
             if (cs) {
+                bool success = false;
                 auto value = fmt::format("data[{}][{}]", i, "value");
                 auto orig = fmt::format("data[{}][{}]", i, "origValue");
                 log_debug("found option to update {}", cs->getUniquePath());
@@ -170,7 +166,7 @@ void web::configSave::process()
                 taskEl.append_attribute("text") = fmt::format("Rescanning directory {}", target).c_str();
                 log_info("Rescanning directory {}", target);
             } else {
-                log_error("No such autoscan or dir: {} ({})", target.c_str(), objectID);
+                log_error("No such autoscan or dir: {} ({})", target, objectID);
             }
         } else {
             auto autoScans = content->getAutoscanDirectories();
