@@ -62,7 +62,7 @@ void Web::Containers::process()
     if (!param("select_it").empty())
         containers.append_attribute("select_it") = param("select_it").c_str();
 
-    auto browseParam = BrowseParam(database->loadObject(parentID), BROWSE_DIRECT_CHILDREN | BROWSE_CONTAINERS);
+    auto browseParam = BrowseParam(database->loadObject(DEFAULT_CLIENT_GROUP, parentID), BROWSE_DIRECT_CHILDREN | BROWSE_CONTAINERS);
     auto arr = database->browse(browseParam);
     for (auto&& obj : arr) {
         // if (obj->isContainer())
@@ -75,9 +75,9 @@ void Web::Containers::process()
         int autoscanType = cont->getAutoscanType();
         ce.append_attribute("autoscan_type") = mapAutoscanType(autoscanType).data();
 
-        auto [url, artAdded] = xmlBuilder->renderContainerImage(server->getVirtualUrl(), cont);
-        if (artAdded) {
-            ce.append_attribute("image") = url.c_str();
+        auto url = xmlBuilder->renderContainerImageURL(cont);
+        if (url) {
+            ce.append_attribute("image") = url.value().c_str();
         }
 
         std::string autoscanMode = "none";
@@ -86,7 +86,7 @@ void Web::Containers::process()
 #ifdef HAVE_INOTIFY
             if (config->getBoolOption(CFG_IMPORT_AUTOSCAN_USE_INOTIFY)) {
                 auto adir = database->getAutoscanDirectory(cont->getID());
-                if (adir && (adir->getScanMode() == ScanMode::INotify))
+                if (adir && (adir->getScanMode() == AutoscanDirectory::ScanMode::INotify))
                     autoscanMode = "inotify";
             }
 #endif
