@@ -65,12 +65,11 @@ void Web::Items::process()
     xml2JsonHints->setFieldType("track", "string");
     items.append_attribute("parent_id") = parentID;
 
-    auto container = database->loadObject(parentID);
+    auto container = database->loadObject(DEFAULT_CLIENT_GROUP, parentID);
     auto param = BrowseParam(container, BROWSE_DIRECT_CHILDREN | BROWSE_ITEMS);
     param.setRange(start, count);
 
-    auto c = container->getClass();
-    if (c == UPNP_CLASS_MUSIC_ALBUM || c == UPNP_CLASS_PLAYLIST_CONTAINER)
+    if (container->isSubClass(UPNP_CLASS_MUSIC_ALBUM) || container->isSubClass(UPNP_CLASS_PLAYLIST_CONTAINER))
         param.setFlag(BROWSE_TRACK_SORT);
 
     // get contents of request
@@ -110,7 +109,7 @@ void Web::Items::process()
 
         if (startpointId != INVALID_OBJECT_ID) {
             auto startPtDir = database->getAutoscanDirectory(startpointId);
-            if (startPtDir && startPtDir->getScanMode() == ScanMode::INotify) {
+            if (startPtDir && startPtDir->getScanMode() == AutoscanDirectory::ScanMode::INotify) {
                 protectItems = true;
                 if (autoscanType == 0 || startPtDir->persistent())
                     protectContainer = true;
@@ -127,6 +126,7 @@ void Web::Items::process()
 
     // ouput objects of container
     int cnt = start + 1;
+    auto cls = container->getClass();
     auto trackFmt = (param.getTotalMatches() >= 100) ? "{:03}" : "{:02}";
     for (auto&& arrayObj : arr) {
         auto item = items.append_child("item");
@@ -134,20 +134,20 @@ void Web::Items::process()
         item.append_child("title").append_child(pugi::node_pcdata).set_value(arrayObj->getTitle().c_str());
 
         auto objItem = std::static_pointer_cast<CdsItem>(arrayObj);
-        if (objItem->getPartNumber() > 0 && c == UPNP_CLASS_MUSIC_ALBUM)
+        if (objItem->getPartNumber() > 0 && startswith(cls, UPNP_CLASS_MUSIC_ALBUM))
             item.append_child("part").append_child(pugi::node_pcdata).set_value(fmt::format("{:02}", objItem->getPartNumber()).c_str());
-        if (objItem->getTrackNumber() > 0 && c != UPNP_CLASS_CONTAINER)
+        if (objItem->getTrackNumber() > 0 && !startswith(cls, UPNP_CLASS_CONTAINER))
             item.append_child("track").append_child(pugi::node_pcdata).set_value(fmt::format(trackFmt, objItem->getTrackNumber()).c_str());
         else
             item.append_child("track").append_child(pugi::node_pcdata).set_value(fmt::format(trackFmt, cnt).c_str());
         item.append_child("mtype").append_child(pugi::node_pcdata).set_value(objItem->getMimeType().c_str());
         item.append_child("upnp_class").append_child(pugi::node_pcdata).set_value(objItem->getClass().c_str());
-        std::string res = UpnpXMLBuilder::getFirstResourcePath(objItem);
+        std::string res = xmlBuilder->getFirstResourcePath(objItem);
         item.append_child("res").append_child(pugi::node_pcdata).set_value(res.c_str());
 
-        auto [url, artAdded] = xmlBuilder->renderItemImage(server->getVirtualUrl(), objItem);
-        if (artAdded) {
-            item.append_child("image").append_child(pugi::node_pcdata).set_value(url.c_str());
+        auto url = xmlBuilder->renderItemImageURL(objItem);
+        if (url) {
+            item.append_child("image").append_child(pugi::node_pcdata).set_value(url.value().c_str());
         }
         cnt++;
     }
