@@ -1,29 +1,29 @@
 /*MT*
-    
+
     MediaTomb - http://www.mediatomb.cc/
-    
+
     web_request_handler.h - this file is part of MediaTomb.
-    
+
     Copyright (C) 2005 Gena Batyan <bgeradz@mediatomb.cc>,
                        Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>
-    
+
     Copyright (C) 2006-2010 Gena Batyan <bgeradz@mediatomb.cc>,
                             Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>,
                             Leonhard Wimmer <leo@mediatomb.cc>
-    
+
     MediaTomb is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
     as published by the Free Software Foundation.
-    
+
     MediaTomb is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
-    
+
     You should have received a copy of the GNU General Public License
     version 2 along with MediaTomb; if not, write to the Free Software
     Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
-    
+
     $Id$
 */
 
@@ -42,32 +42,26 @@
 #include "util/generic_task.h"
 #include "util/xml_to_json.h"
 
-namespace web {
+namespace Web {
 
 class SessionException : public std::runtime_error {
-public:
-    explicit SessionException(const std::string& message)
-        : std::runtime_error(message)
-    {
-    }
+    using std::runtime_error::runtime_error;
 };
 
 class LoginException : public std::runtime_error {
-public:
-    explicit LoginException(const std::string& message)
-        : std::runtime_error(message)
-    {
-    }
+    using std::runtime_error::runtime_error;
 };
 
 class SessionManager;
 
+static constexpr auto SID = "GerberaSID";
+
 /// \brief This class is responsible for processing requests that come to the user interface.
 class WebRequestHandler : public RequestHandler {
 protected:
-    std::shared_ptr<web::SessionManager> sessionManager;
+    std::shared_ptr<Web::SessionManager> sessionManager;
 
-    bool checkRequestCalled;
+    bool checkRequestCalled {};
 
     /// \brief Decoded URL parameters are stored as a dictionary.
     std::map<std::string, std::string> params;
@@ -76,16 +70,16 @@ protected:
     std::string filename;
 
     /// \brief We can also always see what mode was requested.
-    enum UpnpOpenFileMode mode;
+    enum UpnpOpenFileMode mode {};
 
     /// \brief This is the xml document, the root node to be populated by process() method.
-    std::shared_ptr<pugi::xml_document> xmlDoc;
+    std::unique_ptr<pugi::xml_document> xmlDoc;
 
     /// \brief Hints for Xml2Json, such that we know when to create an array
-    std::shared_ptr<Xml2Json::Hints> xml2JsonHints;
+    std::unique_ptr<Xml2Json::Hints> xml2JsonHints;
 
     /// \brief The current session, used for this request; will be filled by
-    /// check_request()
+    /// checkRequest()
     std::shared_ptr<Session> session;
 
     /// \brief Little support function to access stuff from the dictionary in
@@ -94,40 +88,30 @@ protected:
     /// \return Value of the parameter with the given name or nullptr if not found.
     std::string param(const std::string& name) const { return getValueOrDefault(params, name); }
 
-    int intParam(const std::string& name, int invalid = 0);
-    bool boolParam(const std::string& name);
+    int intParam(const std::string& name, int invalid = 0) const;
+    bool boolParam(const std::string& name) const;
 
     /// \brief Checks if the incoming request is valid.
     ///
     /// Each request going to the ui must at least have a valid session id,
     /// and a driver parameter. Also, there can only by a primary or a
     /// a decondary driver.
-    void check_request(bool checkLogin = true);
-
-    /// \brief Helper function to create a generic XML document header.
-    /// \param xsl_link If not nullptr, also adds header information that is required for the XSL processor.
-    /// \return The header as a string... because our parser does not yet understand <? ?> stuff :)
-    static std::string renderXMLHeader();
-
-    /// \brief Prepares the output buffer and calls the process function.
-    /// \return IOHandler
-    /// \todo Genych, chto tut proishodit, ya tolkom che to ne wrubaus??
-    std::unique_ptr<IOHandler> open(enum UpnpOpenFileMode mode);
+    void checkRequest(bool checkLogin = true);
 
     /// \brief add the ui update ids from the given session as xml tags to the given root element
     /// \param session the session from which the ui update ids should be taken
     /// \param updateIDsEl the xml element to add the elements to
-    static void addUpdateIDs(const std::shared_ptr<Session>& session, pugi::xml_node* updateIDsEl);
+    static void addUpdateIDs(const std::shared_ptr<Session>& session, pugi::xml_node& updateIDsEl);
 
     /// \brief check if ui update ids should be added to the response and add
     /// them in that case.
-    /// must only be called after check_request
+    /// must only be called after checkRequest
     void handleUpdateIDs();
 
     /// \brief add the content manager task to the given xml element as xml elements
     /// \param task the task to add to the given xml element
     /// \param parent the xml element to add the elements to
-    static void appendTask(const std::shared_ptr<GenericTask>& task, pugi::xml_node* parent);
+    static void appendTask(const std::shared_ptr<GenericTask>& task, pugi::xml_node& parent);
 
     /// \brief check if accounts are enabled in the config
     /// \return true if accounts are enabled, false if not
@@ -137,7 +121,7 @@ protected:
 
 public:
     /// \brief Constructor, currently empty.
-    explicit WebRequestHandler(std::shared_ptr<ContentManager> content);
+    explicit WebRequestHandler(const std::shared_ptr<ContentManager>& content);
 
     /// \brief Returns information about the requested content.
     /// \param filename Requested URL
@@ -159,6 +143,6 @@ public:
     virtual void process() = 0;
 };
 
-} // namespace web
+} // namespace Web
 
 #endif // __WEB_REQUEST_HANDLER_H__
