@@ -2,11 +2,10 @@
 #include <gtest/gtest.h>
 
 #include "config/config_generator.h"
-#include "config/config_manager.h"
 #include <fstream>
 #include <regex>
 
-using namespace ::testing;
+using ::testing::MatchesRegex;
 
 class ConfigGeneratorTest : public ::testing::Test {
 
