@@ -56,8 +56,9 @@ public:
         return false;
     }
     std::map<std::string, std::string> getDictionaryOption(config_option_t option) const override { return {}; }
+    std::vector<std::vector<std::pair<std::string, std::string>>> getVectorOption(config_option_t option) const override { return {}; }
     std::vector<std::string> getArrayOption(config_option_t option) const override { return {}; }
-    std::shared_ptr<AutoscanList> getAutoscanListOption(config_option_t option) const override { return nullptr; }
+    std::vector<AutoscanDirectory> getAutoscanListOption(config_option_t option) const override { return {}; }
     std::shared_ptr<ClientConfigList> getClientConfigListOption(config_option_t option) const override { return nullptr; }
     std::shared_ptr<DirectoryConfigList> getDirectoryTweakOption(config_option_t option) const override { return nullptr; }
     void updateConfigFromDatabase(const std::shared_ptr<Database>& database) override { }
