@@ -6,6 +6,7 @@
 #include "config/config.h"
 #include "config/config_setup.h"
 #include "database/database.h"
+#include "util/upnp_clients.h"
 
 class DatabaseMock : public Database {
 public:
@@ -33,6 +34,7 @@ public:
     std::string incrementUpdateIDs(const std::unordered_set<int>& ids) override { return {}; }
 
     std::shared_ptr<CdsObject> loadObject(int objectID) override { return nullptr; }
+    std::shared_ptr<CdsObject> loadObject(const std::string& group, int objectID) override { return nullptr; }
     int getChildCount(int contId, bool containers = true, bool items = true, bool hideFsRoot = false) override { return 0; }
     std::map<int, int> getChildCounts(const std::vector<int>& contId, bool containers, bool items, bool hideFsRoot) override { return {}; }
 
@@ -48,16 +50,20 @@ public:
     std::string getInternalSetting(const std::string& key) override { return {}; }
     void storeInternalSetting(const std::string& key, const std::string& value) override { }
 
-    std::vector<ConfigValue> getConfigValues() override
-    {
-        std::vector<ConfigValue> result;
-        return result;
-    }
+    std::vector<ConfigValue> getConfigValues() override { return {}; }
     void removeConfigValue(const std::string& item) override { }
     void updateConfigValue(const std::string& key, const std::string& item, const std::string& value, const std::string& status = "unchanged") override { }
 
-    std::shared_ptr<AutoscanList> getAutoscanList(ScanMode scanode) override { return {}; }
-    void updateAutoscanList(ScanMode scanmode, const std::shared_ptr<AutoscanList>& list) override { }
+    /* clients methods */
+    std::vector<ClientCacheEntry> getClients() override { return {}; }
+    void saveClients(const std::vector<ClientCacheEntry>& cache) override { }
+    std::shared_ptr<ClientStatusDetail> getPlayStatus(const std::string& group, int objectId) override { return {}; };
+    void savePlayStatus(const std::shared_ptr<ClientStatusDetail>& detail) override { };
+    std::vector<std::shared_ptr<ClientStatusDetail>> getPlayStatusList(int objectId) override { return {}; }
+    std::vector<std::map<std::string, std::string>> getClientGroupStats() override { return {}; }
+
+    std::shared_ptr<AutoscanList> getAutoscanList(AutoscanDirectory::ScanMode scanode) override { return {}; }
+    void updateAutoscanList(AutoscanDirectory::ScanMode scanmode, const std::shared_ptr<AutoscanList>& list) override { }
 
     std::shared_ptr<AutoscanDirectory> getAutoscanDirectory(int objectID) override { return {}; }
     void addAutoscanDirectory(const std::shared_ptr<AutoscanDirectory>& adir) override { }
