@@ -1,43 +1,36 @@
 #ifdef HAVE_JS
 
 #include <duktape.h>
-#include <filesystem>
 #include <gmock/gmock.h>
 #include <gtest/gtest.h>
-namespace fs = std::filesystem;
 
-#include "config/config_manager.h"
-#include "util/string_converter.h"
 #include "util/tools.h"
 
 #include "mock/script_test_fixture.h"
 
-using namespace ::testing;
-
 class CommonScriptTest : public ::testing::Test {
 
 public:
-    CommonScriptTest() {};
+    CommonScriptTest() = default;
+    ~CommonScriptTest() override = default;
 
-    virtual ~CommonScriptTest() {};
-
-    virtual void SetUp()
+    void SetUp() override
     {
         ctx = duk_create_heap(nullptr, nullptr, nullptr, nullptr, nullptr);
 
         fs::path ss = fs::path(SCRIPTS_DIR) / "js" / "common.js";
-        std::string script = readTextFile(ss.c_str());
+        std::string script = GrbFile(ss).readTextFile();
         duk_push_string(ctx, ss.c_str());
         duk_pcompile_lstring_filename(ctx, 0, script.c_str(), script.length());
         duk_call(ctx, 0);
     }
 
-    virtual void TearDown()
+    void TearDown() override
     {
         duk_destroy_heap(ctx);
     }
 
-    std::string invokeABCBOX(duk_context* ctx, std::string input, int boxType, std::string divChar)
+    static std::string invokeABCBOX(duk_context* ctx, const std::string& input, int boxType, const std::string& divChar)
     {
         ScriptTestFixture::addConfig(ctx, { { "/import/scripting/virtual-layout/abcBox/skipChars", "" } });
 
@@ -97,7 +90,7 @@ TEST_F(CommonScriptTest, mapInitial_Umlaut)
 TEST_F(CommonScriptTest, escapeSlash_AddsEscapeCharsForBackSlash)
 {
     duk_get_global_string(ctx, "escapeSlash");
-    duk_push_string(ctx, "some\\path\\to\\escape");
+    duk_push_string(ctx, R"(some\path\to\escape)");
 
     duk_pcall(ctx, 1);
 
@@ -108,15 +101,15 @@ TEST_F(CommonScriptTest, escapeSlash_AddsEscapeCharsForBackSlash)
 
 TEST_F(CommonScriptTest, createContainerChain_concatenatesContainerChainWithSlashBasedOnArray)
 {
-    duk_idx_t arr_idx;
+    duk_idx_t arrIdx;
     duk_get_global_string(ctx, "createContainerChain");
-    arr_idx = duk_push_array(ctx);
+    arrIdx = duk_push_array(ctx);
     duk_push_string(ctx, "path");
-    duk_put_prop_index(ctx, arr_idx, 0);
+    duk_put_prop_index(ctx, arrIdx, 0);
     duk_push_string(ctx, "to");
-    duk_put_prop_index(ctx, arr_idx, 1);
+    duk_put_prop_index(ctx, arrIdx, 1);
     duk_push_string(ctx, "combine");
-    duk_put_prop_index(ctx, arr_idx, 2);
+    duk_put_prop_index(ctx, arrIdx, 2);
 
     duk_pcall(ctx, 1);
 
