@@ -5,15 +5,12 @@
 #include <memory>
 
 #include "cds_objects.h"
-#include "config/config_manager.h"
 #include "util/string_converter.h"
 
 #include "mock/common_script_mock.h"
 #include "mock/duk_helper.h"
 #include "mock/script_test_fixture.h"
 
-using namespace ::testing;
-
 // Extends ScriptTestFixture to allow
 // for unique testing of the External URL Playlist
 // processing
@@ -22,9 +19,6 @@ public:
     // As Duktape requires static methods, so must the mock expectations be
     static std::unique_ptr<CommonScriptMock> commonScriptMock;
 
-    // Used to iterate through `readln` content
-    static int readLineCnt;
-
     ExternalUrlM3UPlaylistTest()
     {
         commonScriptMock = std::make_unique<::testing::NiceMock<CommonScriptMock>>();
@@ -38,7 +32,6 @@ public:
 };
 
 std::unique_ptr<CommonScriptMock> ExternalUrlM3UPlaylistTest::commonScriptMock;
-int ExternalUrlM3UPlaylistTest::readLineCnt = 0;
 
 static duk_ret_t getPlaylistType(duk_context* ctx)
 {
@@ -80,14 +73,7 @@ static duk_ret_t getLastPath(duk_context* ctx)
 // Uses the `CommonScriptMock` to track expectations
 static duk_ret_t readln(duk_context* ctx)
 {
-    std::vector<std::string> lines {
-        "#EXTM3U",
-        "#EXTINF:-1,(#1 - 177/750) : Ibiza Global Radio :",
-        "http://46.105.171.217:8024",
-        "-EOF-" // used to stop processing
-    };
-
-    std::string line = lines.at(ExternalUrlM3UPlaylistTest::readLineCnt);
+    std::string line = ExternalUrlM3UPlaylistTest::lines.at(ExternalUrlM3UPlaylistTest::readLineCnt);
 
     duk_push_string(ctx, line.c_str());
     ExternalUrlM3UPlaylistTest::readLineCnt++;
@@ -130,7 +116,7 @@ static duk_function_list_entry js_global_functions[] = {
 };
 
 template <typename Map>
-bool map_compare(Map const& lhs, Map const& rhs)
+bool mapCompare(Map const& lhs, Map const& rhs)
 {
     return lhs.size() == rhs.size() && std::equal(lhs.begin(), lhs.end(), rhs.begin());
 }
@@ -138,7 +124,7 @@ bool map_compare(Map const& lhs, Map const& rhs)
 MATCHER_P(IsIdenticalMap, control, "Map to be identical")
 {
     {
-        return (map_compare(arg, control));
+        return (mapCompare(arg, control));
     }
 }
 
@@ -163,30 +149,31 @@ TEST_F(ExternalUrlM3UPlaylistTest, PrintsWarningWhenPlaylistTypeIsNotFound)
     executeScript(ctx);
 }
 
-TEST_F(ExternalUrlM3UPlaylistTest, AddsCdsObjectFromM3UPlaylistWithExternalUrlPlaylistAndDirChains)
+TEST_F(ExternalUrlM3UPlaylistTest, AddsCdsObjectFromPlaylistWithExternalUrlPlaylistAndDirChains)
 {
-    const std::string MIME_TYPE_AUDIO_MPEG = "audio/mpeg";
-    const std::string OBJTYPE_ITEM_EXTERNAL_URL = "8";
+    ScriptTestFixture::mockPlaylistFile("fixtures/example-external.m3u");
+    const std::string mimeType = "audio/mpeg";
+    const std::string objtypeItemExternalUrl = "8";
 
     std::map<std::string, std::string> asPlaylistChain {
         { "title", "(#1 - 177/750) : Ibiza Global Radio :" },
         { "location", "http://46.105.171.217:8024" },
-        { "mimetype", MIME_TYPE_AUDIO_MPEG },
-        { "objectType", OBJTYPE_ITEM_EXTERNAL_URL },
+        { "mimetype", mimeType },
+        { "objectType", objtypeItemExternalUrl },
         { "playlistOrder", "1" },
         { "protocol", "http-get" },
-        { "description", "Song from Playlist Title" },
+        { "description", "Entry from Playlist Title" },
         { "upnpclass", UPNP_CLASS_MUSIC_TRACK },
     };
 
     std::map<std::string, std::string> asPlaylistDirChain {
         { "title", "(#1 - 177/750) : Ibiza Global Radio :" },
         { "location", "http://46.105.171.217:8024" },
-        { "mimetype", MIME_TYPE_AUDIO_MPEG },
-        { "objectType", OBJTYPE_ITEM_EXTERNAL_URL },
-        { "playlistOrder", "2" },
+        { "mimetype", mimeType },
+        { "objectType", objtypeItemExternalUrl },
+        { "playlistOrder", "1" },
         { "protocol", "http-get" },
-        { "description", "Song from Playlist Title" },
+        { "description", "Entry from Playlist Title" },
         { "upnpclass", UPNP_CLASS_MUSIC_TRACK },
     };
 
@@ -208,4 +195,51 @@ TEST_F(ExternalUrlM3UPlaylistTest, AddsCdsObjectFromM3UPlaylistWithExternalUrlPl
 
     executeScript(ctx);
 }
+
+TEST_F(ExternalUrlM3UPlaylistTest, AddsVideoFromPlaylistWithExternalUrlPlaylistAndDirChains)
+{
+    ScriptTestFixture::mockPlaylistFile("fixtures/example-external-video.m3u");
+    const std::string mimeType = "video/mp4";
+    const std::string objtypeItemExternalUrl = "8";
+
+    std::map<std::string, std::string> asPlaylistChain {
+        { "title", "(#1 - 177/750) : Ibiza Tourism Video :" },
+        { "location", "http://46.105.171.217:8024" },
+        { "mimetype", mimeType },
+        { "objectType", objtypeItemExternalUrl },
+        { "playlistOrder", "1" },
+        { "protocol", "http-get" },
+        { "description", "Entry from Playlist Title" },
+        { "upnpclass", UPNP_CLASS_VIDEO_ITEM },
+    };
+
+    std::map<std::string, std::string> asPlaylistDirChain {
+        { "title", "(#1 - 177/750) : Ibiza Tourism Video :" },
+        { "location", "http://46.105.171.217:8024" },
+        { "mimetype", mimeType },
+        { "objectType", objtypeItemExternalUrl },
+        { "playlistOrder", "1" },
+        { "protocol", "http-get" },
+        { "description", "Entry from Playlist Title" },
+        { "upnpclass", UPNP_CLASS_VIDEO_ITEM },
+    };
+
+    // Expecting the common script calls..and will proxy through the mock objects for verification.
+    EXPECT_CALL(*commonScriptMock, getPlaylistType(Eq("audio/x-mpegurl"))).WillOnce(Return(1));
+    EXPECT_CALL(*commonScriptMock, print(Eq("Processing playlist: /location/of/playlist.m3u"))).WillOnce(Return(1));
+    EXPECT_CALL(*commonScriptMock, addContainerTree(ElementsAre("Playlists", "All Playlists", "Playlist Title"))).WillOnce(Return(1));
+    EXPECT_CALL(*commonScriptMock, getLastPath(Eq("/location/of/playlist.m3u"))).WillOnce(Return(1));
+    EXPECT_CALL(*commonScriptMock, addContainerTree(ElementsAre("Playlists", "Directories", "of", "Playlist Title"))).WillOnce(Return(1));
+    EXPECT_CALL(*commonScriptMock, readln(Eq("#EXTM3U"))).WillOnce(Return(1));
+    EXPECT_CALL(*commonScriptMock, readln(Eq("#EXTINF:-1,(#1 - 177/750) : Ibiza Tourism Video :,video/mp4"))).WillOnce(Return(1));
+    EXPECT_CALL(*commonScriptMock, readln(Eq("http://46.105.171.217:8024"))).WillOnce(Return(1));
+    EXPECT_CALL(*commonScriptMock, readln(Eq("-EOF-"))).WillOnce(Return(0));
+    EXPECT_CALL(*commonScriptMock, addCdsObject(IsIdenticalMap(asPlaylistChain), "42", UNDEFINED)).WillOnce(Return(0));
+    EXPECT_CALL(*commonScriptMock, addCdsObject(IsIdenticalMap(asPlaylistDirChain), "43", UNDEFINED)).WillOnce(Return(0));
+
+    addGlobalFunctions(ctx, js_global_functions);
+    dukMockPlaylist(ctx, "Playlist Title", "/location/of/playlist.m3u", "audio/x-mpegurl");
+
+    executeScript(ctx);
+}
 #endif
