@@ -3,7 +3,7 @@
 
     runtime_test.cc - this file is part of Gerbera.
 
-    Copyright (C) 2016-2021 Gerbera Contributors
+    Copyright (C) 2016-2022 Gerbera Contributors
 
     Gerbera is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
@@ -24,7 +24,7 @@
 
 TEST_F(RuntimeTest, CheckTestCodeLinksAgainstDependencies)
 {
-    ScriptingRuntime* runtime = new ScriptingRuntime();
-    duk_context* ctx = runtime->createContext("testCtx");
+    auto runtime = std::make_unique<ScriptingRuntime>();
+    auto ctx = runtime->createContext("testCtx");
     EXPECT_NE(ctx, nullptr);
 }
