@@ -4,7 +4,7 @@
 
     gerbera-clients.module.js - this file is part of Gerbera.
 
-    Copyright (C) 2016-2021 Gerbera Contributors
+    Copyright (C) 2016-2022 Gerbera Contributors
 
     Gerbera is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
@@ -44,21 +44,24 @@ const menuSelected = () => {
 };
 
 const retrieveGerberaItems = (type) => {
+  var requestData = {
+    req_type: type
+  };
+  requestData[Auth.SID] = Auth.getSessionId();
   return $.ajax({
     url: GerberaApp.clientConfig.api,
     type: 'get',
-    data: {
-      req_type: type,
-      sid: Auth.getSessionId()
-     }
+    data: requestData
   });
 };
 
 const loadItems = (response) => {
   if (response.success) {
     let items;
+    let groups;
 
-    items = transformItems(response.clients.client);
+    items = 'clients' in response ? transformItems(response.clients.client) : [];
+    groups = 'groups' in response ? response.groups.group : [];
 
     const datagrid = $('#clientgrid');
 
@@ -68,6 +71,7 @@ const loadItems = (response) => {
 
     datagrid.clients({
       data: items,
+      groups: groups,
       itemType: 'clients'
     });
   }
